from __future__ import annotations
from win32more import ARCH, Annotated, Boolean, Byte, Bytes, Char, ComPtr, ConstantLazyLoader, Double, Enum, FAILED, Guid, Int16, Int32, Int64, IntPtr, POINTER, SByte, SUCCEEDED, Single, String, Structure, UInt16, UInt32, UInt64, UIntPtr, UnicodeAlias, Union, Void, VoidPtr, cfunctype, cfunctype_pointer, commethod, make_ready, winfunctype, winfunctype_pointer
import win32more.Windows.Win32.Foundation
import win32more.Windows.Win32.NetworkManagement.Ndis
NET_IF_COMPARTMENT_ID_UNSPECIFIED: UInt32 = 0
NET_IF_COMPARTMENT_ID_PRIMARY: UInt32 = 1
IOCTL_NDIS_RESERVED5: UInt32 = 1507380
IOCTL_NDIS_RESERVED6: UInt32 = 1540152
NDIS_OBJECT_TYPE_DEFAULT: UInt32 = 128
NDIS_OBJECT_TYPE_MINIPORT_INIT_PARAMETERS: UInt32 = 129
NDIS_OBJECT_TYPE_SG_DMA_DESCRIPTION: UInt32 = 131
NDIS_OBJECT_TYPE_MINIPORT_INTERRUPT: UInt32 = 132
NDIS_OBJECT_TYPE_DEVICE_OBJECT_ATTRIBUTES: UInt32 = 133
NDIS_OBJECT_TYPE_BIND_PARAMETERS: UInt32 = 134
NDIS_OBJECT_TYPE_OPEN_PARAMETERS: UInt32 = 135
NDIS_OBJECT_TYPE_RSS_CAPABILITIES: UInt32 = 136
NDIS_OBJECT_TYPE_RSS_PARAMETERS: UInt32 = 137
NDIS_OBJECT_TYPE_MINIPORT_DRIVER_CHARACTERISTICS: UInt32 = 138
NDIS_OBJECT_TYPE_FILTER_DRIVER_CHARACTERISTICS: UInt32 = 139
NDIS_OBJECT_TYPE_FILTER_PARTIAL_CHARACTERISTICS: UInt32 = 140
NDIS_OBJECT_TYPE_FILTER_ATTRIBUTES: UInt32 = 141
NDIS_OBJECT_TYPE_CLIENT_CHIMNEY_OFFLOAD_GENERIC_CHARACTERISTICS: UInt32 = 142
NDIS_OBJECT_TYPE_PROVIDER_CHIMNEY_OFFLOAD_GENERIC_CHARACTERISTICS: UInt32 = 143
NDIS_OBJECT_TYPE_CO_PROTOCOL_CHARACTERISTICS: UInt32 = 144
NDIS_OBJECT_TYPE_CO_MINIPORT_CHARACTERISTICS: UInt32 = 145
NDIS_OBJECT_TYPE_MINIPORT_PNP_CHARACTERISTICS: UInt32 = 146
NDIS_OBJECT_TYPE_CLIENT_CHIMNEY_OFFLOAD_CHARACTERISTICS: UInt32 = 147
NDIS_OBJECT_TYPE_PROVIDER_CHIMNEY_OFFLOAD_CHARACTERISTICS: UInt32 = 148
NDIS_OBJECT_TYPE_PROTOCOL_DRIVER_CHARACTERISTICS: UInt32 = 149
NDIS_OBJECT_TYPE_REQUEST_EX: UInt32 = 150
NDIS_OBJECT_TYPE_TIMER_CHARACTERISTICS: UInt32 = 151
NDIS_OBJECT_TYPE_STATUS_INDICATION: UInt32 = 152
NDIS_OBJECT_TYPE_FILTER_ATTACH_PARAMETERS: UInt32 = 153
NDIS_OBJECT_TYPE_FILTER_PAUSE_PARAMETERS: UInt32 = 154
NDIS_OBJECT_TYPE_FILTER_RESTART_PARAMETERS: UInt32 = 155
NDIS_OBJECT_TYPE_PORT_CHARACTERISTICS: UInt32 = 156
NDIS_OBJECT_TYPE_PORT_STATE: UInt32 = 157
NDIS_OBJECT_TYPE_MINIPORT_ADAPTER_REGISTRATION_ATTRIBUTES: UInt32 = 158
NDIS_OBJECT_TYPE_MINIPORT_ADAPTER_GENERAL_ATTRIBUTES: UInt32 = 159
NDIS_OBJECT_TYPE_MINIPORT_ADAPTER_OFFLOAD_ATTRIBUTES: UInt32 = 160
NDIS_OBJECT_TYPE_MINIPORT_ADAPTER_NATIVE_802_11_ATTRIBUTES: UInt32 = 161
NDIS_OBJECT_TYPE_RESTART_GENERAL_ATTRIBUTES: UInt32 = 162
NDIS_OBJECT_TYPE_PROTOCOL_RESTART_PARAMETERS: UInt32 = 163
NDIS_OBJECT_TYPE_MINIPORT_ADD_DEVICE_REGISTRATION_ATTRIBUTES: UInt32 = 164
NDIS_OBJECT_TYPE_CO_CALL_MANAGER_OPTIONAL_HANDLERS: UInt32 = 165
NDIS_OBJECT_TYPE_CO_CLIENT_OPTIONAL_HANDLERS: UInt32 = 166
NDIS_OBJECT_TYPE_OFFLOAD: UInt32 = 167
NDIS_OBJECT_TYPE_OFFLOAD_ENCAPSULATION: UInt32 = 168
NDIS_OBJECT_TYPE_CONFIGURATION_OBJECT: UInt32 = 169
NDIS_OBJECT_TYPE_DRIVER_WRAPPER_OBJECT: UInt32 = 170
NDIS_OBJECT_TYPE_HD_SPLIT_ATTRIBUTES: UInt32 = 171
NDIS_OBJECT_TYPE_NSI_NETWORK_RW_STRUCT: UInt32 = 172
NDIS_OBJECT_TYPE_NSI_COMPARTMENT_RW_STRUCT: UInt32 = 173
NDIS_OBJECT_TYPE_NSI_INTERFACE_PERSIST_RW_STRUCT: UInt32 = 174
NDIS_OBJECT_TYPE_MINIPORT_ADAPTER_HARDWARE_ASSIST_ATTRIBUTES: UInt32 = 175
NDIS_OBJECT_TYPE_SHARED_MEMORY_PROVIDER_CHARACTERISTICS: UInt32 = 176
NDIS_OBJECT_TYPE_RSS_PROCESSOR_INFO: UInt32 = 177
NDIS_OBJECT_TYPE_NDK_PROVIDER_CHARACTERISTICS: UInt32 = 178
NDIS_OBJECT_TYPE_MINIPORT_ADAPTER_NDK_ATTRIBUTES: UInt32 = 179
NDIS_OBJECT_TYPE_MINIPORT_SS_CHARACTERISTICS: UInt32 = 180
NDIS_OBJECT_TYPE_QOS_CAPABILITIES: UInt32 = 181
NDIS_OBJECT_TYPE_QOS_PARAMETERS: UInt32 = 182
NDIS_OBJECT_TYPE_QOS_CLASSIFICATION_ELEMENT: UInt32 = 183
NDIS_OBJECT_TYPE_SWITCH_OPTIONAL_HANDLERS: UInt32 = 184
NDIS_OBJECT_TYPE_PD_TRANSMIT_QUEUE: UInt32 = 190
NDIS_OBJECT_TYPE_PD_RECEIVE_QUEUE: UInt32 = 191
NDIS_OBJECT_TYPE_MINIPORT_ADAPTER_PACKET_DIRECT_ATTRIBUTES: UInt32 = 197
NDIS_OBJECT_TYPE_MINIPORT_DEVICE_POWER_NOTIFICATION: UInt32 = 198
NDIS_OBJECT_TYPE_RSS_PARAMETERS_V2: UInt32 = 200
NDIS_OBJECT_TYPE_RSS_SET_INDIRECTION_ENTRIES: UInt32 = 201
NDIS_STATISTICS_FLAGS_VALID_DIRECTED_FRAMES_RCV: UInt32 = 1
NDIS_STATISTICS_FLAGS_VALID_MULTICAST_FRAMES_RCV: UInt32 = 2
NDIS_STATISTICS_FLAGS_VALID_BROADCAST_FRAMES_RCV: UInt32 = 4
NDIS_STATISTICS_FLAGS_VALID_BYTES_RCV: UInt32 = 8
NDIS_STATISTICS_FLAGS_VALID_RCV_DISCARDS: UInt32 = 16
NDIS_STATISTICS_FLAGS_VALID_RCV_ERROR: UInt32 = 32
NDIS_STATISTICS_FLAGS_VALID_DIRECTED_FRAMES_XMIT: UInt32 = 64
NDIS_STATISTICS_FLAGS_VALID_MULTICAST_FRAMES_XMIT: UInt32 = 128
NDIS_STATISTICS_FLAGS_VALID_BROADCAST_FRAMES_XMIT: UInt32 = 256
NDIS_STATISTICS_FLAGS_VALID_BYTES_XMIT: UInt32 = 512
NDIS_STATISTICS_FLAGS_VALID_XMIT_ERROR: UInt32 = 1024
NDIS_STATISTICS_FLAGS_VALID_XMIT_DISCARDS: UInt32 = 32768
NDIS_STATISTICS_FLAGS_VALID_DIRECTED_BYTES_RCV: UInt32 = 65536
NDIS_STATISTICS_FLAGS_VALID_MULTICAST_BYTES_RCV: UInt32 = 131072
NDIS_STATISTICS_FLAGS_VALID_BROADCAST_BYTES_RCV: UInt32 = 262144
NDIS_STATISTICS_FLAGS_VALID_DIRECTED_BYTES_XMIT: UInt32 = 524288
NDIS_STATISTICS_FLAGS_VALID_MULTICAST_BYTES_XMIT: UInt32 = 1048576
NDIS_STATISTICS_FLAGS_VALID_BROADCAST_BYTES_XMIT: UInt32 = 2097152
NDIS_STATISTICS_INFO_REVISION_1: UInt32 = 1
NDIS_RSC_STATISTICS_REVISION_1: UInt32 = 1
NDIS_INTERRUPT_MODERATION_CHANGE_NEEDS_RESET: UInt32 = 1
NDIS_INTERRUPT_MODERATION_CHANGE_NEEDS_REINITIALIZE: UInt32 = 2
NDIS_INTERRUPT_MODERATION_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_TIMEOUT_DPC_REQUEST_CAPABILITIES_REVISION_1: UInt32 = 1
NDIS_OBJECT_TYPE_PCI_DEVICE_CUSTOM_PROPERTIES_REVISION_1: UInt32 = 1
NDIS_OBJECT_TYPE_PCI_DEVICE_CUSTOM_PROPERTIES_REVISION_2: UInt32 = 2
OID_GEN_SUPPORTED_LIST: UInt32 = 65793
OID_GEN_HARDWARE_STATUS: UInt32 = 65794
OID_GEN_MEDIA_SUPPORTED: UInt32 = 65795
OID_GEN_MEDIA_IN_USE: UInt32 = 65796
OID_GEN_MAXIMUM_LOOKAHEAD: UInt32 = 65797
OID_GEN_MAXIMUM_FRAME_SIZE: UInt32 = 65798
OID_GEN_LINK_SPEED: UInt32 = 65799
OID_GEN_TRANSMIT_BUFFER_SPACE: UInt32 = 65800
OID_GEN_RECEIVE_BUFFER_SPACE: UInt32 = 65801
OID_GEN_TRANSMIT_BLOCK_SIZE: UInt32 = 65802
OID_GEN_RECEIVE_BLOCK_SIZE: UInt32 = 65803
OID_GEN_VENDOR_ID: UInt32 = 65804
OID_GEN_VENDOR_DESCRIPTION: UInt32 = 65805
OID_GEN_CURRENT_PACKET_FILTER: UInt32 = 65806
OID_GEN_CURRENT_LOOKAHEAD: UInt32 = 65807
OID_GEN_DRIVER_VERSION: UInt32 = 65808
OID_GEN_MAXIMUM_TOTAL_SIZE: UInt32 = 65809
OID_GEN_PROTOCOL_OPTIONS: UInt32 = 65810
OID_GEN_MAC_OPTIONS: UInt32 = 65811
OID_GEN_MEDIA_CONNECT_STATUS: UInt32 = 65812
OID_GEN_MAXIMUM_SEND_PACKETS: UInt32 = 65813
OID_GEN_VENDOR_DRIVER_VERSION: UInt32 = 65814
OID_GEN_SUPPORTED_GUIDS: UInt32 = 65815
OID_GEN_NETWORK_LAYER_ADDRESSES: UInt32 = 65816
OID_GEN_TRANSPORT_HEADER_OFFSET: UInt32 = 65817
OID_GEN_MEDIA_CAPABILITIES: UInt32 = 66049
OID_GEN_PHYSICAL_MEDIUM: UInt32 = 66050
OID_GEN_RECEIVE_SCALE_CAPABILITIES: UInt32 = 66051
OID_GEN_RECEIVE_SCALE_PARAMETERS: UInt32 = 66052
OID_GEN_MAC_ADDRESS: UInt32 = 66053
OID_GEN_MAX_LINK_SPEED: UInt32 = 66054
OID_GEN_LINK_STATE: UInt32 = 66055
OID_GEN_LINK_PARAMETERS: UInt32 = 66056
OID_GEN_INTERRUPT_MODERATION: UInt32 = 66057
OID_GEN_NDIS_RESERVED_3: UInt32 = 66058
OID_GEN_NDIS_RESERVED_4: UInt32 = 66059
OID_GEN_NDIS_RESERVED_5: UInt32 = 66060
OID_GEN_ENUMERATE_PORTS: UInt32 = 66061
OID_GEN_PORT_STATE: UInt32 = 66062
OID_GEN_PORT_AUTHENTICATION_PARAMETERS: UInt32 = 66063
OID_GEN_TIMEOUT_DPC_REQUEST_CAPABILITIES: UInt32 = 66064
OID_GEN_PCI_DEVICE_CUSTOM_PROPERTIES: UInt32 = 66065
OID_GEN_NDIS_RESERVED_6: UInt32 = 66066
OID_GEN_PHYSICAL_MEDIUM_EX: UInt32 = 66067
OID_GEN_RECEIVE_SCALE_PARAMETERS_V2: UInt32 = 66068
OID_GEN_MACHINE_NAME: UInt32 = 66074
OID_GEN_RNDIS_CONFIG_PARAMETER: UInt32 = 66075
OID_GEN_VLAN_ID: UInt32 = 66076
OID_GEN_RECEIVE_HASH: UInt32 = 66079
OID_GEN_MINIPORT_RESTART_ATTRIBUTES: UInt32 = 66077
OID_GEN_HD_SPLIT_PARAMETERS: UInt32 = 66078
OID_GEN_HD_SPLIT_CURRENT_CONFIG: UInt32 = 66080
OID_GEN_PROMISCUOUS_MODE: UInt32 = 66176
OID_GEN_LAST_CHANGE: UInt32 = 66177
OID_GEN_DISCONTINUITY_TIME: UInt32 = 66178
OID_GEN_OPERATIONAL_STATUS: UInt32 = 66179
OID_GEN_XMIT_LINK_SPEED: UInt32 = 66180
OID_GEN_RCV_LINK_SPEED: UInt32 = 66181
OID_GEN_UNKNOWN_PROTOS: UInt32 = 66182
OID_GEN_INTERFACE_INFO: UInt32 = 66183
OID_GEN_ADMIN_STATUS: UInt32 = 66184
OID_GEN_ALIAS: UInt32 = 66185
OID_GEN_MEDIA_CONNECT_STATUS_EX: UInt32 = 66186
OID_GEN_LINK_SPEED_EX: UInt32 = 66187
OID_GEN_MEDIA_DUPLEX_STATE: UInt32 = 66188
OID_GEN_IP_OPER_STATUS: UInt32 = 66189
OID_WWAN_DRIVER_CAPS: UInt32 = 234946816
OID_WWAN_DEVICE_CAPS: UInt32 = 234946817
OID_WWAN_READY_INFO: UInt32 = 234946818
OID_WWAN_RADIO_STATE: UInt32 = 234946819
OID_WWAN_PIN: UInt32 = 234946820
OID_WWAN_PIN_LIST: UInt32 = 234946821
OID_WWAN_HOME_PROVIDER: UInt32 = 234946822
OID_WWAN_PREFERRED_PROVIDERS: UInt32 = 234946823
OID_WWAN_VISIBLE_PROVIDERS: UInt32 = 234946824
OID_WWAN_REGISTER_STATE: UInt32 = 234946825
OID_WWAN_PACKET_SERVICE: UInt32 = 234946826
OID_WWAN_SIGNAL_STATE: UInt32 = 234946827
OID_WWAN_CONNECT: UInt32 = 234946828
OID_WWAN_PROVISIONED_CONTEXTS: UInt32 = 234946829
OID_WWAN_SERVICE_ACTIVATION: UInt32 = 234946830
OID_WWAN_SMS_CONFIGURATION: UInt32 = 234946831
OID_WWAN_SMS_READ: UInt32 = 234946832
OID_WWAN_SMS_SEND: UInt32 = 234946833
OID_WWAN_SMS_DELETE: UInt32 = 234946834
OID_WWAN_SMS_STATUS: UInt32 = 234946835
OID_WWAN_VENDOR_SPECIFIC: UInt32 = 234946836
OID_WWAN_AUTH_CHALLENGE: UInt32 = 234946837
OID_WWAN_ENUMERATE_DEVICE_SERVICES: UInt32 = 234946838
OID_WWAN_SUBSCRIBE_DEVICE_SERVICE_EVENTS: UInt32 = 234946839
OID_WWAN_DEVICE_SERVICE_COMMAND: UInt32 = 234946840
OID_WWAN_USSD: UInt32 = 234946841
OID_WWAN_PIN_EX: UInt32 = 234946849
OID_WWAN_ENUMERATE_DEVICE_SERVICE_COMMANDS: UInt32 = 234946850
OID_WWAN_DEVICE_SERVICE_SESSION: UInt32 = 234946851
OID_WWAN_DEVICE_SERVICE_SESSION_WRITE: UInt32 = 234946852
OID_WWAN_PREFERRED_MULTICARRIER_PROVIDERS: UInt32 = 234946853
OID_WWAN_CREATE_MAC: UInt32 = 234946854
OID_WWAN_DELETE_MAC: UInt32 = 234946855
OID_WWAN_UICC_FILE_STATUS: UInt32 = 234946856
OID_WWAN_UICC_ACCESS_BINARY: UInt32 = 234946857
OID_WWAN_UICC_ACCESS_RECORD: UInt32 = 234946858
OID_WWAN_PIN_EX2: UInt32 = 234946859
OID_WWAN_MBIM_VERSION: UInt32 = 234946860
OID_WWAN_SYS_CAPS: UInt32 = 234946861
OID_WWAN_DEVICE_CAPS_EX: UInt32 = 234946862
OID_WWAN_SYS_SLOTMAPPINGS: UInt32 = 234946863
OID_WWAN_SLOT_INFO_STATUS: UInt32 = 234946864
OID_WWAN_DEVICE_BINDINGS: UInt32 = 234946865
OID_WWAN_REGISTER_STATE_EX: UInt32 = 234946866
OID_WWAN_IMS_VOICE_STATE: UInt32 = 234946867
OID_WWAN_SIGNAL_STATE_EX: UInt32 = 234946868
OID_WWAN_LOCATION_STATE: UInt32 = 234946869
OID_WWAN_NITZ: UInt32 = 234946870
OID_WWAN_NETWORK_IDLE_HINT: UInt32 = 234946871
OID_WWAN_PRESHUTDOWN: UInt32 = 234946872
OID_WWAN_UICC_ATR: UInt32 = 234946873
OID_WWAN_UICC_OPEN_CHANNEL: UInt32 = 234946874
OID_WWAN_UICC_CLOSE_CHANNEL: UInt32 = 234946875
OID_WWAN_UICC_APDU: UInt32 = 234946876
OID_WWAN_UICC_TERMINAL_CAPABILITY: UInt32 = 234946877
OID_WWAN_PS_MEDIA_CONFIG: UInt32 = 234946878
OID_WWAN_SAR_CONFIG: UInt32 = 234946879
OID_WWAN_SAR_TRANSMISSION_STATUS: UInt32 = 234946880
OID_WWAN_NETWORK_BLACKLIST: UInt32 = 234946881
OID_WWAN_LTE_ATTACH_CONFIG: UInt32 = 234946882
OID_WWAN_LTE_ATTACH_STATUS: UInt32 = 234946883
OID_WWAN_MODEM_CONFIG_INFO: UInt32 = 234946884
OID_WWAN_PCO: UInt32 = 234946885
OID_WWAN_UICC_RESET: UInt32 = 234946886
OID_WWAN_DEVICE_RESET: UInt32 = 234946887
OID_WWAN_BASE_STATIONS_INFO: UInt32 = 234946888
OID_WWAN_MPDP: UInt32 = 234946889
OID_WWAN_UICC_APP_LIST: UInt32 = 234946890
OID_WWAN_MODEM_LOGGING_CONFIG: UInt32 = 234946891
OID_WWAN_REGISTER_PARAMS: UInt32 = 234946892
OID_WWAN_NETWORK_PARAMS: UInt32 = 234946893
OID_WWAN_UE_POLICY: UInt32 = 234946894
OID_GEN_XMIT_OK: UInt32 = 131329
OID_GEN_RCV_OK: UInt32 = 131330
OID_GEN_XMIT_ERROR: UInt32 = 131331
OID_GEN_RCV_ERROR: UInt32 = 131332
OID_GEN_RCV_NO_BUFFER: UInt32 = 131333
OID_GEN_STATISTICS: UInt32 = 131334
OID_GEN_DIRECTED_BYTES_XMIT: UInt32 = 131585
OID_GEN_DIRECTED_FRAMES_XMIT: UInt32 = 131586
OID_GEN_MULTICAST_BYTES_XMIT: UInt32 = 131587
OID_GEN_MULTICAST_FRAMES_XMIT: UInt32 = 131588
OID_GEN_BROADCAST_BYTES_XMIT: UInt32 = 131589
OID_GEN_BROADCAST_FRAMES_XMIT: UInt32 = 131590
OID_GEN_DIRECTED_BYTES_RCV: UInt32 = 131591
OID_GEN_DIRECTED_FRAMES_RCV: UInt32 = 131592
OID_GEN_MULTICAST_BYTES_RCV: UInt32 = 131593
OID_GEN_MULTICAST_FRAMES_RCV: UInt32 = 131594
OID_GEN_BROADCAST_BYTES_RCV: UInt32 = 131595
OID_GEN_BROADCAST_FRAMES_RCV: UInt32 = 131596
OID_GEN_RCV_CRC_ERROR: UInt32 = 131597
OID_GEN_TRANSMIT_QUEUE_LENGTH: UInt32 = 131598
OID_GEN_GET_TIME_CAPS: UInt32 = 131599
OID_GEN_GET_NETCARD_TIME: UInt32 = 131600
OID_GEN_NETCARD_LOAD: UInt32 = 131601
OID_GEN_DEVICE_PROFILE: UInt32 = 131602
OID_GEN_INIT_TIME_MS: UInt32 = 131603
OID_GEN_RESET_COUNTS: UInt32 = 131604
OID_GEN_MEDIA_SENSE_COUNTS: UInt32 = 131605
OID_GEN_FRIENDLY_NAME: UInt32 = 131606
OID_GEN_NDIS_RESERVED_1: UInt32 = 131607
OID_GEN_NDIS_RESERVED_2: UInt32 = 131608
OID_GEN_BYTES_RCV: UInt32 = 131609
OID_GEN_BYTES_XMIT: UInt32 = 131610
OID_GEN_RCV_DISCARDS: UInt32 = 131611
OID_GEN_XMIT_DISCARDS: UInt32 = 131612
OID_TCP_RSC_STATISTICS: UInt32 = 131613
OID_GEN_NDIS_RESERVED_7: UInt32 = 131614
OID_GEN_CO_SUPPORTED_LIST: UInt32 = 65793
OID_GEN_CO_HARDWARE_STATUS: UInt32 = 65794
OID_GEN_CO_MEDIA_SUPPORTED: UInt32 = 65795
OID_GEN_CO_MEDIA_IN_USE: UInt32 = 65796
OID_GEN_CO_LINK_SPEED: UInt32 = 65799
OID_GEN_CO_VENDOR_ID: UInt32 = 65804
OID_GEN_CO_VENDOR_DESCRIPTION: UInt32 = 65805
OID_GEN_CO_DRIVER_VERSION: UInt32 = 65808
OID_GEN_CO_PROTOCOL_OPTIONS: UInt32 = 65810
OID_GEN_CO_MAC_OPTIONS: UInt32 = 65811
OID_GEN_CO_MEDIA_CONNECT_STATUS: UInt32 = 65812
OID_GEN_CO_VENDOR_DRIVER_VERSION: UInt32 = 65814
OID_GEN_CO_SUPPORTED_GUIDS: UInt32 = 65815
OID_GEN_CO_GET_TIME_CAPS: UInt32 = 131599
OID_GEN_CO_GET_NETCARD_TIME: UInt32 = 131600
OID_GEN_CO_MINIMUM_LINK_SPEED: UInt32 = 131360
OID_GEN_CO_XMIT_PDUS_OK: UInt32 = 131329
OID_GEN_CO_RCV_PDUS_OK: UInt32 = 131330
OID_GEN_CO_XMIT_PDUS_ERROR: UInt32 = 131331
OID_GEN_CO_RCV_PDUS_ERROR: UInt32 = 131332
OID_GEN_CO_RCV_PDUS_NO_BUFFER: UInt32 = 131333
OID_GEN_CO_RCV_CRC_ERROR: UInt32 = 131597
OID_GEN_CO_TRANSMIT_QUEUE_LENGTH: UInt32 = 131598
OID_GEN_CO_BYTES_XMIT: UInt32 = 131585
OID_GEN_CO_BYTES_RCV: UInt32 = 131591
OID_GEN_CO_NETCARD_LOAD: UInt32 = 131601
OID_GEN_CO_DEVICE_PROFILE: UInt32 = 131602
OID_GEN_CO_BYTES_XMIT_OUTSTANDING: UInt32 = 131617
OID_KDNET_ENUMERATE_PFS: UInt32 = 131618
OID_KDNET_ADD_PF: UInt32 = 131619
OID_KDNET_REMOVE_PF: UInt32 = 131620
OID_KDNET_QUERY_PF_INFORMATION: UInt32 = 131621
OID_802_3_PERMANENT_ADDRESS: UInt32 = 16843009
OID_802_3_CURRENT_ADDRESS: UInt32 = 16843010
OID_802_3_MULTICAST_LIST: UInt32 = 16843011
OID_802_3_MAXIMUM_LIST_SIZE: UInt32 = 16843012
OID_802_3_MAC_OPTIONS: UInt32 = 16843013
NDIS_802_3_MAC_OPTION_PRIORITY: UInt32 = 1
OID_802_3_RCV_ERROR_ALIGNMENT: UInt32 = 16908545
OID_802_3_XMIT_ONE_COLLISION: UInt32 = 16908546
OID_802_3_XMIT_MORE_COLLISIONS: UInt32 = 16908547
OID_802_3_XMIT_DEFERRED: UInt32 = 16908801
OID_802_3_XMIT_MAX_COLLISIONS: UInt32 = 16908802
OID_802_3_RCV_OVERRUN: UInt32 = 16908803
OID_802_3_XMIT_UNDERRUN: UInt32 = 16908804
OID_802_3_XMIT_HEARTBEAT_FAILURE: UInt32 = 16908805
OID_802_3_XMIT_TIMES_CRS_LOST: UInt32 = 16908806
OID_802_3_XMIT_LATE_COLLISIONS: UInt32 = 16908807
OID_802_3_ADD_MULTICAST_ADDRESS: UInt32 = 16843272
OID_802_3_DELETE_MULTICAST_ADDRESS: UInt32 = 16843273
OID_802_5_PERMANENT_ADDRESS: UInt32 = 33620225
OID_802_5_CURRENT_ADDRESS: UInt32 = 33620226
OID_802_5_CURRENT_FUNCTIONAL: UInt32 = 33620227
OID_802_5_CURRENT_GROUP: UInt32 = 33620228
OID_802_5_LAST_OPEN_STATUS: UInt32 = 33620229
OID_802_5_CURRENT_RING_STATUS: UInt32 = 33620230
OID_802_5_CURRENT_RING_STATE: UInt32 = 33620231
OID_802_5_LINE_ERRORS: UInt32 = 33685761
OID_802_5_LOST_FRAMES: UInt32 = 33685762
OID_802_5_BURST_ERRORS: UInt32 = 33686017
OID_802_5_AC_ERRORS: UInt32 = 33686018
OID_802_5_ABORT_DELIMETERS: UInt32 = 33686019
OID_802_5_FRAME_COPIED_ERRORS: UInt32 = 33686020
OID_802_5_FREQUENCY_ERRORS: UInt32 = 33686021
OID_802_5_TOKEN_ERRORS: UInt32 = 33686022
OID_802_5_INTERNAL_ERRORS: UInt32 = 33686023
OID_FDDI_LONG_PERMANENT_ADDR: UInt32 = 50397441
OID_FDDI_LONG_CURRENT_ADDR: UInt32 = 50397442
OID_FDDI_LONG_MULTICAST_LIST: UInt32 = 50397443
OID_FDDI_LONG_MAX_LIST_SIZE: UInt32 = 50397444
OID_FDDI_SHORT_PERMANENT_ADDR: UInt32 = 50397445
OID_FDDI_SHORT_CURRENT_ADDR: UInt32 = 50397446
OID_FDDI_SHORT_MULTICAST_LIST: UInt32 = 50397447
OID_FDDI_SHORT_MAX_LIST_SIZE: UInt32 = 50397448
OID_FDDI_ATTACHMENT_TYPE: UInt32 = 50462977
OID_FDDI_UPSTREAM_NODE_LONG: UInt32 = 50462978
OID_FDDI_DOWNSTREAM_NODE_LONG: UInt32 = 50462979
OID_FDDI_FRAME_ERRORS: UInt32 = 50462980
OID_FDDI_FRAMES_LOST: UInt32 = 50462981
OID_FDDI_RING_MGT_STATE: UInt32 = 50462982
OID_FDDI_LCT_FAILURES: UInt32 = 50462983
OID_FDDI_LEM_REJECTS: UInt32 = 50462984
OID_FDDI_LCONNECTION_STATE: UInt32 = 50462985
OID_FDDI_SMT_STATION_ID: UInt32 = 50528769
OID_FDDI_SMT_OP_VERSION_ID: UInt32 = 50528770
OID_FDDI_SMT_HI_VERSION_ID: UInt32 = 50528771
OID_FDDI_SMT_LO_VERSION_ID: UInt32 = 50528772
OID_FDDI_SMT_MANUFACTURER_DATA: UInt32 = 50528773
OID_FDDI_SMT_USER_DATA: UInt32 = 50528774
OID_FDDI_SMT_MIB_VERSION_ID: UInt32 = 50528775
OID_FDDI_SMT_MAC_CT: UInt32 = 50528776
OID_FDDI_SMT_NON_MASTER_CT: UInt32 = 50528777
OID_FDDI_SMT_MASTER_CT: UInt32 = 50528778
OID_FDDI_SMT_AVAILABLE_PATHS: UInt32 = 50528779
OID_FDDI_SMT_CONFIG_CAPABILITIES: UInt32 = 50528780
OID_FDDI_SMT_CONFIG_POLICY: UInt32 = 50528781
OID_FDDI_SMT_CONNECTION_POLICY: UInt32 = 50528782
OID_FDDI_SMT_T_NOTIFY: UInt32 = 50528783
OID_FDDI_SMT_STAT_RPT_POLICY: UInt32 = 50528784
OID_FDDI_SMT_TRACE_MAX_EXPIRATION: UInt32 = 50528785
OID_FDDI_SMT_PORT_INDEXES: UInt32 = 50528786
OID_FDDI_SMT_MAC_INDEXES: UInt32 = 50528787
OID_FDDI_SMT_BYPASS_PRESENT: UInt32 = 50528788
OID_FDDI_SMT_ECM_STATE: UInt32 = 50528789
OID_FDDI_SMT_CF_STATE: UInt32 = 50528790
OID_FDDI_SMT_HOLD_STATE: UInt32 = 50528791
OID_FDDI_SMT_REMOTE_DISCONNECT_FLAG: UInt32 = 50528792
OID_FDDI_SMT_STATION_STATUS: UInt32 = 50528793
OID_FDDI_SMT_PEER_WRAP_FLAG: UInt32 = 50528794
OID_FDDI_SMT_MSG_TIME_STAMP: UInt32 = 50528795
OID_FDDI_SMT_TRANSITION_TIME_STAMP: UInt32 = 50528796
OID_FDDI_SMT_SET_COUNT: UInt32 = 50528797
OID_FDDI_SMT_LAST_SET_STATION_ID: UInt32 = 50528798
OID_FDDI_MAC_FRAME_STATUS_FUNCTIONS: UInt32 = 50528799
OID_FDDI_MAC_BRIDGE_FUNCTIONS: UInt32 = 50528800
OID_FDDI_MAC_T_MAX_CAPABILITY: UInt32 = 50528801
OID_FDDI_MAC_TVX_CAPABILITY: UInt32 = 50528802
OID_FDDI_MAC_AVAILABLE_PATHS: UInt32 = 50528803
OID_FDDI_MAC_CURRENT_PATH: UInt32 = 50528804
OID_FDDI_MAC_UPSTREAM_NBR: UInt32 = 50528805
OID_FDDI_MAC_DOWNSTREAM_NBR: UInt32 = 50528806
OID_FDDI_MAC_OLD_UPSTREAM_NBR: UInt32 = 50528807
OID_FDDI_MAC_OLD_DOWNSTREAM_NBR: UInt32 = 50528808
OID_FDDI_MAC_DUP_ADDRESS_TEST: UInt32 = 50528809
OID_FDDI_MAC_REQUESTED_PATHS: UInt32 = 50528810
OID_FDDI_MAC_DOWNSTREAM_PORT_TYPE: UInt32 = 50528811
OID_FDDI_MAC_INDEX: UInt32 = 50528812
OID_FDDI_MAC_SMT_ADDRESS: UInt32 = 50528813
OID_FDDI_MAC_LONG_GRP_ADDRESS: UInt32 = 50528814
OID_FDDI_MAC_SHORT_GRP_ADDRESS: UInt32 = 50528815
OID_FDDI_MAC_T_REQ: UInt32 = 50528816
OID_FDDI_MAC_T_NEG: UInt32 = 50528817
OID_FDDI_MAC_T_MAX: UInt32 = 50528818
OID_FDDI_MAC_TVX_VALUE: UInt32 = 50528819
OID_FDDI_MAC_T_PRI0: UInt32 = 50528820
OID_FDDI_MAC_T_PRI1: UInt32 = 50528821
OID_FDDI_MAC_T_PRI2: UInt32 = 50528822
OID_FDDI_MAC_T_PRI3: UInt32 = 50528823
OID_FDDI_MAC_T_PRI4: UInt32 = 50528824
OID_FDDI_MAC_T_PRI5: UInt32 = 50528825
OID_FDDI_MAC_T_PRI6: UInt32 = 50528826
OID_FDDI_MAC_FRAME_CT: UInt32 = 50528827
OID_FDDI_MAC_COPIED_CT: UInt32 = 50528828
OID_FDDI_MAC_TRANSMIT_CT: UInt32 = 50528829
OID_FDDI_MAC_TOKEN_CT: UInt32 = 50528830
OID_FDDI_MAC_ERROR_CT: UInt32 = 50528831
OID_FDDI_MAC_LOST_CT: UInt32 = 50528832
OID_FDDI_MAC_TVX_EXPIRED_CT: UInt32 = 50528833
OID_FDDI_MAC_NOT_COPIED_CT: UInt32 = 50528834
OID_FDDI_MAC_LATE_CT: UInt32 = 50528835
OID_FDDI_MAC_RING_OP_CT: UInt32 = 50528836
OID_FDDI_MAC_FRAME_ERROR_THRESHOLD: UInt32 = 50528837
OID_FDDI_MAC_FRAME_ERROR_RATIO: UInt32 = 50528838
OID_FDDI_MAC_NOT_COPIED_THRESHOLD: UInt32 = 50528839
OID_FDDI_MAC_NOT_COPIED_RATIO: UInt32 = 50528840
OID_FDDI_MAC_RMT_STATE: UInt32 = 50528841
OID_FDDI_MAC_DA_FLAG: UInt32 = 50528842
OID_FDDI_MAC_UNDA_FLAG: UInt32 = 50528843
OID_FDDI_MAC_FRAME_ERROR_FLAG: UInt32 = 50528844
OID_FDDI_MAC_NOT_COPIED_FLAG: UInt32 = 50528845
OID_FDDI_MAC_MA_UNITDATA_AVAILABLE: UInt32 = 50528846
OID_FDDI_MAC_HARDWARE_PRESENT: UInt32 = 50528847
OID_FDDI_MAC_MA_UNITDATA_ENABLE: UInt32 = 50528848
OID_FDDI_PATH_INDEX: UInt32 = 50528849
OID_FDDI_PATH_RING_LATENCY: UInt32 = 50528850
OID_FDDI_PATH_TRACE_STATUS: UInt32 = 50528851
OID_FDDI_PATH_SBA_PAYLOAD: UInt32 = 50528852
OID_FDDI_PATH_SBA_OVERHEAD: UInt32 = 50528853
OID_FDDI_PATH_CONFIGURATION: UInt32 = 50528854
OID_FDDI_PATH_T_R_MODE: UInt32 = 50528855
OID_FDDI_PATH_SBA_AVAILABLE: UInt32 = 50528856
OID_FDDI_PATH_TVX_LOWER_BOUND: UInt32 = 50528857
OID_FDDI_PATH_T_MAX_LOWER_BOUND: UInt32 = 50528858
OID_FDDI_PATH_MAX_T_REQ: UInt32 = 50528859
OID_FDDI_PORT_MY_TYPE: UInt32 = 50528860
OID_FDDI_PORT_NEIGHBOR_TYPE: UInt32 = 50528861
OID_FDDI_PORT_CONNECTION_POLICIES: UInt32 = 50528862
OID_FDDI_PORT_MAC_INDICATED: UInt32 = 50528863
OID_FDDI_PORT_CURRENT_PATH: UInt32 = 50528864
OID_FDDI_PORT_REQUESTED_PATHS: UInt32 = 50528865
OID_FDDI_PORT_MAC_PLACEMENT: UInt32 = 50528866
OID_FDDI_PORT_AVAILABLE_PATHS: UInt32 = 50528867
OID_FDDI_PORT_MAC_LOOP_TIME: UInt32 = 50528868
OID_FDDI_PORT_PMD_CLASS: UInt32 = 50528869
OID_FDDI_PORT_CONNECTION_CAPABILITIES: UInt32 = 50528870
OID_FDDI_PORT_INDEX: UInt32 = 50528871
OID_FDDI_PORT_MAINT_LS: UInt32 = 50528872
OID_FDDI_PORT_BS_FLAG: UInt32 = 50528873
OID_FDDI_PORT_PC_LS: UInt32 = 50528874
OID_FDDI_PORT_EB_ERROR_CT: UInt32 = 50528875
OID_FDDI_PORT_LCT_FAIL_CT: UInt32 = 50528876
OID_FDDI_PORT_LER_ESTIMATE: UInt32 = 50528877
OID_FDDI_PORT_LEM_REJECT_CT: UInt32 = 50528878
OID_FDDI_PORT_LEM_CT: UInt32 = 50528879
OID_FDDI_PORT_LER_CUTOFF: UInt32 = 50528880
OID_FDDI_PORT_LER_ALARM: UInt32 = 50528881
OID_FDDI_PORT_CONNNECT_STATE: UInt32 = 50528882
OID_FDDI_PORT_PCM_STATE: UInt32 = 50528883
OID_FDDI_PORT_PC_WITHHOLD: UInt32 = 50528884
OID_FDDI_PORT_LER_FLAG: UInt32 = 50528885
OID_FDDI_PORT_HARDWARE_PRESENT: UInt32 = 50528886
OID_FDDI_SMT_STATION_ACTION: UInt32 = 50528887
OID_FDDI_PORT_ACTION: UInt32 = 50528888
OID_FDDI_IF_DESCR: UInt32 = 50528889
OID_FDDI_IF_TYPE: UInt32 = 50528890
OID_FDDI_IF_MTU: UInt32 = 50528891
OID_FDDI_IF_SPEED: UInt32 = 50528892
OID_FDDI_IF_PHYS_ADDRESS: UInt32 = 50528893
OID_FDDI_IF_ADMIN_STATUS: UInt32 = 50528894
OID_FDDI_IF_OPER_STATUS: UInt32 = 50528895
OID_FDDI_IF_LAST_CHANGE: UInt32 = 50528896
OID_FDDI_IF_IN_OCTETS: UInt32 = 50528897
OID_FDDI_IF_IN_UCAST_PKTS: UInt32 = 50528898
OID_FDDI_IF_IN_NUCAST_PKTS: UInt32 = 50528899
OID_FDDI_IF_IN_DISCARDS: UInt32 = 50528900
OID_FDDI_IF_IN_ERRORS: UInt32 = 50528901
OID_FDDI_IF_IN_UNKNOWN_PROTOS: UInt32 = 50528902
OID_FDDI_IF_OUT_OCTETS: UInt32 = 50528903
OID_FDDI_IF_OUT_UCAST_PKTS: UInt32 = 50528904
OID_FDDI_IF_OUT_NUCAST_PKTS: UInt32 = 50528905
OID_FDDI_IF_OUT_DISCARDS: UInt32 = 50528906
OID_FDDI_IF_OUT_ERRORS: UInt32 = 50528907
OID_FDDI_IF_OUT_QLEN: UInt32 = 50528908
OID_FDDI_IF_SPECIFIC: UInt32 = 50528909
OID_WAN_PERMANENT_ADDRESS: UInt32 = 67174657
OID_WAN_CURRENT_ADDRESS: UInt32 = 67174658
OID_WAN_QUALITY_OF_SERVICE: UInt32 = 67174659
OID_WAN_PROTOCOL_TYPE: UInt32 = 67174660
OID_WAN_MEDIUM_SUBTYPE: UInt32 = 67174661
OID_WAN_HEADER_FORMAT: UInt32 = 67174662
OID_WAN_GET_INFO: UInt32 = 67174663
OID_WAN_SET_LINK_INFO: UInt32 = 67174664
OID_WAN_GET_LINK_INFO: UInt32 = 67174665
OID_WAN_LINE_COUNT: UInt32 = 67174666
OID_WAN_PROTOCOL_CAPS: UInt32 = 67174667
OID_WAN_GET_BRIDGE_INFO: UInt32 = 67174922
OID_WAN_SET_BRIDGE_INFO: UInt32 = 67174923
OID_WAN_GET_COMP_INFO: UInt32 = 67174924
OID_WAN_SET_COMP_INFO: UInt32 = 67174925
OID_WAN_GET_STATS_INFO: UInt32 = 67174926
OID_WAN_CO_GET_INFO: UInt32 = 67174784
OID_WAN_CO_SET_LINK_INFO: UInt32 = 67174785
OID_WAN_CO_GET_LINK_INFO: UInt32 = 67174786
OID_WAN_CO_GET_COMP_INFO: UInt32 = 67175040
OID_WAN_CO_SET_COMP_INFO: UInt32 = 67175041
OID_WAN_CO_GET_STATS_INFO: UInt32 = 67175042
OID_LTALK_CURRENT_NODE_ID: UInt32 = 83951874
OID_LTALK_IN_BROADCASTS: UInt32 = 84017409
OID_LTALK_IN_LENGTH_ERRORS: UInt32 = 84017410
OID_LTALK_OUT_NO_HANDLERS: UInt32 = 84017665
OID_LTALK_COLLISIONS: UInt32 = 84017666
OID_LTALK_DEFERS: UInt32 = 84017667
OID_LTALK_NO_DATA_ERRORS: UInt32 = 84017668
OID_LTALK_RANDOM_CTS_ERRORS: UInt32 = 84017669
OID_LTALK_FCS_ERRORS: UInt32 = 84017670
OID_ARCNET_PERMANENT_ADDRESS: UInt32 = 100729089
OID_ARCNET_CURRENT_ADDRESS: UInt32 = 100729090
OID_ARCNET_RECONFIGURATIONS: UInt32 = 100794881
OID_TAPI_ACCEPT: UInt32 = 117637377
OID_TAPI_ANSWER: UInt32 = 117637378
OID_TAPI_CLOSE: UInt32 = 117637379
OID_TAPI_CLOSE_CALL: UInt32 = 117637380
OID_TAPI_CONDITIONAL_MEDIA_DETECTION: UInt32 = 117637381
OID_TAPI_CONFIG_DIALOG: UInt32 = 117637382
OID_TAPI_DEV_SPECIFIC: UInt32 = 117637383
OID_TAPI_DIAL: UInt32 = 117637384
OID_TAPI_DROP: UInt32 = 117637385
OID_TAPI_GET_ADDRESS_CAPS: UInt32 = 117637386
OID_TAPI_GET_ADDRESS_ID: UInt32 = 117637387
OID_TAPI_GET_ADDRESS_STATUS: UInt32 = 117637388
OID_TAPI_GET_CALL_ADDRESS_ID: UInt32 = 117637389
OID_TAPI_GET_CALL_INFO: UInt32 = 117637390
OID_TAPI_GET_CALL_STATUS: UInt32 = 117637391
OID_TAPI_GET_DEV_CAPS: UInt32 = 117637392
OID_TAPI_GET_DEV_CONFIG: UInt32 = 117637393
OID_TAPI_GET_EXTENSION_ID: UInt32 = 117637394
OID_TAPI_GET_ID: UInt32 = 117637395
OID_TAPI_GET_LINE_DEV_STATUS: UInt32 = 117637396
OID_TAPI_MAKE_CALL: UInt32 = 117637397
OID_TAPI_NEGOTIATE_EXT_VERSION: UInt32 = 117637398
OID_TAPI_OPEN: UInt32 = 117637399
OID_TAPI_PROVIDER_INITIALIZE: UInt32 = 117637400
OID_TAPI_PROVIDER_SHUTDOWN: UInt32 = 117637401
OID_TAPI_SECURE_CALL: UInt32 = 117637402
OID_TAPI_SELECT_EXT_VERSION: UInt32 = 117637403
OID_TAPI_SEND_USER_USER_INFO: UInt32 = 117637404
OID_TAPI_SET_APP_SPECIFIC: UInt32 = 117637405
OID_TAPI_SET_CALL_PARAMS: UInt32 = 117637406
OID_TAPI_SET_DEFAULT_MEDIA_DETECTION: UInt32 = 117637407
OID_TAPI_SET_DEV_CONFIG: UInt32 = 117637408
OID_TAPI_SET_MEDIA_MODE: UInt32 = 117637409
OID_TAPI_SET_STATUS_MESSAGES: UInt32 = 117637410
OID_TAPI_GATHER_DIGITS: UInt32 = 117637411
OID_TAPI_MONITOR_DIGITS: UInt32 = 117637412
OID_ATM_SUPPORTED_VC_RATES: UInt32 = 134283521
OID_ATM_SUPPORTED_SERVICE_CATEGORY: UInt32 = 134283522
OID_ATM_SUPPORTED_AAL_TYPES: UInt32 = 134283523
OID_ATM_HW_CURRENT_ADDRESS: UInt32 = 134283524
OID_ATM_MAX_ACTIVE_VCS: UInt32 = 134283525
OID_ATM_MAX_ACTIVE_VCI_BITS: UInt32 = 134283526
OID_ATM_MAX_ACTIVE_VPI_BITS: UInt32 = 134283527
OID_ATM_MAX_AAL0_PACKET_SIZE: UInt32 = 134283528
OID_ATM_MAX_AAL1_PACKET_SIZE: UInt32 = 134283529
OID_ATM_MAX_AAL34_PACKET_SIZE: UInt32 = 134283530
OID_ATM_MAX_AAL5_PACKET_SIZE: UInt32 = 134283531
OID_ATM_SIGNALING_VPIVCI: UInt32 = 134283777
OID_ATM_ASSIGNED_VPI: UInt32 = 134283778
OID_ATM_ACQUIRE_ACCESS_NET_RESOURCES: UInt32 = 134283779
OID_ATM_RELEASE_ACCESS_NET_RESOURCES: UInt32 = 134283780
OID_ATM_ILMI_VPIVCI: UInt32 = 134283781
OID_ATM_DIGITAL_BROADCAST_VPIVCI: UInt32 = 134283782
OID_ATM_GET_NEAREST_FLOW: UInt32 = 134283783
OID_ATM_ALIGNMENT_REQUIRED: UInt32 = 134283784
OID_ATM_LECS_ADDRESS: UInt32 = 134283785
OID_ATM_SERVICE_ADDRESS: UInt32 = 134283786
OID_ATM_CALL_PROCEEDING: UInt32 = 134283787
OID_ATM_CALL_ALERTING: UInt32 = 134283788
OID_ATM_PARTY_ALERTING: UInt32 = 134283789
OID_ATM_CALL_NOTIFY: UInt32 = 134283790
OID_ATM_MY_IP_NM_ADDRESS: UInt32 = 134283791
OID_ATM_RCV_CELLS_OK: UInt32 = 134349057
OID_ATM_XMIT_CELLS_OK: UInt32 = 134349058
OID_ATM_RCV_CELLS_DROPPED: UInt32 = 134349059
OID_ATM_RCV_INVALID_VPI_VCI: UInt32 = 134349313
OID_ATM_CELLS_HEC_ERROR: UInt32 = 134349314
OID_ATM_RCV_REASSEMBLY_ERROR: UInt32 = 134349315
OID_802_11_BSSID: UInt32 = 218169601
OID_802_11_SSID: UInt32 = 218169602
OID_802_11_NETWORK_TYPES_SUPPORTED: UInt32 = 218169859
OID_802_11_NETWORK_TYPE_IN_USE: UInt32 = 218169860
OID_802_11_TX_POWER_LEVEL: UInt32 = 218169861
OID_802_11_RSSI: UInt32 = 218169862
OID_802_11_RSSI_TRIGGER: UInt32 = 218169863
OID_802_11_INFRASTRUCTURE_MODE: UInt32 = 218169608
OID_802_11_FRAGMENTATION_THRESHOLD: UInt32 = 218169865
OID_802_11_RTS_THRESHOLD: UInt32 = 218169866
OID_802_11_NUMBER_OF_ANTENNAS: UInt32 = 218169867
OID_802_11_RX_ANTENNA_SELECTED: UInt32 = 218169868
OID_802_11_TX_ANTENNA_SELECTED: UInt32 = 218169869
OID_802_11_SUPPORTED_RATES: UInt32 = 218169870
OID_802_11_DESIRED_RATES: UInt32 = 218169872
OID_802_11_CONFIGURATION: UInt32 = 218169873
OID_802_11_STATISTICS: UInt32 = 218235410
OID_802_11_ADD_WEP: UInt32 = 218169619
OID_802_11_REMOVE_WEP: UInt32 = 218169620
OID_802_11_DISASSOCIATE: UInt32 = 218169621
OID_802_11_POWER_MODE: UInt32 = 218169878
OID_802_11_BSSID_LIST: UInt32 = 218169879
OID_802_11_AUTHENTICATION_MODE: UInt32 = 218169624
OID_802_11_PRIVACY_FILTER: UInt32 = 218169625
OID_802_11_BSSID_LIST_SCAN: UInt32 = 218169626
OID_802_11_WEP_STATUS: UInt32 = 218169627
OID_802_11_ENCRYPTION_STATUS: UInt32 = 218169627
OID_802_11_RELOAD_DEFAULTS: UInt32 = 218169628
OID_802_11_ADD_KEY: UInt32 = 218169629
OID_802_11_REMOVE_KEY: UInt32 = 218169630
OID_802_11_ASSOCIATION_INFORMATION: UInt32 = 218169631
OID_802_11_TEST: UInt32 = 218169632
OID_802_11_MEDIA_STREAM_MODE: UInt32 = 218169633
OID_802_11_CAPABILITY: UInt32 = 218169634
OID_802_11_PMKID: UInt32 = 218169635
OID_802_11_NON_BCAST_SSID_LIST: UInt32 = 218169636
OID_802_11_RADIO_STATUS: UInt32 = 218169637
NDIS_ETH_TYPE_IPV4: UInt32 = 2048
NDIS_ETH_TYPE_ARP: UInt32 = 2054
NDIS_ETH_TYPE_IPV6: UInt32 = 34525
NDIS_ETH_TYPE_802_1X: UInt32 = 34958
NDIS_ETH_TYPE_802_1Q: UInt32 = 33024
NDIS_ETH_TYPE_SLOW_PROTOCOL: UInt32 = 34825
NDIS_802_11_LENGTH_SSID: UInt32 = 32
NDIS_802_11_LENGTH_RATES: UInt32 = 8
NDIS_802_11_LENGTH_RATES_EX: UInt32 = 16
NDIS_802_11_AUTH_REQUEST_AUTH_FIELDS: UInt32 = 15
NDIS_802_11_AUTH_REQUEST_REAUTH: UInt32 = 1
NDIS_802_11_AUTH_REQUEST_KEYUPDATE: UInt32 = 2
NDIS_802_11_AUTH_REQUEST_PAIRWISE_ERROR: UInt32 = 6
NDIS_802_11_AUTH_REQUEST_GROUP_ERROR: UInt32 = 14
NDIS_802_11_PMKID_CANDIDATE_PREAUTH_ENABLED: UInt32 = 1
NDIS_802_11_AI_REQFI_CAPABILITIES: UInt32 = 1
NDIS_802_11_AI_REQFI_LISTENINTERVAL: UInt32 = 2
NDIS_802_11_AI_REQFI_CURRENTAPADDRESS: UInt32 = 4
NDIS_802_11_AI_RESFI_CAPABILITIES: UInt32 = 1
NDIS_802_11_AI_RESFI_STATUSCODE: UInt32 = 2
NDIS_802_11_AI_RESFI_ASSOCIATIONID: UInt32 = 4
OID_IRDA_RECEIVING: UInt32 = 167837952
OID_IRDA_TURNAROUND_TIME: UInt32 = 167837953
OID_IRDA_SUPPORTED_SPEEDS: UInt32 = 167837954
OID_IRDA_LINK_SPEED: UInt32 = 167837955
OID_IRDA_MEDIA_BUSY: UInt32 = 167837956
OID_IRDA_EXTRA_RCV_BOFS: UInt32 = 167838208
OID_IRDA_RATE_SNIFF: UInt32 = 167838209
OID_IRDA_UNICAST_LIST: UInt32 = 167838210
OID_IRDA_MAX_UNICAST_LIST_SIZE: UInt32 = 167838211
OID_IRDA_MAX_RECEIVE_WINDOW_SIZE: UInt32 = 167838212
OID_IRDA_MAX_SEND_WINDOW_SIZE: UInt32 = 167838213
OID_IRDA_RESERVED1: UInt32 = 167838218
OID_IRDA_RESERVED2: UInt32 = 167838223
OID_1394_LOCAL_NODE_INFO: UInt32 = 201392385
OID_1394_VC_INFO: UInt32 = 201392386
OID_CO_ADD_PVC: UInt32 = 4261412865
OID_CO_DELETE_PVC: UInt32 = 4261412866
OID_CO_GET_CALL_INFORMATION: UInt32 = 4261412867
OID_CO_ADD_ADDRESS: UInt32 = 4261412868
OID_CO_DELETE_ADDRESS: UInt32 = 4261412869
OID_CO_GET_ADDRESSES: UInt32 = 4261412870
OID_CO_ADDRESS_CHANGE: UInt32 = 4261412871
OID_CO_SIGNALING_ENABLED: UInt32 = 4261412872
OID_CO_SIGNALING_DISABLED: UInt32 = 4261412873
OID_CO_AF_CLOSE: UInt32 = 4261412874
OID_CO_TAPI_CM_CAPS: UInt32 = 4261416961
OID_CO_TAPI_LINE_CAPS: UInt32 = 4261416962
OID_CO_TAPI_ADDRESS_CAPS: UInt32 = 4261416963
OID_CO_TAPI_TRANSLATE_TAPI_CALLPARAMS: UInt32 = 4261416964
OID_CO_TAPI_TRANSLATE_NDIS_CALLPARAMS: UInt32 = 4261416965
OID_CO_TAPI_TRANSLATE_TAPI_SAP: UInt32 = 4261416966
OID_CO_TAPI_GET_CALL_DIAGNOSTICS: UInt32 = 4261416967
OID_CO_TAPI_REPORT_DIGITS: UInt32 = 4261416968
OID_CO_TAPI_DONT_REPORT_DIGITS: UInt32 = 4261416969
OID_PNP_CAPABILITIES: UInt32 = 4244701440
OID_PNP_SET_POWER: UInt32 = 4244701441
OID_PNP_QUERY_POWER: UInt32 = 4244701442
OID_PNP_ADD_WAKE_UP_PATTERN: UInt32 = 4244701443
OID_PNP_REMOVE_WAKE_UP_PATTERN: UInt32 = 4244701444
OID_PNP_WAKE_UP_PATTERN_LIST: UInt32 = 4244701445
OID_PNP_ENABLE_WAKE_UP: UInt32 = 4244701446
OID_PNP_WAKE_UP_OK: UInt32 = 4244767232
OID_PNP_WAKE_UP_ERROR: UInt32 = 4244767233
OID_PM_CURRENT_CAPABILITIES: UInt32 = 4244701447
OID_PM_HARDWARE_CAPABILITIES: UInt32 = 4244701448
OID_PM_PARAMETERS: UInt32 = 4244701449
OID_PM_ADD_WOL_PATTERN: UInt32 = 4244701450
OID_PM_REMOVE_WOL_PATTERN: UInt32 = 4244701451
OID_PM_WOL_PATTERN_LIST: UInt32 = 4244701452
OID_PM_ADD_PROTOCOL_OFFLOAD: UInt32 = 4244701453
OID_PM_GET_PROTOCOL_OFFLOAD: UInt32 = 4244701454
OID_PM_REMOVE_PROTOCOL_OFFLOAD: UInt32 = 4244701455
OID_PM_PROTOCOL_OFFLOAD_LIST: UInt32 = 4244701456
OID_PM_RESERVED_1: UInt32 = 4244701457
OID_RECEIVE_FILTER_HARDWARE_CAPABILITIES: UInt32 = 66081
OID_RECEIVE_FILTER_GLOBAL_PARAMETERS: UInt32 = 66082
OID_RECEIVE_FILTER_ALLOCATE_QUEUE: UInt32 = 66083
OID_RECEIVE_FILTER_FREE_QUEUE: UInt32 = 66084
OID_RECEIVE_FILTER_ENUM_QUEUES: UInt32 = 66085
OID_RECEIVE_FILTER_QUEUE_PARAMETERS: UInt32 = 66086
OID_RECEIVE_FILTER_SET_FILTER: UInt32 = 66087
OID_RECEIVE_FILTER_CLEAR_FILTER: UInt32 = 66088
OID_RECEIVE_FILTER_ENUM_FILTERS: UInt32 = 66089
OID_RECEIVE_FILTER_PARAMETERS: UInt32 = 66090
OID_RECEIVE_FILTER_QUEUE_ALLOCATION_COMPLETE: UInt32 = 66091
OID_RECEIVE_FILTER_CURRENT_CAPABILITIES: UInt32 = 66093
OID_NIC_SWITCH_HARDWARE_CAPABILITIES: UInt32 = 66094
OID_NIC_SWITCH_CURRENT_CAPABILITIES: UInt32 = 66095
OID_RECEIVE_FILTER_MOVE_FILTER: UInt32 = 66096
OID_VLAN_RESERVED1: UInt32 = 66097
OID_VLAN_RESERVED2: UInt32 = 66098
OID_VLAN_RESERVED3: UInt32 = 66099
OID_VLAN_RESERVED4: UInt32 = 66100
OID_PACKET_COALESCING_FILTER_MATCH_COUNT: UInt32 = 66101
OID_NIC_SWITCH_CREATE_SWITCH: UInt32 = 66103
OID_NIC_SWITCH_PARAMETERS: UInt32 = 66104
OID_NIC_SWITCH_DELETE_SWITCH: UInt32 = 66105
OID_NIC_SWITCH_ENUM_SWITCHES: UInt32 = 66112
OID_NIC_SWITCH_CREATE_VPORT: UInt32 = 66113
OID_NIC_SWITCH_VPORT_PARAMETERS: UInt32 = 66114
OID_NIC_SWITCH_ENUM_VPORTS: UInt32 = 66115
OID_NIC_SWITCH_DELETE_VPORT: UInt32 = 66116
OID_NIC_SWITCH_ALLOCATE_VF: UInt32 = 66117
OID_NIC_SWITCH_FREE_VF: UInt32 = 66118
OID_NIC_SWITCH_VF_PARAMETERS: UInt32 = 66119
OID_NIC_SWITCH_ENUM_VFS: UInt32 = 66120
OID_SRIOV_HARDWARE_CAPABILITIES: UInt32 = 66121
OID_SRIOV_CURRENT_CAPABILITIES: UInt32 = 66128
OID_SRIOV_READ_VF_CONFIG_SPACE: UInt32 = 66129
OID_SRIOV_WRITE_VF_CONFIG_SPACE: UInt32 = 66130
OID_SRIOV_READ_VF_CONFIG_BLOCK: UInt32 = 66131
OID_SRIOV_WRITE_VF_CONFIG_BLOCK: UInt32 = 66132
OID_SRIOV_RESET_VF: UInt32 = 66133
OID_SRIOV_SET_VF_POWER_STATE: UInt32 = 66134
OID_SRIOV_VF_VENDOR_DEVICE_ID: UInt32 = 66135
OID_SRIOV_PROBED_BARS: UInt32 = 66136
OID_SRIOV_BAR_RESOURCES: UInt32 = 66137
OID_SRIOV_PF_LUID: UInt32 = 66144
OID_SRIOV_CONFIG_STATE: UInt32 = 66145
OID_SRIOV_VF_SERIAL_NUMBER: UInt32 = 66146
OID_SRIOV_OVERLYING_ADAPTER_INFO: UInt32 = 66152
OID_SRIOV_VF_INVALIDATE_CONFIG_BLOCK: UInt32 = 66153
OID_SWITCH_PROPERTY_ADD: UInt32 = 66147
OID_SWITCH_PROPERTY_UPDATE: UInt32 = 66148
OID_SWITCH_PROPERTY_DELETE: UInt32 = 66149
OID_SWITCH_PROPERTY_ENUM: UInt32 = 66150
OID_SWITCH_FEATURE_STATUS_QUERY: UInt32 = 66151
OID_SWITCH_NIC_REQUEST: UInt32 = 66160
OID_SWITCH_PORT_PROPERTY_ADD: UInt32 = 66161
OID_SWITCH_PORT_PROPERTY_UPDATE: UInt32 = 66162
OID_SWITCH_PORT_PROPERTY_DELETE: UInt32 = 66163
OID_SWITCH_PORT_PROPERTY_ENUM: UInt32 = 66164
OID_SWITCH_PARAMETERS: UInt32 = 66165
OID_SWITCH_PORT_ARRAY: UInt32 = 66166
OID_SWITCH_NIC_ARRAY: UInt32 = 66167
OID_SWITCH_PORT_CREATE: UInt32 = 66168
OID_SWITCH_PORT_DELETE: UInt32 = 66169
OID_SWITCH_NIC_CREATE: UInt32 = 66170
OID_SWITCH_NIC_CONNECT: UInt32 = 66171
OID_SWITCH_NIC_DISCONNECT: UInt32 = 66172
OID_SWITCH_NIC_DELETE: UInt32 = 66173
OID_SWITCH_PORT_FEATURE_STATUS_QUERY: UInt32 = 66174
OID_SWITCH_PORT_TEARDOWN: UInt32 = 66175
OID_SWITCH_NIC_SAVE: UInt32 = 66192
OID_SWITCH_NIC_SAVE_COMPLETE: UInt32 = 66193
OID_SWITCH_NIC_RESTORE: UInt32 = 66194
OID_SWITCH_NIC_RESTORE_COMPLETE: UInt32 = 66195
OID_SWITCH_NIC_UPDATED: UInt32 = 66196
OID_SWITCH_PORT_UPDATED: UInt32 = 66197
OID_SWITCH_NIC_DIRECT_REQUEST: UInt32 = 66198
OID_SWITCH_NIC_SUSPEND: UInt32 = 66199
OID_SWITCH_NIC_RESUME: UInt32 = 66200
OID_SWITCH_NIC_SUSPENDED_LM_SOURCE_STARTED: UInt32 = 66201
OID_SWITCH_NIC_SUSPENDED_LM_SOURCE_FINISHED: UInt32 = 66202
OID_GEN_RSS_SET_INDIRECTION_TABLE_ENTRIES: UInt32 = 66240
OID_GEN_ISOLATION_PARAMETERS: UInt32 = 66304
OID_GFT_HARDWARE_CAPABILITIES: UInt32 = 66561
OID_GFT_CURRENT_CAPABILITIES: UInt32 = 66562
OID_GFT_GLOBAL_PARAMETERS: UInt32 = 66563
OID_GFT_CREATE_TABLE: UInt32 = 66564
OID_GFT_DELETE_TABLE: UInt32 = 66565
OID_GFT_ENUM_TABLES: UInt32 = 66566
OID_GFT_ALLOCATE_COUNTERS: UInt32 = 66567
OID_GFT_FREE_COUNTERS: UInt32 = 66568
OID_GFT_ENUM_COUNTERS: UInt32 = 66569
OID_GFT_COUNTER_VALUES: UInt32 = 66570
OID_GFT_STATISTICS: UInt32 = 66571
OID_GFT_ADD_FLOW_ENTRIES: UInt32 = 66572
OID_GFT_DELETE_FLOW_ENTRIES: UInt32 = 66573
OID_GFT_ENUM_FLOW_ENTRIES: UInt32 = 66574
OID_GFT_ACTIVATE_FLOW_ENTRIES: UInt32 = 66575
OID_GFT_DEACTIVATE_FLOW_ENTRIES: UInt32 = 66576
OID_GFT_FLOW_ENTRY_PARAMETERS: UInt32 = 66577
OID_GFT_EXACT_MATCH_PROFILE: UInt32 = 66578
OID_GFT_HEADER_TRANSPOSITION_PROFILE: UInt32 = 66579
OID_GFT_WILDCARD_MATCH_PROFILE: UInt32 = 66580
OID_GFT_ENUM_PROFILES: UInt32 = 66581
OID_GFT_DELETE_PROFILE: UInt32 = 66582
OID_GFT_VPORT_PARAMETERS: UInt32 = 66583
OID_GFT_CREATE_LOGICAL_VPORT: UInt32 = 66584
OID_GFT_DELETE_LOGICAL_VPORT: UInt32 = 66585
OID_GFT_ENUM_LOGICAL_VPORTS: UInt32 = 66586
OID_QOS_OFFLOAD_HARDWARE_CAPABILITIES: UInt32 = 67073
OID_QOS_OFFLOAD_CURRENT_CAPABILITIES: UInt32 = 67074
OID_QOS_OFFLOAD_CREATE_SQ: UInt32 = 67075
OID_QOS_OFFLOAD_DELETE_SQ: UInt32 = 67076
OID_QOS_OFFLOAD_UPDATE_SQ: UInt32 = 67077
OID_QOS_OFFLOAD_ENUM_SQS: UInt32 = 67078
OID_QOS_OFFLOAD_SQ_STATS: UInt32 = 67079
OID_PD_OPEN_PROVIDER: UInt32 = 66817
OID_PD_CLOSE_PROVIDER: UInt32 = 66818
OID_PD_QUERY_CURRENT_CONFIG: UInt32 = 66819
NDIS_PNP_WAKE_UP_MAGIC_PACKET: UInt32 = 1
NDIS_PNP_WAKE_UP_PATTERN_MATCH: UInt32 = 2
NDIS_PNP_WAKE_UP_LINK_CHANGE: UInt32 = 4
OID_TCP_TASK_OFFLOAD: UInt32 = 4227924481
OID_TCP_TASK_IPSEC_ADD_SA: UInt32 = 4227924482
OID_TCP_TASK_IPSEC_DELETE_SA: UInt32 = 4227924483
OID_TCP_SAN_SUPPORT: UInt32 = 4227924484
OID_TCP_TASK_IPSEC_ADD_UDPESP_SA: UInt32 = 4227924485
OID_TCP_TASK_IPSEC_DELETE_UDPESP_SA: UInt32 = 4227924486
OID_TCP4_OFFLOAD_STATS: UInt32 = 4227924487
OID_TCP6_OFFLOAD_STATS: UInt32 = 4227924488
OID_IP4_OFFLOAD_STATS: UInt32 = 4227924489
OID_IP6_OFFLOAD_STATS: UInt32 = 4227924490
OID_TCP_OFFLOAD_CURRENT_CONFIG: UInt32 = 4227924491
OID_TCP_OFFLOAD_PARAMETERS: UInt32 = 4227924492
OID_TCP_OFFLOAD_HARDWARE_CAPABILITIES: UInt32 = 4227924493
OID_TCP_CONNECTION_OFFLOAD_CURRENT_CONFIG: UInt32 = 4227924494
OID_TCP_CONNECTION_OFFLOAD_HARDWARE_CAPABILITIES: UInt32 = 4227924495
OID_OFFLOAD_ENCAPSULATION: UInt32 = 16843018
OID_TCP_TASK_IPSEC_OFFLOAD_V2_ADD_SA: UInt32 = 4228055554
OID_TCP_TASK_IPSEC_OFFLOAD_V2_DELETE_SA: UInt32 = 4228055555
OID_TCP_TASK_IPSEC_OFFLOAD_V2_UPDATE_SA: UInt32 = 4228055556
OID_TCP_TASK_IPSEC_OFFLOAD_V2_ADD_SA_EX: UInt32 = 4228055557
OID_FFP_SUPPORT: UInt32 = 4227924496
OID_FFP_FLUSH: UInt32 = 4227924497
OID_FFP_CONTROL: UInt32 = 4227924498
OID_FFP_PARAMS: UInt32 = 4227924499
OID_FFP_DATA: UInt32 = 4227924500
OID_FFP_DRIVER_STATS: UInt32 = 4227990032
OID_FFP_ADAPTER_STATS: UInt32 = 4227990033
OID_TCP_CONNECTION_OFFLOAD_PARAMETERS: UInt32 = 4228055553
OID_TUNNEL_INTERFACE_SET_OID: UInt32 = 251724038
OID_TUNNEL_INTERFACE_RELEASE_OID: UInt32 = 251724039
OID_QOS_RESERVED1: UInt32 = 4211147008
OID_QOS_RESERVED2: UInt32 = 4211147009
OID_QOS_RESERVED3: UInt32 = 4211147010
OID_QOS_RESERVED4: UInt32 = 4211147011
OID_QOS_RESERVED5: UInt32 = 4211147012
OID_QOS_RESERVED6: UInt32 = 4211147013
OID_QOS_RESERVED7: UInt32 = 4211147014
OID_QOS_RESERVED8: UInt32 = 4211147015
OID_QOS_RESERVED9: UInt32 = 4211147016
OID_QOS_RESERVED10: UInt32 = 4211147017
OID_QOS_RESERVED11: UInt32 = 4211147018
OID_QOS_RESERVED12: UInt32 = 4211147019
OID_QOS_RESERVED13: UInt32 = 4211147020
OID_QOS_RESERVED14: UInt32 = 4211147021
OID_QOS_RESERVED15: UInt32 = 4211147022
OID_QOS_RESERVED16: UInt32 = 4211147023
OID_QOS_RESERVED17: UInt32 = 4211147024
OID_QOS_RESERVED18: UInt32 = 4211147025
OID_QOS_RESERVED19: UInt32 = 4211147026
OID_QOS_RESERVED20: UInt32 = 4211147027
OID_XBOX_ACC_RESERVED0: UInt32 = 4194304000
OFFLOAD_MAX_SAS: UInt32 = 3
OFFLOAD_INBOUND_SA: UInt32 = 1
OFFLOAD_OUTBOUND_SA: UInt32 = 2
NDIS_PROTOCOL_ID_DEFAULT: UInt32 = 0
NDIS_PROTOCOL_ID_TCP_IP: UInt32 = 2
NDIS_PROTOCOL_ID_IP6: UInt32 = 3
NDIS_PROTOCOL_ID_IPX: UInt32 = 6
NDIS_PROTOCOL_ID_NBF: UInt32 = 7
NDIS_PROTOCOL_ID_MAX: UInt32 = 15
NDIS_PROTOCOL_ID_MASK: UInt32 = 15
READABLE_LOCAL_CLOCK: UInt32 = 1
CLOCK_NETWORK_DERIVED: UInt32 = 2
CLOCK_PRECISION: UInt32 = 4
RECEIVE_TIME_INDICATION_CAPABLE: UInt32 = 8
TIMED_SEND_CAPABLE: UInt32 = 16
TIME_STAMP_CAPABLE: UInt32 = 32
NDIS_DEVICE_WAKE_UP_ENABLE: UInt32 = 1
NDIS_DEVICE_WAKE_ON_PATTERN_MATCH_ENABLE: UInt32 = 2
NDIS_DEVICE_WAKE_ON_MAGIC_PACKET_ENABLE: UInt32 = 4
WAN_PROTOCOL_KEEPS_STATS: UInt32 = 1
fNDIS_GUID_TO_OID: UInt32 = 1
fNDIS_GUID_TO_STATUS: UInt32 = 2
fNDIS_GUID_ANSI_STRING: UInt32 = 4
fNDIS_GUID_UNICODE_STRING: UInt32 = 8
fNDIS_GUID_ARRAY: UInt32 = 16
fNDIS_GUID_ALLOW_READ: UInt32 = 32
fNDIS_GUID_ALLOW_WRITE: UInt32 = 64
fNDIS_GUID_METHOD: UInt32 = 128
fNDIS_GUID_NDIS_RESERVED: UInt32 = 256
fNDIS_GUID_SUPPORT_COMMON_HEADER: UInt32 = 512
NDIS_PACKET_TYPE_DIRECTED: UInt32 = 1
NDIS_PACKET_TYPE_MULTICAST: UInt32 = 2
NDIS_PACKET_TYPE_ALL_MULTICAST: UInt32 = 4
NDIS_PACKET_TYPE_BROADCAST: UInt32 = 8
NDIS_PACKET_TYPE_SOURCE_ROUTING: UInt32 = 16
NDIS_PACKET_TYPE_PROMISCUOUS: UInt32 = 32
NDIS_PACKET_TYPE_SMT: UInt32 = 64
NDIS_PACKET_TYPE_ALL_LOCAL: UInt32 = 128
NDIS_PACKET_TYPE_GROUP: UInt32 = 4096
NDIS_PACKET_TYPE_ALL_FUNCTIONAL: UInt32 = 8192
NDIS_PACKET_TYPE_FUNCTIONAL: UInt32 = 16384
NDIS_PACKET_TYPE_MAC_FRAME: UInt32 = 32768
NDIS_PACKET_TYPE_NO_LOCAL: UInt32 = 65536
NDIS_RING_SIGNAL_LOSS: UInt32 = 32768
NDIS_RING_HARD_ERROR: UInt32 = 16384
NDIS_RING_SOFT_ERROR: UInt32 = 8192
NDIS_RING_TRANSMIT_BEACON: UInt32 = 4096
NDIS_RING_LOBE_WIRE_FAULT: UInt32 = 2048
NDIS_RING_AUTO_REMOVAL_ERROR: UInt32 = 1024
NDIS_RING_REMOVE_RECEIVED: UInt32 = 512
NDIS_RING_COUNTER_OVERFLOW: UInt32 = 256
NDIS_RING_SINGLE_STATION: UInt32 = 128
NDIS_RING_RING_RECOVERY: UInt32 = 64
NDIS_PROT_OPTION_ESTIMATED_LENGTH: UInt32 = 1
NDIS_PROT_OPTION_NO_LOOPBACK: UInt32 = 2
NDIS_PROT_OPTION_NO_RSVD_ON_RCVPKT: UInt32 = 4
NDIS_PROT_OPTION_SEND_RESTRICTED: UInt32 = 8
NDIS_MAC_OPTION_COPY_LOOKAHEAD_DATA: UInt32 = 1
NDIS_MAC_OPTION_RECEIVE_SERIALIZED: UInt32 = 2
NDIS_MAC_OPTION_TRANSFERS_NOT_PEND: UInt32 = 4
NDIS_MAC_OPTION_NO_LOOPBACK: UInt32 = 8
NDIS_MAC_OPTION_FULL_DUPLEX: UInt32 = 16
NDIS_MAC_OPTION_EOTX_INDICATION: UInt32 = 32
NDIS_MAC_OPTION_8021P_PRIORITY: UInt32 = 64
NDIS_MAC_OPTION_SUPPORTS_MAC_ADDRESS_OVERWRITE: UInt32 = 128
NDIS_MAC_OPTION_RECEIVE_AT_DPC: UInt32 = 256
NDIS_MAC_OPTION_8021Q_VLAN: UInt32 = 512
NDIS_MAC_OPTION_RESERVED: UInt32 = 2147483648
NDIS_MEDIA_CAP_TRANSMIT: UInt32 = 1
NDIS_MEDIA_CAP_RECEIVE: UInt32 = 2
NDIS_CO_MAC_OPTION_DYNAMIC_LINK_SPEED: UInt32 = 1
NDIS_LINK_STATE_XMIT_LINK_SPEED_AUTO_NEGOTIATED: UInt32 = 1
NDIS_LINK_STATE_RCV_LINK_SPEED_AUTO_NEGOTIATED: UInt32 = 2
NDIS_LINK_STATE_DUPLEX_AUTO_NEGOTIATED: UInt32 = 4
NDIS_LINK_STATE_PAUSE_FUNCTIONS_AUTO_NEGOTIATED: UInt32 = 8
NDIS_LINK_STATE_REVISION_1: UInt32 = 1
NDIS_LINK_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_OPER_STATE_REVISION_1: UInt32 = 1
MAXIMUM_IP_OPER_STATUS_ADDRESS_FAMILIES_SUPPORTED: UInt32 = 32
NDIS_IP_OPER_STATUS_INFO_REVISION_1: UInt32 = 1
NDIS_IP_OPER_STATE_REVISION_1: UInt32 = 1
NDIS_OFFLOAD_PARAMETERS_NO_CHANGE: UInt32 = 0
NDIS_OFFLOAD_PARAMETERS_TX_RX_DISABLED: UInt32 = 1
NDIS_OFFLOAD_PARAMETERS_TX_ENABLED_RX_DISABLED: UInt32 = 2
NDIS_OFFLOAD_PARAMETERS_RX_ENABLED_TX_DISABLED: UInt32 = 3
NDIS_OFFLOAD_PARAMETERS_TX_RX_ENABLED: UInt32 = 4
NDIS_OFFLOAD_PARAMETERS_LSOV1_DISABLED: UInt32 = 1
NDIS_OFFLOAD_PARAMETERS_LSOV1_ENABLED: UInt32 = 2
NDIS_OFFLOAD_PARAMETERS_IPSECV1_DISABLED: UInt32 = 1
NDIS_OFFLOAD_PARAMETERS_IPSECV1_AH_ENABLED: UInt32 = 2
NDIS_OFFLOAD_PARAMETERS_IPSECV1_ESP_ENABLED: UInt32 = 3
NDIS_OFFLOAD_PARAMETERS_IPSECV1_AH_AND_ESP_ENABLED: UInt32 = 4
NDIS_OFFLOAD_PARAMETERS_LSOV2_DISABLED: UInt32 = 1
NDIS_OFFLOAD_PARAMETERS_LSOV2_ENABLED: UInt32 = 2
NDIS_OFFLOAD_PARAMETERS_IPSECV2_DISABLED: UInt32 = 1
NDIS_OFFLOAD_PARAMETERS_IPSECV2_AH_ENABLED: UInt32 = 2
NDIS_OFFLOAD_PARAMETERS_IPSECV2_ESP_ENABLED: UInt32 = 3
NDIS_OFFLOAD_PARAMETERS_IPSECV2_AH_AND_ESP_ENABLED: UInt32 = 4
NDIS_OFFLOAD_PARAMETERS_RSC_DISABLED: UInt32 = 1
NDIS_OFFLOAD_PARAMETERS_RSC_ENABLED: UInt32 = 2
NDIS_ENCAPSULATION_TYPE_GRE_MAC: UInt32 = 1
NDIS_ENCAPSULATION_TYPE_VXLAN: UInt32 = 2
NDIS_OFFLOAD_PARAMETERS_CONNECTION_OFFLOAD_DISABLED: UInt32 = 1
NDIS_OFFLOAD_PARAMETERS_CONNECTION_OFFLOAD_ENABLED: UInt32 = 2
NDIS_OFFLOAD_PARAMETERS_USO_DISABLED: UInt32 = 1
NDIS_OFFLOAD_PARAMETERS_USO_ENABLED: UInt32 = 2
NDIS_OFFLOAD_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_OFFLOAD_PARAMETERS_REVISION_2: UInt32 = 2
NDIS_OFFLOAD_PARAMETERS_REVISION_3: UInt32 = 3
NDIS_OFFLOAD_PARAMETERS_REVISION_4: UInt32 = 4
NDIS_OFFLOAD_PARAMETERS_REVISION_5: UInt32 = 5
NDIS_OFFLOAD_PARAMETERS_SKIP_REGISTRY_UPDATE: UInt32 = 1
IPSEC_OFFLOAD_V2_AUTHENTICATION_MD5: UInt32 = 1
IPSEC_OFFLOAD_V2_AUTHENTICATION_SHA_1: UInt32 = 2
IPSEC_OFFLOAD_V2_AUTHENTICATION_SHA_256: UInt32 = 4
IPSEC_OFFLOAD_V2_AUTHENTICATION_AES_GCM_128: UInt32 = 8
IPSEC_OFFLOAD_V2_AUTHENTICATION_AES_GCM_192: UInt32 = 16
IPSEC_OFFLOAD_V2_AUTHENTICATION_AES_GCM_256: UInt32 = 32
IPSEC_OFFLOAD_V2_ENCRYPTION_NONE: UInt32 = 1
IPSEC_OFFLOAD_V2_ENCRYPTION_DES_CBC: UInt32 = 2
IPSEC_OFFLOAD_V2_ENCRYPTION_3_DES_CBC: UInt32 = 4
IPSEC_OFFLOAD_V2_ENCRYPTION_AES_GCM_128: UInt32 = 8
IPSEC_OFFLOAD_V2_ENCRYPTION_AES_GCM_192: UInt32 = 16
IPSEC_OFFLOAD_V2_ENCRYPTION_AES_GCM_256: UInt32 = 32
IPSEC_OFFLOAD_V2_ENCRYPTION_AES_CBC_128: UInt32 = 64
IPSEC_OFFLOAD_V2_ENCRYPTION_AES_CBC_192: UInt32 = 128
IPSEC_OFFLOAD_V2_ENCRYPTION_AES_CBC_256: UInt32 = 256
NDIS_TCP_RECV_SEG_COALESC_OFFLOAD_REVISION_1: UInt32 = 1
NDIS_ENCAPSULATED_PACKET_TASK_OFFLOAD_NOT_SUPPORTED: UInt32 = 0
NDIS_ENCAPSULATED_PACKET_TASK_OFFLOAD_INNER_IPV4: UInt32 = 1
NDIS_ENCAPSULATED_PACKET_TASK_OFFLOAD_OUTER_IPV4: UInt32 = 2
NDIS_ENCAPSULATED_PACKET_TASK_OFFLOAD_INNER_IPV6: UInt32 = 4
NDIS_ENCAPSULATED_PACKET_TASK_OFFLOAD_OUTER_IPV6: UInt32 = 8
NDIS_OFFLOAD_FLAGS_GROUP_CHECKSUM_CAPABILITIES: UInt32 = 1
IPSEC_OFFLOAD_V2_AND_TCP_CHECKSUM_COEXISTENCE: UInt32 = 2
IPSEC_OFFLOAD_V2_AND_UDP_CHECKSUM_COEXISTENCE: UInt32 = 4
NDIS_OFFLOAD_REVISION_1: UInt32 = 1
NDIS_OFFLOAD_REVISION_2: UInt32 = 2
NDIS_OFFLOAD_REVISION_3: UInt32 = 3
NDIS_OFFLOAD_REVISION_4: UInt32 = 4
NDIS_OFFLOAD_REVISION_5: UInt32 = 5
NDIS_OFFLOAD_REVISION_6: UInt32 = 6
NDIS_OFFLOAD_REVISION_7: UInt32 = 7
NDIS_TCP_CONNECTION_OFFLOAD_REVISION_1: UInt32 = 1
NDIS_TCP_CONNECTION_OFFLOAD_REVISION_2: UInt32 = 2
NDIS_PORT_AUTHENTICATION_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_WMI_DEFAULT_METHOD_ID: UInt32 = 1
NDIS_WMI_OBJECT_TYPE_SET: UInt32 = 1
NDIS_WMI_OBJECT_TYPE_METHOD: UInt32 = 2
NDIS_WMI_OBJECT_TYPE_EVENT: UInt32 = 3
NDIS_WMI_OBJECT_TYPE_ENUM_ADAPTER: UInt32 = 4
NDIS_WMI_OBJECT_TYPE_OUTPUT_INFO: UInt32 = 5
NDIS_WMI_METHOD_HEADER_REVISION_1: UInt32 = 1
NDIS_WMI_SET_HEADER_REVISION_1: UInt32 = 1
NDIS_WMI_EVENT_HEADER_REVISION_1: UInt32 = 1
NDIS_WMI_ENUM_ADAPTER_REVISION_1: UInt32 = 1
NDIS_DEVICE_TYPE_ENDPOINT: UInt32 = 1
NDIS_HD_SPLIT_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_HD_SPLIT_COMBINE_ALL_HEADERS: UInt32 = 1
NDIS_HD_SPLIT_CURRENT_CONFIG_REVISION_1: UInt32 = 1
NDIS_HD_SPLIT_CAPS_SUPPORTS_HEADER_DATA_SPLIT: UInt32 = 1
NDIS_HD_SPLIT_CAPS_SUPPORTS_IPV4_OPTIONS: UInt32 = 2
NDIS_HD_SPLIT_CAPS_SUPPORTS_IPV6_EXTENSION_HEADERS: UInt32 = 4
NDIS_HD_SPLIT_CAPS_SUPPORTS_TCP_OPTIONS: UInt32 = 8
NDIS_HD_SPLIT_ENABLE_HEADER_DATA_SPLIT: UInt32 = 1
NDIS_PM_WOL_BITMAP_PATTERN_SUPPORTED: UInt32 = 1
NDIS_PM_WOL_MAGIC_PACKET_SUPPORTED: UInt32 = 2
NDIS_PM_WOL_IPV4_TCP_SYN_SUPPORTED: UInt32 = 4
NDIS_PM_WOL_IPV6_TCP_SYN_SUPPORTED: UInt32 = 8
NDIS_PM_WOL_IPV4_DEST_ADDR_WILDCARD_SUPPORTED: UInt32 = 512
NDIS_PM_WOL_IPV6_DEST_ADDR_WILDCARD_SUPPORTED: UInt32 = 2048
NDIS_PM_WOL_EAPOL_REQUEST_ID_MESSAGE_SUPPORTED: UInt32 = 65536
NDIS_PM_PROTOCOL_OFFLOAD_ARP_SUPPORTED: UInt32 = 1
NDIS_PM_PROTOCOL_OFFLOAD_NS_SUPPORTED: UInt32 = 2
NDIS_PM_PROTOCOL_OFFLOAD_80211_RSN_REKEY_SUPPORTED: UInt32 = 128
NDIS_PM_WAKE_ON_MEDIA_CONNECT_SUPPORTED: UInt32 = 1
NDIS_PM_WAKE_ON_MEDIA_DISCONNECT_SUPPORTED: UInt32 = 2
NDIS_WLAN_WAKE_ON_NLO_DISCOVERY_SUPPORTED: UInt32 = 1
NDIS_WLAN_WAKE_ON_AP_ASSOCIATION_LOST_SUPPORTED: UInt32 = 2
NDIS_WLAN_WAKE_ON_GTK_HANDSHAKE_ERROR_SUPPORTED: UInt32 = 4
NDIS_WLAN_WAKE_ON_4WAY_HANDSHAKE_REQUEST_SUPPORTED: UInt32 = 8
NDIS_WWAN_WAKE_ON_REGISTER_STATE_SUPPORTED: UInt32 = 1
NDIS_WWAN_WAKE_ON_SMS_RECEIVE_SUPPORTED: UInt32 = 2
NDIS_WWAN_WAKE_ON_USSD_RECEIVE_SUPPORTED: UInt32 = 4
NDIS_WWAN_WAKE_ON_PACKET_STATE_SUPPORTED: UInt32 = 8
NDIS_WWAN_WAKE_ON_UICC_CHANGE_SUPPORTED: UInt32 = 16
NDIS_PM_WAKE_PACKET_INDICATION_SUPPORTED: UInt32 = 1
NDIS_PM_SELECTIVE_SUSPEND_SUPPORTED: UInt32 = 2
NDIS_PM_WOL_BITMAP_PATTERN_ENABLED: UInt32 = 1
NDIS_PM_WOL_MAGIC_PACKET_ENABLED: UInt32 = 2
NDIS_PM_WOL_IPV4_TCP_SYN_ENABLED: UInt32 = 4
NDIS_PM_WOL_IPV6_TCP_SYN_ENABLED: UInt32 = 8
NDIS_PM_WOL_IPV4_DEST_ADDR_WILDCARD_ENABLED: UInt32 = 512
NDIS_PM_WOL_IPV6_DEST_ADDR_WILDCARD_ENABLED: UInt32 = 2048
NDIS_PM_WOL_EAPOL_REQUEST_ID_MESSAGE_ENABLED: UInt32 = 65536
NDIS_PM_PROTOCOL_OFFLOAD_ARP_ENABLED: UInt32 = 1
NDIS_PM_PROTOCOL_OFFLOAD_NS_ENABLED: UInt32 = 2
NDIS_PM_PROTOCOL_OFFLOAD_80211_RSN_REKEY_ENABLED: UInt32 = 128
NDIS_PM_WAKE_ON_LINK_CHANGE_ENABLED: UInt32 = 1
NDIS_PM_WAKE_ON_MEDIA_DISCONNECT_ENABLED: UInt32 = 2
NDIS_PM_SELECTIVE_SUSPEND_ENABLED: UInt32 = 16
NDIS_WLAN_WAKE_ON_NLO_DISCOVERY_ENABLED: UInt32 = 1
NDIS_WLAN_WAKE_ON_AP_ASSOCIATION_LOST_ENABLED: UInt32 = 2
NDIS_WLAN_WAKE_ON_GTK_HANDSHAKE_ERROR_ENABLED: UInt32 = 4
NDIS_WLAN_WAKE_ON_4WAY_HANDSHAKE_REQUEST_ENABLED: UInt32 = 8
NDIS_WWAN_WAKE_ON_REGISTER_STATE_ENABLED: UInt32 = 1
NDIS_WWAN_WAKE_ON_SMS_RECEIVE_ENABLED: UInt32 = 2
NDIS_WWAN_WAKE_ON_USSD_RECEIVE_ENABLED: UInt32 = 4
NDIS_WWAN_WAKE_ON_PACKET_STATE_ENABLED: UInt32 = 8
NDIS_WWAN_WAKE_ON_UICC_CHANGE_ENABLED: UInt32 = 16
NDIS_PM_WOL_PRIORITY_LOWEST: UInt32 = 4294967295
NDIS_PM_WOL_PRIORITY_NORMAL: UInt32 = 268435456
NDIS_PM_WOL_PRIORITY_HIGHEST: UInt32 = 1
NDIS_PM_PROTOCOL_OFFLOAD_PRIORITY_LOWEST: UInt32 = 4294967295
NDIS_PM_PROTOCOL_OFFLOAD_PRIORITY_NORMAL: UInt32 = 268435456
NDIS_PM_PROTOCOL_OFFLOAD_PRIORITY_HIGHEST: UInt32 = 1
NDIS_PM_MAX_STRING_SIZE: UInt32 = 64
NDIS_PM_CAPABILITIES_REVISION_1: UInt32 = 1
NDIS_PM_CAPABILITIES_REVISION_2: UInt32 = 2
NDIS_PM_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_PM_PARAMETERS_REVISION_2: UInt32 = 2
EAPOL_REQUEST_ID_WOL_FLAG_MUST_ENCRYPT: UInt32 = 1
NDIS_PM_MAX_PATTERN_ID: UInt32 = 65535
NDIS_PM_PRIVATE_PATTERN_ID: UInt32 = 1
NDIS_PM_WOL_PATTERN_REVISION_1: UInt32 = 1
NDIS_PM_WOL_PATTERN_REVISION_2: UInt32 = 2
DOT11_RSN_KCK_LENGTH: UInt32 = 16
DOT11_RSN_KEK_LENGTH: UInt32 = 16
DOT11_RSN_MAX_CIPHER_KEY_LENGTH: UInt32 = 32
NDIS_PM_PROTOCOL_OFFLOAD_REVISION_1: UInt32 = 1
NDIS_PM_PROTOCOL_OFFLOAD_REVISION_2: UInt32 = 2
NDIS_SIZEOF_NDIS_PM_PROTOCOL_OFFLOAD_REVISION_1: UInt32 = 240
NDIS_PM_WAKE_REASON_REVISION_1: UInt32 = 1
NDIS_PM_WAKE_PACKET_REVISION_1: UInt32 = 1
NDIS_WMI_PM_ADMIN_CONFIG_REVISION_1: UInt32 = 1
NDIS_WMI_PM_ACTIVE_CAPABILITIES_REVISION_1: UInt32 = 1
NDIS_RECEIVE_FILTER_MAC_HEADER_SUPPORTED: UInt32 = 1
NDIS_RECEIVE_FILTER_IPV4_HEADER_SUPPORTED: UInt32 = 2
NDIS_RECEIVE_FILTER_IPV6_HEADER_SUPPORTED: UInt32 = 4
NDIS_RECEIVE_FILTER_ARP_HEADER_SUPPORTED: UInt32 = 8
NDIS_RECEIVE_FILTER_UDP_HEADER_SUPPORTED: UInt32 = 16
NDIS_RECEIVE_FILTER_MAC_HEADER_DEST_ADDR_SUPPORTED: UInt32 = 1
NDIS_RECEIVE_FILTER_MAC_HEADER_SOURCE_ADDR_SUPPORTED: UInt32 = 2
NDIS_RECEIVE_FILTER_MAC_HEADER_PROTOCOL_SUPPORTED: UInt32 = 4
NDIS_RECEIVE_FILTER_MAC_HEADER_VLAN_ID_SUPPORTED: UInt32 = 8
NDIS_RECEIVE_FILTER_MAC_HEADER_PRIORITY_SUPPORTED: UInt32 = 16
NDIS_RECEIVE_FILTER_MAC_HEADER_PACKET_TYPE_SUPPORTED: UInt32 = 32
NDIS_RECEIVE_FILTER_ARP_HEADER_OPERATION_SUPPORTED: UInt32 = 1
NDIS_RECEIVE_FILTER_ARP_HEADER_SPA_SUPPORTED: UInt32 = 2
NDIS_RECEIVE_FILTER_ARP_HEADER_TPA_SUPPORTED: UInt32 = 4
NDIS_RECEIVE_FILTER_IPV4_HEADER_PROTOCOL_SUPPORTED: UInt32 = 1
NDIS_RECEIVE_FILTER_IPV6_HEADER_PROTOCOL_SUPPORTED: UInt32 = 1
NDIS_RECEIVE_FILTER_UDP_HEADER_DEST_PORT_SUPPORTED: UInt32 = 1
NDIS_RECEIVE_FILTER_TEST_HEADER_FIELD_EQUAL_SUPPORTED: UInt32 = 1
NDIS_RECEIVE_FILTER_TEST_HEADER_FIELD_MASK_EQUAL_SUPPORTED: UInt32 = 2
NDIS_RECEIVE_FILTER_TEST_HEADER_FIELD_NOT_EQUAL_SUPPORTED: UInt32 = 4
NDIS_RECEIVE_FILTER_MSI_X_SUPPORTED: UInt32 = 1
NDIS_RECEIVE_FILTER_VM_QUEUE_SUPPORTED: UInt32 = 2
NDIS_RECEIVE_FILTER_LOOKAHEAD_SPLIT_SUPPORTED: UInt32 = 4
NDIS_RECEIVE_FILTER_DYNAMIC_PROCESSOR_AFFINITY_CHANGE_SUPPORTED: UInt32 = 8
NDIS_RECEIVE_FILTER_INTERRUPT_VECTOR_COALESCING_SUPPORTED: UInt32 = 16
NDIS_RECEIVE_FILTER_IMPLAT_MIN_OF_QUEUES_MODE: UInt32 = 64
NDIS_RECEIVE_FILTER_IMPLAT_SUM_OF_QUEUES_MODE: UInt32 = 128
NDIS_RECEIVE_FILTER_PACKET_COALESCING_SUPPORTED_ON_DEFAULT_QUEUE: UInt32 = 256
NDIS_RECEIVE_FILTER_ANY_VLAN_SUPPORTED: UInt32 = 32
NDIS_RECEIVE_FILTER_DYNAMIC_PROCESSOR_AFFINITY_CHANGE_FOR_DEFAULT_QUEUE_SUPPORTED: UInt32 = 64
NDIS_RECEIVE_FILTER_VMQ_FILTERS_ENABLED: UInt32 = 1
NDIS_RECEIVE_FILTER_PACKET_COALESCING_FILTERS_ENABLED: UInt32 = 2
NDIS_RECEIVE_FILTER_VM_QUEUES_ENABLED: UInt32 = 1
NDIS_RECEIVE_FILTER_CAPABILITIES_REVISION_1: UInt32 = 1
NDIS_RECEIVE_FILTER_CAPABILITIES_REVISION_2: UInt32 = 2
NDIS_NIC_SWITCH_CAPS_VLAN_SUPPORTED: UInt32 = 1
NDIS_NIC_SWITCH_CAPS_PER_VPORT_INTERRUPT_MODERATION_SUPPORTED: UInt32 = 2
NDIS_NIC_SWITCH_CAPS_ASYMMETRIC_QUEUE_PAIRS_FOR_NONDEFAULT_VPORT_SUPPORTED: UInt32 = 4
NDIS_NIC_SWITCH_CAPS_VF_RSS_SUPPORTED: UInt32 = 8
NDIS_NIC_SWITCH_CAPS_SINGLE_VPORT_POOL: UInt32 = 16
NDIS_NIC_SWITCH_CAPS_RSS_PARAMETERS_PER_PF_VPORT_SUPPORTED: UInt32 = 32
NDIS_NIC_SWITCH_CAPS_NIC_SWITCH_WITHOUT_IOV_SUPPORTED: UInt32 = 64
NDIS_NIC_SWITCH_CAPS_RSS_ON_PF_VPORTS_SUPPORTED: UInt32 = 128
NDIS_NIC_SWITCH_CAPS_RSS_PER_PF_VPORT_INDIRECTION_TABLE_SUPPORTED: UInt32 = 256
NDIS_NIC_SWITCH_CAPS_RSS_PER_PF_VPORT_HASH_FUNCTION_SUPPORTED: UInt32 = 512
NDIS_NIC_SWITCH_CAPS_RSS_PER_PF_VPORT_HASH_TYPE_SUPPORTED: UInt32 = 1024
NDIS_NIC_SWITCH_CAPS_RSS_PER_PF_VPORT_HASH_KEY_SUPPORTED: UInt32 = 2048
NDIS_NIC_SWITCH_CAPS_RSS_PER_PF_VPORT_INDIRECTION_TABLE_SIZE_RESTRICTED: UInt32 = 4096
NDIS_NIC_SWITCH_CAPABILITIES_REVISION_1: UInt32 = 1
NDIS_NIC_SWITCH_CAPABILITIES_REVISION_2: UInt32 = 2
NDIS_NIC_SWITCH_CAPABILITIES_REVISION_3: UInt32 = 3
NDIS_RECEIVE_FILTER_GLOBAL_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_DEFAULT_RECEIVE_QUEUE_ID: UInt32 = 0
NDIS_DEFAULT_RECEIVE_QUEUE_GROUP_ID: UInt32 = 0
NDIS_DEFAULT_RECEIVE_FILTER_ID: UInt32 = 0
NDIS_RECEIVE_FILTER_FIELD_MAC_HEADER_VLAN_UNTAGGED_OR_ZERO: UInt32 = 1
NDIS_RECEIVE_FILTER_RESERVED: UInt32 = 254
NDIS_RECEIVE_FILTER_FIELD_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_RECEIVE_FILTER_FIELD_PARAMETERS_REVISION_2: UInt32 = 2
NDIS_RECEIVE_FILTER_FLAGS_RESERVED: UInt32 = 1
NDIS_RECEIVE_FILTER_PACKET_ENCAPSULATION_GRE: UInt32 = 2
NDIS_RECEIVE_FILTER_PACKET_ENCAPSULATION: UInt32 = 2
NDIS_RECEIVE_FILTER_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_RECEIVE_FILTER_PARAMETERS_REVISION_2: UInt32 = 2
NDIS_RECEIVE_FILTER_CLEAR_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_RECEIVE_QUEUE_PARAMETERS_PER_QUEUE_RECEIVE_INDICATION: UInt32 = 1
NDIS_RECEIVE_QUEUE_PARAMETERS_LOOKAHEAD_SPLIT_REQUIRED: UInt32 = 2
NDIS_RECEIVE_QUEUE_PARAMETERS_FLAGS_CHANGED: UInt32 = 65536
NDIS_RECEIVE_QUEUE_PARAMETERS_PROCESSOR_AFFINITY_CHANGED: UInt32 = 131072
NDIS_RECEIVE_QUEUE_PARAMETERS_SUGGESTED_RECV_BUFFER_NUMBERS_CHANGED: UInt32 = 262144
NDIS_RECEIVE_QUEUE_PARAMETERS_NAME_CHANGED: UInt32 = 524288
NDIS_RECEIVE_QUEUE_PARAMETERS_INTERRUPT_COALESCING_DOMAIN_ID_CHANGED: UInt32 = 1048576
NDIS_RECEIVE_QUEUE_PARAMETERS_QOS_SQ_ID_CHANGED: UInt32 = 2097152
NDIS_RECEIVE_QUEUE_PARAMETERS_CHANGE_MASK: UInt32 = 4294901760
NDIS_RECEIVE_QUEUE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_RECEIVE_QUEUE_PARAMETERS_REVISION_2: UInt32 = 2
NDIS_RECEIVE_QUEUE_PARAMETERS_REVISION_3: UInt32 = 3
NDIS_RECEIVE_QUEUE_FREE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_RECEIVE_QUEUE_INFO_REVISION_1: UInt32 = 1
NDIS_RECEIVE_QUEUE_INFO_REVISION_2: UInt32 = 2
NDIS_RECEIVE_QUEUE_INFO_ARRAY_REVISION_1: UInt32 = 1
NDIS_RECEIVE_FILTER_INFO_REVISION_1: UInt32 = 1
NDIS_RECEIVE_FILTER_INFO_ARRAY_REVISION_1: UInt32 = 1
NDIS_RECEIVE_FILTER_INFO_ARRAY_REVISION_2: UInt32 = 2
NDIS_RECEIVE_FILTER_INFO_ARRAY_VPORT_ID_SPECIFIED: UInt32 = 1
NDIS_RECEIVE_QUEUE_ALLOCATION_COMPLETE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_RECEIVE_QUEUE_ALLOCATION_COMPLETE_ARRAY_REVISION_1: UInt32 = 1
NDIS_RECEIVE_SCALE_CAPABILITIES_REVISION_1: UInt32 = 1
NDIS_RECEIVE_SCALE_CAPABILITIES_REVISION_2: UInt32 = 2
NDIS_RECEIVE_SCALE_CAPABILITIES_REVISION_3: UInt32 = 3
NDIS_RSS_CAPS_HASH_TYPE_TCP_IPV4: UInt32 = 256
NDIS_RSS_CAPS_HASH_TYPE_TCP_IPV6: UInt32 = 512
NDIS_RSS_CAPS_HASH_TYPE_TCP_IPV6_EX: UInt32 = 1024
NDIS_RSS_CAPS_HASH_TYPE_UDP_IPV4: UInt32 = 2048
NDIS_RSS_CAPS_HASH_TYPE_UDP_IPV6: UInt32 = 4096
NDIS_RSS_CAPS_HASH_TYPE_UDP_IPV6_EX: UInt32 = 8192
NDIS_RSS_CAPS_MESSAGE_SIGNALED_INTERRUPTS: UInt32 = 16777216
NDIS_RSS_CAPS_CLASSIFICATION_AT_ISR: UInt32 = 33554432
NDIS_RSS_CAPS_CLASSIFICATION_AT_DPC: UInt32 = 67108864
NDIS_RSS_CAPS_USING_MSI_X: UInt32 = 134217728
NDIS_RSS_CAPS_RSS_AVAILABLE_ON_PORTS: UInt32 = 268435456
NDIS_RSS_CAPS_SUPPORTS_MSI_X: UInt32 = 536870912
NDIS_RSS_CAPS_SUPPORTS_INDEPENDENT_ENTRY_MOVE: UInt32 = 1073741824
NDIS_RSS_PARAM_FLAG_BASE_CPU_UNCHANGED: UInt32 = 1
NDIS_RSS_PARAM_FLAG_HASH_INFO_UNCHANGED: UInt32 = 2
NDIS_RSS_PARAM_FLAG_ITABLE_UNCHANGED: UInt32 = 4
NDIS_RSS_PARAM_FLAG_HASH_KEY_UNCHANGED: UInt32 = 8
NDIS_RSS_PARAM_FLAG_DISABLE_RSS: UInt32 = 16
NDIS_RSS_PARAM_FLAG_DEFAULT_PROCESSOR_UNCHANGED: UInt32 = 32
NDIS_RSS_INDIRECTION_TABLE_SIZE_REVISION_1: UInt32 = 128
NDIS_RSS_HASH_SECRET_KEY_SIZE_REVISION_1: UInt32 = 40
NDIS_RECEIVE_SCALE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_RECEIVE_SCALE_PARAMETERS_REVISION_2: UInt32 = 2
NDIS_RECEIVE_SCALE_PARAMETERS_REVISION_3: UInt32 = 3
NDIS_RSS_INDIRECTION_TABLE_MAX_SIZE_REVISION_1: UInt32 = 128
NDIS_RSS_HASH_SECRET_KEY_MAX_SIZE_REVISION_1: UInt32 = 40
NDIS_RSS_HASH_SECRET_KEY_MAX_SIZE_REVISION_2: UInt32 = 40
NDIS_RSS_HASH_SECRET_KEY_MAX_SIZE_REVISION_3: UInt32 = 40
NDIS_RECEIVE_SCALE_PARAMETERS_V2_REVISION_1: UInt32 = 1
NDIS_RECEIVE_SCALE_PARAM_ENABLE_RSS: UInt32 = 1
NDIS_RECEIVE_SCALE_PARAM_HASH_INFO_CHANGED: UInt32 = 2
NDIS_RECEIVE_SCALE_PARAM_HASH_KEY_CHANGED: UInt32 = 4
NDIS_RECEIVE_SCALE_PARAM_NUMBER_OF_QUEUES_CHANGED: UInt32 = 8
NDIS_RECEIVE_SCALE_PARAM_NUMBER_OF_ENTRIES_CHANGED: UInt32 = 16
NDIS_RSS_SET_INDIRECTION_ENTRY_FLAG_PRIMARY_PROCESSOR: UInt32 = 1
NDIS_RSS_SET_INDIRECTION_ENTRY_FLAG_DEFAULT_PROCESSOR: UInt32 = 2
NDIS_RSS_SET_INDIRECTION_ENTRIES_REVISION_1: UInt32 = 1
NDIS_RECEIVE_HASH_FLAG_ENABLE_HASH: UInt32 = 1
NDIS_RECEIVE_HASH_FLAG_HASH_INFO_UNCHANGED: UInt32 = 2
NDIS_RECEIVE_HASH_FLAG_HASH_KEY_UNCHANGED: UInt32 = 4
NDIS_RECEIVE_HASH_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_RSS_PROCESSOR_INFO_REVISION_1: UInt32 = 1
NDIS_RSS_PROCESSOR_INFO_REVISION_2: UInt32 = 2
NDIS_SYSTEM_PROCESSOR_INFO_EX_REVISION_1: UInt32 = 1
NDIS_HYPERVISOR_INFO_FLAG_HYPERVISOR_PRESENT: UInt32 = 1
NDIS_HYPERVISOR_INFO_REVISION_1: UInt32 = 1
NDIS_WMI_RECEIVE_QUEUE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_WMI_RECEIVE_QUEUE_INFO_REVISION_1: UInt32 = 1
NDIS_NDK_CAPABILITIES_REVISION_1: UInt32 = 1
OID_NDK_SET_STATE: UInt32 = 4228121089
OID_NDK_STATISTICS: UInt32 = 4228121090
OID_NDK_CONNECTIONS: UInt32 = 4228121091
OID_NDK_LOCAL_ENDPOINTS: UInt32 = 4228121092
GUID_NDIS_NDK_CAPABILITIES: Guid = Guid('{7969ba4d-dd80-4bc7-b3e6-68043997e519}')
GUID_NDIS_NDK_STATE: Guid = Guid('{530c69c9-2f51-49de-a1af-088d54ffa474}')
NDIS_NDK_STATISTICS_INFO_REVISION_1: UInt32 = 1
NDIS_NDK_CONNECTIONS_REVISION_1: UInt32 = 1
NDIS_NDK_LOCAL_ENDPOINTS_REVISION_1: UInt32 = 1
OID_QOS_HARDWARE_CAPABILITIES: UInt32 = 4228186113
OID_QOS_CURRENT_CAPABILITIES: UInt32 = 4228186114
OID_QOS_PARAMETERS: UInt32 = 4228186115
OID_QOS_OPERATIONAL_PARAMETERS: UInt32 = 4228186116
OID_QOS_REMOTE_PARAMETERS: UInt32 = 4228186117
NDIS_QOS_MAXIMUM_PRIORITIES: UInt32 = 8
NDIS_QOS_MAXIMUM_TRAFFIC_CLASSES: UInt32 = 8
NDIS_QOS_CAPABILITIES_STRICT_TSA_SUPPORTED: UInt32 = 1
NDIS_QOS_CAPABILITIES_MACSEC_BYPASS_SUPPORTED: UInt32 = 2
NDIS_QOS_CAPABILITIES_CEE_DCBX_SUPPORTED: UInt32 = 4
NDIS_QOS_CAPABILITIES_IEEE_DCBX_SUPPORTED: UInt32 = 8
NDIS_QOS_CAPABILITIES_REVISION_1: UInt32 = 1
NDIS_QOS_CLASSIFICATION_SET_BY_MINIPORT_MASK: UInt32 = 4278190080
NDIS_QOS_CLASSIFICATION_ENFORCED_BY_MINIPORT: UInt32 = 16777216
NDIS_QOS_CONDITION_RESERVED: UInt32 = 0
NDIS_QOS_CONDITION_DEFAULT: UInt32 = 1
NDIS_QOS_CONDITION_TCP_PORT: UInt32 = 2
NDIS_QOS_CONDITION_UDP_PORT: UInt32 = 3
NDIS_QOS_CONDITION_TCP_OR_UDP_PORT: UInt32 = 4
NDIS_QOS_CONDITION_ETHERTYPE: UInt32 = 5
NDIS_QOS_CONDITION_NETDIRECT_PORT: UInt32 = 6
NDIS_QOS_CONDITION_MAXIMUM: UInt32 = 7
NDIS_QOS_ACTION_PRIORITY: UInt32 = 0
NDIS_QOS_ACTION_MAXIMUM: UInt32 = 1
NDIS_QOS_CLASSIFICATION_ELEMENT_REVISION_1: UInt32 = 1
NDIS_QOS_PARAMETERS_ETS_CHANGED: UInt32 = 1
NDIS_QOS_PARAMETERS_ETS_CONFIGURED: UInt32 = 2
NDIS_QOS_PARAMETERS_PFC_CHANGED: UInt32 = 256
NDIS_QOS_PARAMETERS_PFC_CONFIGURED: UInt32 = 512
NDIS_QOS_PARAMETERS_CLASSIFICATION_CHANGED: UInt32 = 65536
NDIS_QOS_PARAMETERS_CLASSIFICATION_CONFIGURED: UInt32 = 131072
NDIS_QOS_PARAMETERS_WILLING: UInt32 = 2147483648
NDIS_QOS_TSA_STRICT: UInt32 = 0
NDIS_QOS_TSA_CBS: UInt32 = 1
NDIS_QOS_TSA_ETS: UInt32 = 2
NDIS_QOS_TSA_MAXIMUM: UInt32 = 3
NDIS_QOS_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_DEFAULT_VPORT_ID: UInt32 = 0
NDIS_DEFAULT_SWITCH_ID: UInt32 = 0
NDIS_NIC_SWITCH_PARAMETERS_CHANGE_MASK: UInt32 = 4294901760
NDIS_NIC_SWITCH_PARAMETERS_SWITCH_NAME_CHANGED: UInt32 = 65536
NDIS_NIC_SWITCH_PARAMETERS_DEFAULT_NUMBER_OF_QUEUE_PAIRS_FOR_DEFAULT_VPORT: UInt32 = 1
NDIS_NIC_SWITCH_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_NIC_SWITCH_PARAMETERS_REVISION_2: UInt32 = 2
NDIS_NIC_SWITCH_DELETE_SWITCH_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_NIC_SWITCH_INFO_REVISION_1: UInt32 = 1
NDIS_NIC_SWITCH_INFO_ARRAY_REVISION_1: UInt32 = 1
NDIS_NIC_SWITCH_VPORT_PARAMS_LOOKAHEAD_SPLIT_ENABLED: UInt32 = 1
NDIS_NIC_SWITCH_VPORT_PARAMS_PACKET_DIRECT_RX_ONLY: UInt32 = 2
NDIS_NIC_SWITCH_VPORT_PARAMS_ENFORCE_MAX_SG_LIST: UInt32 = 32768
NDIS_NIC_SWITCH_VPORT_PARAMS_CHANGE_MASK: UInt32 = 4294901760
NDIS_NIC_SWITCH_VPORT_PARAMS_FLAGS_CHANGED: UInt32 = 65536
NDIS_NIC_SWITCH_VPORT_PARAMS_NAME_CHANGED: UInt32 = 131072
NDIS_NIC_SWITCH_VPORT_PARAMS_INT_MOD_CHANGED: UInt32 = 262144
NDIS_NIC_SWITCH_VPORT_PARAMS_STATE_CHANGED: UInt32 = 524288
NDIS_NIC_SWITCH_VPORT_PARAMS_PROCESSOR_AFFINITY_CHANGED: UInt32 = 1048576
NDIS_NIC_SWITCH_VPORT_PARAMS_NDK_PARAMS_CHANGED: UInt32 = 2097152
NDIS_NIC_SWITCH_VPORT_PARAMS_QOS_SQ_ID_CHANGED: UInt32 = 4194304
NDIS_NIC_SWITCH_VPORT_PARAMS_NUM_QUEUE_PAIRS_CHANGED: UInt32 = 8388608
NDIS_NIC_SWITCH_VPORT_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_NIC_SWITCH_VPORT_PARAMETERS_REVISION_2: UInt32 = 2
NDIS_NIC_SWITCH_DELETE_VPORT_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_NIC_SWITCH_VPORT_INFO_LOOKAHEAD_SPLIT_ENABLED: UInt32 = 1
NDIS_NIC_SWITCH_VPORT_INFO_PACKET_DIRECT_RX_ONLY: UInt32 = 2
NDIS_NIC_SWITCH_VPORT_INFO_GFT_ENABLED: UInt32 = 4
NDIS_NIC_SWITCH_VPORT_INFO_REVISION_1: UInt32 = 1
NDIS_NIC_SWITCH_VPORT_INFO_ARRAY_ENUM_ON_SPECIFIC_FUNCTION: UInt32 = 1
NDIS_NIC_SWITCH_VPORT_INFO_ARRAY_ENUM_ON_SPECIFIC_SWITCH: UInt32 = 2
NDIS_NIC_SWITCH_VPORT_INFO_ARRAY_REVISION_1: UInt32 = 1
NDIS_NIC_SWITCH_VF_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_NIC_SWITCH_FREE_VF_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_NIC_SWITCH_VF_INFO_REVISION_1: UInt32 = 1
NDIS_NIC_SWITCH_VF_INFO_ARRAY_ENUM_ON_SPECIFIC_SWITCH: UInt32 = 1
NDIS_NIC_SWITCH_VF_INFO_ARRAY_REVISION_1: UInt32 = 1
NDIS_SRIOV_CAPS_SRIOV_SUPPORTED: UInt32 = 1
NDIS_SRIOV_CAPS_PF_MINIPORT: UInt32 = 2
NDIS_SRIOV_CAPS_VF_MINIPORT: UInt32 = 4
NDIS_SRIOV_CAPABILITIES_REVISION_1: UInt32 = 1
NDIS_SRIOV_READ_VF_CONFIG_SPACE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SRIOV_WRITE_VF_CONFIG_SPACE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SRIOV_READ_VF_CONFIG_BLOCK_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SRIOV_WRITE_VF_CONFIG_BLOCK_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SRIOV_RESET_VF_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SRIOV_SET_VF_POWER_STATE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SRIOV_CONFIG_STATE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SRIOV_VF_VENDOR_DEVICE_ID_INFO_REVISION_1: UInt32 = 1
NDIS_SRIOV_PROBED_BARS_INFO_REVISION_1: UInt32 = 1
NDIS_RECEIVE_FILTER_MOVE_FILTER_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SRIOV_BAR_RESOURCES_INFO_REVISION_1: UInt32 = 1
NDIS_SRIOV_PF_LUID_INFO_REVISION_1: UInt32 = 1
NDIS_SRIOV_VF_SERIAL_NUMBER_INFO_REVISION_1: UInt32 = 1
NDIS_SRIOV_VF_INVALIDATE_CONFIG_BLOCK_INFO_REVISION_1: UInt32 = 1
NDIS_SRIOV_OVERLYING_ADAPTER_INFO_VERSION_1: UInt32 = 1
NDIS_ISOLATION_NAME_MAX_STRING_SIZE: UInt32 = 127
NDIS_ROUTING_DOMAIN_ISOLATION_ENTRY_REVISION_1: UInt32 = 1
NDIS_ROUTING_DOMAIN_ENTRY_REVISION_1: UInt32 = 1
NDIS_ISOLATION_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SWITCH_OBJECT_SERIALIZATION_VERSION_1: UInt32 = 1
NDIS_SWITCH_PORT_PROPERTY_SECURITY_REVISION_1: UInt32 = 1
NDIS_SWITCH_PORT_PROPERTY_SECURITY_REVISION_2: UInt32 = 2
NDIS_SWITCH_PORT_PROPERTY_VLAN_REVISION_1: UInt32 = 1
NDIS_SWITCH_PORT_PROPERTY_PROFILE_REVISION_1: UInt32 = 1
NDIS_SWITCH_PORT_PROPERTY_ISOLATION_REVISION_1: UInt32 = 1
NDIS_SWITCH_PORT_PROPERTY_ROUTING_DOMAIN_REVISION_1: UInt32 = 1
NDIS_SWITCH_PORT_PROPERTY_CUSTOM_REVISION_1: UInt32 = 1
NDIS_SWITCH_PORT_PROPERTY_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SWITCH_PORT_PROPERTY_DELETE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SWITCH_PORT_PROPERTY_ENUM_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SWITCH_PORT_PROPERTY_ENUM_INFO_REVISION_1: UInt32 = 1
NDIS_SWITCH_PORT_FEATURE_STATUS_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SWITCH_PORT_FEATURE_STATUS_CUSTOM_REVISION_1: UInt32 = 1
NDIS_SWITCH_PROPERTY_CUSTOM_REVISION_1: UInt32 = 1
NDIS_SWITCH_PROPERTY_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SWITCH_PROPERTY_DELETE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SWITCH_PROPERTY_ENUM_INFO_REVISION_1: UInt32 = 1
NDIS_SWITCH_PROPERTY_ENUM_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SWITCH_FEATURE_STATUS_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SWITCH_FEATURE_STATUS_CUSTOM_REVISION_1: UInt32 = 1
NDIS_SWITCH_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SWITCH_PORT_PARAMETERS_FLAG_UNTRUSTED_INTERNAL_PORT: UInt32 = 1
NDIS_SWITCH_PORT_PARAMETERS_FLAG_RESTORING_PORT: UInt32 = 2
NDIS_SWITCH_PORT_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SWITCH_PORT_ARRAY_REVISION_1: UInt32 = 1
NDIS_SWITCH_NIC_FLAGS_NIC_INITIALIZING: UInt32 = 1
NDIS_SWITCH_NIC_FLAGS_NIC_SUSPENDED: UInt32 = 2
NDIS_SWITCH_NIC_FLAGS_MAPPED_NIC_UPDATED: UInt32 = 4
NDIS_SWITCH_NIC_FLAGS_NIC_SUSPENDED_LM: UInt32 = 16
NDIS_SWITCH_NIC_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_SWITCH_NIC_PARAMETERS_REVISION_2: UInt32 = 2
NDIS_SWITCH_NIC_ARRAY_REVISION_1: UInt32 = 1
NDIS_SWITCH_NIC_OID_REQUEST_REVISION_1: UInt32 = 1
NDIS_SWITCH_NIC_SAVE_STATE_REVISION_1: UInt32 = 1
NDIS_SWITCH_NIC_SAVE_STATE_REVISION_2: UInt32 = 2
NDIS_PORT_STATE_REVISION_1: UInt32 = 1
NDIS_PORT_CHAR_USE_DEFAULT_AUTH_SETTINGS: UInt32 = 1
NDIS_PORT_CHARACTERISTICS_REVISION_1: UInt32 = 1
NDIS_PORT_ARRAY_REVISION_1: UInt32 = 1
ETHERNET_LENGTH_OF_ADDRESS: UInt32 = 6
NDIS_GFP_HEADER_PRESENT_ETHERNET: UInt32 = 1
NDIS_GFP_HEADER_PRESENT_IPV4: UInt32 = 2
NDIS_GFP_HEADER_PRESENT_IPV6: UInt32 = 4
NDIS_GFP_HEADER_PRESENT_TCP: UInt32 = 8
NDIS_GFP_HEADER_PRESENT_UDP: UInt32 = 16
NDIS_GFP_HEADER_PRESENT_ICMP: UInt32 = 32
NDIS_GFP_HEADER_PRESENT_NO_ENCAP: UInt32 = 64
NDIS_GFP_HEADER_PRESENT_IP_IN_IP_ENCAP: UInt32 = 128
NDIS_GFP_HEADER_PRESENT_IP_IN_GRE_ENCAP: UInt32 = 256
NDIS_GFP_HEADER_PRESENT_NVGRE_ENCAP: UInt32 = 512
NDIS_GFP_HEADER_PRESENT_VXLAN_ENCAP: UInt32 = 1024
NDIS_GFP_HEADER_PRESENT_ESP: UInt32 = 2048
NDIS_GFP_ENCAPSULATION_TYPE_NOT_ENCAPSULATED: UInt32 = 1
NDIS_GFP_ENCAPSULATION_TYPE_IP_IN_IP: UInt32 = 2
NDIS_GFP_ENCAPSULATION_TYPE_IP_IN_GRE: UInt32 = 4
NDIS_GFP_ENCAPSULATION_TYPE_NVGRE: UInt32 = 8
NDIS_GFP_ENCAPSULATION_TYPE_VXLAN: UInt32 = 16
NDIS_GFP_UNDEFINED_PROFILE_ID: UInt32 = 0
NDIS_GFP_HEADER_GROUP_EXACT_MATCH_PROFILE_IS_TTL_ONE: UInt32 = 1
NDIS_GFP_HEADER_GROUP_EXACT_MATCH_PROFILE_REVISION_1: UInt32 = 1
NDIS_GFP_EXACT_MATCH_PROFILE_RDMA_FLOW: UInt32 = 1
NDIS_GFP_EXACT_MATCH_PROFILE_REVISION_1: UInt32 = 1
NDIS_GFP_HEADER_GROUP_EXACT_MATCH_IS_TTL_ONE: UInt32 = 1
NDIS_GFP_HEADER_GROUP_EXACT_MATCH_REVISION_1: UInt32 = 1
NDIS_GFP_HEADER_GROUP_WILDCARD_MATCH_PROFILE_IS_TTL_ONE: UInt32 = 1
NDIS_GFP_HEADER_GROUP_WILDCARD_MATCH_PROFILE_REVISION_1: UInt32 = 1
NDIS_GFP_WILDCARD_MATCH_PROFILE_REVISION_1: UInt32 = 1
NDIS_GFP_HEADER_GROUP_WILDCARD_MATCH_IS_TTL_ONE: UInt32 = 1
NDIS_GFP_HEADER_GROUP_WILDCARD_MATCH_REVISION_1: UInt32 = 1
NDIS_PD_CAPS_RECEIVE_FILTER_COUNTERS_SUPPORTED: UInt32 = 1
NDIS_PD_CAPS_DRAIN_NOTIFICATIONS_SUPPORTED: UInt32 = 2
NDIS_PD_CAPS_NOTIFICATION_MODERATION_INTERVAL_SUPPORTED: UInt32 = 4
NDIS_PD_CAPS_NOTIFICATION_MODERATION_COUNT_SUPPORTED: UInt32 = 8
NDIS_PD_CAPABILITIES_REVISION_1: UInt32 = 1
NDIS_PD_CONFIG_REVISION_1: UInt32 = 1
NDIS_GFT_UNDEFINED_FLOW_ENTRY_ID: UInt32 = 0
NDIS_GFT_UNDEFINED_TABLE_ID: UInt32 = 0
NDIS_GFT_TABLE_INCLUDE_EXTERNAL_VPPORT: UInt32 = 1
NDIS_GFT_TABLE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_GFT_TABLE_INFO_REVISION_1: UInt32 = 1
NDIS_GFT_TABLE_INFO_ARRAY_REVISION_1: UInt32 = 1
NDIS_GFT_DELETE_TABLE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_GFT_UNDEFINED_COUNTER_ID: UInt32 = 0
NDIS_GFT_MAX_COUNTER_OBJECTS_PER_FLOW_ENTRY: UInt32 = 8
NDIS_GFT_COUNTER_PARAMETERS_CLIENT_SPECIFIED_ADDRESS: UInt32 = 1
NDIS_GFT_COUNTER_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_GFT_FREE_COUNTER_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_GFT_COUNTER_INFO_REVISION_1: UInt32 = 1
NDIS_GFT_COUNTER_INFO_ARRAY_REVISION_1: UInt32 = 1
NDIS_GFT_COUNTER_VALUE_ARRAY_UPDATE_MEMORY_MAPPED_COUNTERS: UInt32 = 1
NDIS_GFT_COUNTER_VALUE_ARRAY_GET_VALUES: UInt32 = 2
NDIS_GFT_COUNTER_VALUE_ARRAY_REVISION_1: UInt32 = 1
NDIS_GFT_STATISTICS_REVISION_1: UInt32 = 1
NDIS_GFT_HEADER_GROUP_TRANSPOSITION_PROFILE_DECREMENT_TTL_IF_NOT_ONE: UInt32 = 1
NDIS_GFT_HEADER_GROUP_TRANSPOSITION_PROFILE_REVISION_1: UInt32 = 1
NDIS_GFT_UNDEFINED_CUSTOM_ACTION: UInt32 = 0
NDIS_GFT_RESERVED_CUSTOM_ACTIONS: UInt32 = 256
NDIS_GFT_CUSTOM_ACTION_PROFILE_REVISION_1: UInt32 = 1
NDIS_GFT_HTP_REDIRECT_TO_INGRESS_QUEUE_OF_VPORT: UInt32 = 1
NDIS_GFT_HTP_REDIRECT_TO_EGRESS_QUEUE_OF_VPORT: UInt32 = 2
NDIS_GFT_HTP_REDIRECT_TO_INGRESS_QUEUE_OF_VPORT_IF_TTL_IS_ONE: UInt32 = 4
NDIS_GFT_HTP_REDIRECT_TO_EGRESS_QUEUE_OF_VPORT_IF_TTL_IS_ONE: UInt32 = 8
NDIS_GFT_HTP_COPY_ALL_PACKETS: UInt32 = 16
NDIS_GFT_HTP_COPY_FIRST_PACKET: UInt32 = 32
NDIS_GFT_HTP_COPY_WHEN_TCP_FLAG_SET: UInt32 = 64
NDIS_GFT_HTP_CUSTOM_ACTION_PRESENT: UInt32 = 128
NDIS_GFT_HTP_META_ACTION_BEFORE_HEADER_TRANSPOSITION: UInt32 = 256
NDIS_GFT_HEADER_TRANSPOSITION_PROFILE_REVISION_1: UInt32 = 1
NDIS_GFT_HEADER_GROUP_TRANSPOSITION_DECREMENT_TTL_IF_NOT_ONE: UInt32 = 1
NDIS_GFT_HEADER_GROUP_TRANSPOSITION_REVISION_1: UInt32 = 1
NDIS_GFT_CUSTOM_ACTION_LAST_ACTION: UInt32 = 1
NDIS_GFT_CUSTOM_ACTION_REVISION_1: UInt32 = 1
NDIS_GFT_EMFE_ADD_IN_ACTIVATED_STATE: UInt32 = 1
NDIS_GFT_EMFE_MATCH_AND_ACTION_MUST_BE_SUPPORTED: UInt32 = 2
NDIS_GFT_EMFE_RDMA_FLOW: UInt32 = 4
NDIS_GFT_EMFE_REDIRECT_TO_INGRESS_QUEUE_OF_VPORT: UInt32 = 4096
NDIS_GFT_EMFE_REDIRECT_TO_EGRESS_QUEUE_OF_VPORT: UInt32 = 8192
NDIS_GFT_EMFE_REDIRECT_TO_INGRESS_QUEUE_OF_VPORT_IF_TTL_IS_ONE: UInt32 = 16384
NDIS_GFT_EMFE_REDIRECT_TO_EGRESS_QUEUE_OF_VPORT_IF_TTL_IS_ONE: UInt32 = 32768
NDIS_GFT_EMFE_COPY_ALL_PACKETS: UInt32 = 65536
NDIS_GFT_EMFE_COPY_FIRST_PACKET: UInt32 = 131072
NDIS_GFT_EMFE_COPY_WHEN_TCP_FLAG_SET: UInt32 = 262144
NDIS_GFT_EMFE_CUSTOM_ACTION_PRESENT: UInt32 = 524288
NDIS_GFT_EMFE_META_ACTION_BEFORE_HEADER_TRANSPOSITION: UInt32 = 1048576
NDIS_GFT_EMFE_COPY_AFTER_TCP_FIN_FLAG_SET: UInt32 = 2097152
NDIS_GFT_EMFE_COPY_AFTER_TCP_RST_FLAG_SET: UInt32 = 4194304
NDIS_GFT_EMFE_COPY_CONDITION_CHANGED: UInt32 = 16777216
NDIS_GFT_EMFE_ALL_VPORT_FLOW_ENTRIES: UInt32 = 33554432
NDIS_GFT_EMFE_COUNTER_ALLOCATE: UInt32 = 1
NDIS_GFT_EMFE_COUNTER_MEMORY_MAPPED: UInt32 = 2
NDIS_GFT_EMFE_COUNTER_CLIENT_SPECIFIED_ADDRESS: UInt32 = 4
NDIS_GFT_EMFE_COUNTER_TRACK_TCP_FLOW: UInt32 = 8
NDIS_GFT_EXACT_MATCH_FLOW_ENTRY_REVISION_1: UInt32 = 1
NDIS_GFT_WCFE_ADD_IN_ACTIVATED_STATE: UInt32 = 1
NDIS_GFT_WCFE_REDIRECT_TO_INGRESS_QUEUE_OF_VPORT: UInt32 = 2
NDIS_GFT_WCFE_REDIRECT_TO_EGRESS_QUEUE_OF_VPORT: UInt32 = 4
NDIS_GFT_WCFE_REDIRECT_TO_INGRESS_QUEUE_OF_VPORT_IF_TTL_IS_ONE: UInt32 = 8
NDIS_GFT_WCFE_REDIRECT_TO_EGRESS_QUEUE_OF_VPORT_IF_TTL_IS_ONE: UInt32 = 16
NDIS_GFT_WCFE_COPY_ALL_PACKETS: UInt32 = 32
NDIS_GFT_WCFE_CUSTOM_ACTION_PRESENT: UInt32 = 64
NDIS_GFT_WCFE_COUNTER_ALLOCATE: UInt32 = 1
NDIS_GFT_WCFE_COUNTER_MEMORY_MAPPED: UInt32 = 2
NDIS_GFT_WCFE_COUNTER_CLIENT_SPECIFIED_ADDRESS: UInt32 = 4
NDIS_GFT_WILDCARD_MATCH_FLOW_ENTRY_REVISION_1: UInt32 = 1
NDIS_GFT_PROFILE_INFO_REVISION_1: UInt32 = 1
NDIS_GFT_PROFILE_INFO_ARRAY_REVISION_1: UInt32 = 1
NDIS_GFT_DELETE_PROFILE_ALL_PROFILES: UInt32 = 1
NDIS_GFT_DELETE_PROFILE_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_GFT_FLOW_ENTRY_ARRAY_REVISION_1: UInt32 = 1
NDIS_GFT_FLOW_ENTRY_INFO_ALL_FLOW_ENTRIES: UInt32 = 1
NDIS_GFT_FLOW_ENTRY_INFO_ARRAY_REVISION_1: UInt32 = 1
NDIS_GFT_FLOW_ENTRY_ID_ALL_NIC_SWITCH_FLOW_ENTRIES: UInt32 = 1
NDIS_GFT_FLOW_ENTRY_ID_ALL_TABLE_FLOW_ENTRIES: UInt32 = 2
NDIS_GFT_FLOW_ENTRY_ID_ALL_VPORT_FLOW_ENTRIES: UInt32 = 4
NDIS_GFT_FLOW_ENTRY_ID_RANGE_DEFINED: UInt32 = 8
NDIS_GFT_FLOW_ENTRY_ID_ARRAY_DEFINED: UInt32 = 16
NDIS_GFT_FLOW_ENTRY_ID_ARRAY_COUNTER_VALUES: UInt32 = 65536
NDIS_GFT_FLOW_ENTRY_ID_ARRAY_REVISION_1: UInt32 = 1
NDIS_GFT_OFFLOAD_PARAMETERS_ENABLE_OFFLOAD: UInt32 = 1
NDIS_GFT_OFFLOAD_PARAMETERS_CUSTOM_PROVIDER_RESERVED: UInt32 = 4278190080
NDIS_GFT_OFFLOAD_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_GFT_OFFLOAD_CAPS_ADD_FLOW_ENTRY_DEACTIVATED_PREFERRED: UInt32 = 1
NDIS_GFT_OFFLOAD_CAPS_RATE_LIMITING_QUEUE_SUPPORTED: UInt32 = 2
NDIS_GFT_OFFLOAD_CAPS_MEMORY_MAPPED_COUNTERS: UInt32 = 1
NDIS_GFT_OFFLOAD_CAPS_MEMORY_MAPPED_PAKCET_AND_BYTE_COUNTERS: UInt32 = 2
NDIS_GFT_OFFLOAD_CAPS_PER_FLOW_ENTRY_COUNTERS: UInt32 = 4
NDIS_GFT_OFFLOAD_CAPS_PER_PACKET_COUNTER_UPDATE: UInt32 = 8
NDIS_GFT_OFFLOAD_CAPS_CLIENT_SPECIFIED_MEMORY_MAPPED_COUNTERS: UInt32 = 16
NDIS_GFT_OFFLOAD_CAPS_INGRESS_AGGREGATE_COUNTERS: UInt32 = 32
NDIS_GFT_OFFLOAD_CAPS_EGRESS_AGGREGATE_COUNTERS: UInt32 = 64
NDIS_GFT_OFFLOAD_CAPS_TRACK_TCP_FLOW_STATE: UInt32 = 128
NDIS_GFT_OFFLOAD_CAPS_COMBINED_COUNTER_AND_STATE: UInt32 = 256
NDIS_GFT_OFFLOAD_CAPS_INGRESS_WILDCARD_MATCH: UInt32 = 1
NDIS_GFT_OFFLOAD_CAPS_EGRESS_WILDCARD_MATCH: UInt32 = 2
NDIS_GFT_OFFLOAD_CAPS_INGRESS_EXACT_MATCH: UInt32 = 4
NDIS_GFT_OFFLOAD_CAPS_EGRESS_EXACT_MATCH: UInt32 = 8
NDIS_GFT_OFFLOAD_CAPS_EXT_VPORT_INGRESS_WILDCARD_MATCH: UInt32 = 16
NDIS_GFT_OFFLOAD_CAPS_EXT_VPORT_EGRESS_WILDCARD_MATCH: UInt32 = 32
NDIS_GFT_OFFLOAD_CAPS_EXT_VPORT_INGRESS_EXACT_MATCH: UInt32 = 64
NDIS_GFT_OFFLOAD_CAPS_EXT_VPORT_EGRESS_EXACT_MATCH: UInt32 = 128
NDIS_GFT_OFFLOAD_CAPS_POP: UInt32 = 1
NDIS_GFT_OFFLOAD_CAPS_PUSH: UInt32 = 2
NDIS_GFT_OFFLOAD_CAPS_MODIFY: UInt32 = 4
NDIS_GFT_OFFLOAD_CAPS_IGNORE_ACTION_SUPPORTED: UInt32 = 8
NDIS_GFT_OFFLOAD_CAPS_REDIRECT_TO_INGRESS_QUEUE_OF_VPORT: UInt32 = 16
NDIS_GFT_OFFLOAD_CAPS_REDIRECT_TO_EGRESS_QUEUE_OF_VPORT: UInt32 = 32
NDIS_GFT_OFFLOAD_CAPS_REDIRECT_TO_INGRESS_QUEUE_OF_VPORT_IF_TTL_IS_ONE: UInt32 = 64
NDIS_GFT_OFFLOAD_CAPS_REDIRECT_TO_EGRESS_QUEUE_OF_VPORT_IF_TTL_IS_ONE: UInt32 = 128
NDIS_GFT_OFFLOAD_CAPS_COPY_ALL: UInt32 = 256
NDIS_GFT_OFFLOAD_CAPS_COPY_FIRST: UInt32 = 512
NDIS_GFT_OFFLOAD_CAPS_COPY_WHEN_TCP_FLAG_SET: UInt32 = 1024
NDIS_GFT_OFFLOAD_CAPS_SAMPLE: UInt32 = 2048
NDIS_GFT_OFFLOAD_CAPS_META_ACTION_BEFORE_HEADER_TRANSPOSITION: UInt32 = 4096
NDIS_GFT_OFFLOAD_CAPS_META_ACTION_AFTER_HEADER_TRANSPOSITION: UInt32 = 8192
NDIS_GFT_OFFLOAD_CAPS_PER_VPORT_EXCEPTION_VPORT: UInt32 = 16384
NDIS_GFT_OFFLOAD_CAPS_DESIGNATED_EXCEPTION_VPORT: UInt32 = 32768
NDIS_GFT_OFFLOAD_CAPS_DSCP_MASK: UInt32 = 65536
NDIS_GFT_OFFLOAD_CAPS_8021P_PRIORITY_MASK: UInt32 = 131072
NDIS_GFT_OFFLOAD_CAPS_ALLOW: UInt32 = 262144
NDIS_GFT_OFFLOAD_CAPS_DROP: UInt32 = 524288
NDIS_GFT_OFFLOAD_CAPABILITIES_REVISION_1: UInt32 = 1
NDIS_GFT_VPORT_ENABLE: UInt32 = 1
NDIS_GFT_VPORT_PARSE_VXLAN: UInt32 = 2
NDIS_GFT_VPORT_PARSE_VXLAN_NOT_IN_SRC_PORT_RANGE: UInt32 = 4
NDIS_GFT_VPORT_ENABLE_STATE_CHANGED: UInt32 = 1048576
NDIS_GFT_VPORT_EXCEPTION_VPORT_CHANGED: UInt32 = 2097152
NDIS_GFT_VPORT_SAMPLING_RATE_CHANGED: UInt32 = 4194304
NDIS_GFT_VPORT_DSCP_MASK_CHANGED: UInt32 = 8388608
NDIS_GFT_VPORT_PRIORITY_MASK_CHANGED: UInt32 = 16777216
NDIS_GFT_VPORT_VXLAN_SETTINGS_CHANGED: UInt32 = 33554432
NDIS_GFT_VPORT_DSCP_FLAGS_CHANGED: UInt32 = 67108864
NDIS_GFT_VPORT_PARAMS_CHANGE_MASK: UInt32 = 4293918720
NDIS_GFT_VPORT_PARAMS_CUSTOM_PROVIDER_RESERVED: UInt32 = 1044480
NDIS_GFT_VPORT_MAX_DSCP_MASK_COUNTER_OBJECTS: UInt32 = 64
NDIS_GFT_VPORT_MAX_PRIORITY_MASK_COUNTER_OBJECTS: UInt32 = 8
NDIS_GFT_VPORT_DSCP_GUARD_ENABLE_RX: UInt32 = 1
NDIS_GFT_VPORT_DSCP_GUARD_ENABLE_TX: UInt32 = 2
NDIS_GFT_VPORT_DSCP_MASK_ENABLE_RX: UInt32 = 4
NDIS_GFT_VPORT_DSCP_MASK_ENABLE_TX: UInt32 = 8
NDIS_GFT_VPORT_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_QOS_DEFAULT_SQ_ID: UInt32 = 0
NDIS_QOS_SQ_PARAMETERS_REVISION_1: UInt32 = 1
NDIS_QOS_SQ_PARAMETERS_REVISION_2: UInt32 = 2
NDIS_QOS_SQ_TRANSMIT_CAP_ENABLED: UInt32 = 1
NDIS_QOS_SQ_TRANSMIT_RESERVATION_ENABLED: UInt32 = 2
NDIS_QOS_SQ_RECEIVE_CAP_ENABLED: UInt32 = 4
NDIS_QOS_SQ_PARAMETERS_ARRAY_REVISION_1: UInt32 = 1
NDIS_QOS_SQ_ARRAY_REVISION_1: UInt32 = 1
NDIS_QOS_OFFLOAD_CAPABILITIES_REVISION_1: UInt32 = 1
NDIS_QOS_OFFLOAD_CAPABILITIES_REVISION_2: UInt32 = 2
NDIS_QOS_OFFLOAD_CAPS_STANDARD_SQ: UInt32 = 1
NDIS_QOS_OFFLOAD_CAPS_GFT_SQ: UInt32 = 2
NDIS_QOS_SQ_STATS_REVISION_1: UInt32 = 1
NDIS_TIMESTAMP_CAPABILITIES_REVISION_1: UInt32 = 1
OID_TIMESTAMP_CAPABILITY: UInt32 = 10485761
OID_TIMESTAMP_CURRENT_CONFIG: UInt32 = 10485762
NDIS_HARDWARE_CROSSTIMESTAMP_REVISION_1: UInt32 = 1
OID_TIMESTAMP_GET_CROSSTIMESTAMP: UInt32 = 10485763
NdisHashFunctionToeplitz: UInt32 = 1
NdisHashFunctionReserved1: UInt32 = 2
NdisHashFunctionReserved2: UInt32 = 4
NdisHashFunctionReserved3: UInt32 = 8
NDIS_HASH_FUNCTION_MASK: UInt32 = 255
NDIS_HASH_TYPE_MASK: UInt32 = 16776960
NDIS_HASH_IPV4: UInt32 = 256
NDIS_HASH_TCP_IPV4: UInt32 = 512
NDIS_HASH_IPV6: UInt32 = 1024
NDIS_HASH_IPV6_EX: UInt32 = 2048
NDIS_HASH_TCP_IPV6: UInt32 = 4096
NDIS_HASH_TCP_IPV6_EX: UInt32 = 8192
NDIS_HASH_UDP_IPV4: UInt32 = 16384
NDIS_HASH_UDP_IPV6: UInt32 = 32768
NDIS_HASH_UDP_IPV6_EX: UInt32 = 65536
DD_NDIS_DEVICE_NAME: String = '\\Device\\NDIS'
NDIS_MAXIMUM_PORTS: UInt32 = 16777216
NDIS_OBJECT_REVISION_1: UInt32 = 1
NDIS_OFFLOAD_NOT_SUPPORTED: UInt32 = 0
NDIS_OFFLOAD_SUPPORTED: UInt32 = 1
NDIS_OFFLOAD_SET_NO_CHANGE: UInt32 = 0
NDIS_OFFLOAD_SET_ON: UInt32 = 1
NDIS_OFFLOAD_SET_OFF: UInt32 = 2
NDIS_ENCAPSULATION_NOT_SUPPORTED: UInt32 = 0
NDIS_ENCAPSULATION_NULL: UInt32 = 1
NDIS_ENCAPSULATION_IEEE_802_3: UInt32 = 2
NDIS_ENCAPSULATION_IEEE_802_3_P_AND_Q: UInt32 = 4
NDIS_ENCAPSULATION_IEEE_802_3_P_AND_Q_IN_OOB: UInt32 = 8
NDIS_ENCAPSULATION_IEEE_LLC_SNAP_ROUTED: UInt32 = 16
NDIS_OBJECT_TYPE_OID_REQUEST: UInt32 = 150
NDIS_SUPPORT_NDIS687: UInt32 = 1
NDIS_SUPPORT_NDIS686: UInt32 = 1
NDIS_SUPPORT_NDIS685: UInt32 = 1
NDIS_SUPPORT_NDIS684: UInt32 = 1
NDIS_SUPPORT_NDIS683: UInt32 = 1
NDIS_SUPPORT_NDIS682: UInt32 = 1
NDIS_SUPPORT_NDIS681: UInt32 = 1
NDIS_SUPPORT_NDIS680: UInt32 = 1
NDIS_SUPPORT_NDIS670: UInt32 = 1
NDIS_SUPPORT_NDIS660: UInt32 = 1
NDIS_SUPPORT_NDIS651: UInt32 = 1
NDIS_SUPPORT_NDIS650: UInt32 = 1
NDIS_SUPPORT_NDIS640: UInt32 = 1
NDIS_SUPPORT_NDIS630: UInt32 = 1
NDIS_SUPPORT_NDIS620: UInt32 = 1
NDIS_SUPPORT_NDIS61: UInt32 = 1
NDIS_SUPPORT_NDIS6: UInt32 = 1
GUID_NDIS_LAN_CLASS: Guid = Guid('{ad498944-762f-11d0-8dcb-00c04fc3358c}')
GUID_DEVINTERFACE_NET: Guid = Guid('{cac88484-7515-4c03-82e6-71a87abac361}')
UNSPECIFIED_NETWORK_GUID: Guid = Guid('{12ba5bde-143e-4c0d-b66d-2379bb141913}')
GUID_DEVINTERFACE_NETUIO: Guid = Guid('{08336f60-0679-4c6c-85d2-ae7ced65fff7}')
GUID_NDIS_ENUMERATE_ADAPTER: Guid = Guid('{981f2d7f-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_NOTIFY_ADAPTER_REMOVAL: Guid = Guid('{981f2d80-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_NOTIFY_ADAPTER_ARRIVAL: Guid = Guid('{981f2d81-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_ENUMERATE_VC: Guid = Guid('{981f2d82-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_NOTIFY_VC_REMOVAL: Guid = Guid('{981f2d79-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_NOTIFY_VC_ARRIVAL: Guid = Guid('{182f9e0c-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_NOTIFY_BIND: Guid = Guid('{5413531c-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_NOTIFY_UNBIND: Guid = Guid('{6e3ce1ec-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_WAKE_ON_MAGIC_PACKET_ONLY: Guid = Guid('{a14f1c97-8839-4f8a-9996-a28996ebbf1d}')
GUID_NDIS_NOTIFY_DEVICE_POWER_ON: Guid = Guid('{5f81cfd0-f046-4342-af61-895acedaefd9}')
GUID_NDIS_NOTIFY_DEVICE_POWER_OFF: Guid = Guid('{81bc8189-b026-46ab-b964-f182e342934e}')
GUID_NDIS_NOTIFY_FILTER_REMOVAL: Guid = Guid('{1f177cd9-5955-4721-9f6a-78ebdfaef889}')
GUID_NDIS_NOTIFY_FILTER_ARRIVAL: Guid = Guid('{0b6d3c89-5917-43ca-b578-d01a7967c41c}')
GUID_NDIS_NOTIFY_DEVICE_POWER_ON_EX: Guid = Guid('{2b440188-92ac-4f60-9b2d-20a30cbb6bbe}')
GUID_NDIS_NOTIFY_DEVICE_POWER_OFF_EX: Guid = Guid('{4159353c-5cd7-42ce-8fe4-a45a2380cc4f}')
GUID_NDIS_PM_ADMIN_CONFIG: Guid = Guid('{1528d111-708a-4ca4-9215-c05771161cda}')
GUID_NDIS_PM_ACTIVE_CAPABILITIES: Guid = Guid('{b2cf76e3-b3ae-4394-a01f-338c9870e939}')
GUID_NDIS_RSS_ENABLED: Guid = Guid('{9565cd55-3402-4e32-a5b6-2f143f2f2c30}')
GUID_NDIS_GEN_HARDWARE_STATUS: Guid = Guid('{5ec10354-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_MEDIA_SUPPORTED: Guid = Guid('{5ec10355-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_MEDIA_IN_USE: Guid = Guid('{5ec10356-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_MAXIMUM_LOOKAHEAD: Guid = Guid('{5ec10357-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_MAXIMUM_FRAME_SIZE: Guid = Guid('{5ec10358-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_LINK_SPEED: Guid = Guid('{5ec10359-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_TRANSMIT_BUFFER_SPACE: Guid = Guid('{5ec1035a-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_RECEIVE_BUFFER_SPACE: Guid = Guid('{5ec1035b-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_TRANSMIT_BLOCK_SIZE: Guid = Guid('{5ec1035c-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_RECEIVE_BLOCK_SIZE: Guid = Guid('{5ec1035d-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_VENDOR_ID: Guid = Guid('{5ec1035e-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_VENDOR_DESCRIPTION: Guid = Guid('{5ec1035f-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_CURRENT_PACKET_FILTER: Guid = Guid('{5ec10360-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_CURRENT_LOOKAHEAD: Guid = Guid('{5ec10361-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_DRIVER_VERSION: Guid = Guid('{5ec10362-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_MAXIMUM_TOTAL_SIZE: Guid = Guid('{5ec10363-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_MAC_OPTIONS: Guid = Guid('{5ec10365-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_MEDIA_CONNECT_STATUS: Guid = Guid('{5ec10366-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_MAXIMUM_SEND_PACKETS: Guid = Guid('{5ec10367-a61a-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_VENDOR_DRIVER_VERSION: Guid = Guid('{447956f9-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_VLAN_ID: Guid = Guid('{765dc702-c5e8-4b67-843b-3f5a4ff2648b}')
GUID_NDIS_GEN_PHYSICAL_MEDIUM: Guid = Guid('{418ca16d-3937-4208-940a-ec6196278085}')
GUID_NDIS_TCP_OFFLOAD_CURRENT_CONFIG: Guid = Guid('{68542fed-5c74-461e-8934-91c6f9c60960}')
GUID_NDIS_TCP_OFFLOAD_HARDWARE_CAPABILITIES: Guid = Guid('{cd5f1102-590f-4ada-ab65-5b31b1dc0172}')
GUID_NDIS_TCP_OFFLOAD_PARAMETERS: Guid = Guid('{8ead9a22-7f69-4bc6-949a-c8187b074e61}')
GUID_NDIS_TCP_CONNECTION_OFFLOAD_CURRENT_CONFIG: Guid = Guid('{2ee6aef1-0851-458b-bf0d-792343d1cde1}')
GUID_NDIS_TCP_CONNECTION_OFFLOAD_HARDWARE_CAPABILITIES: Guid = Guid('{8ce71f2c-d63a-4390-a487-18fa47262ceb}')
GUID_NDIS_RECEIVE_SCALE_CAPABILITIES: Guid = Guid('{26c28774-4252-48fe-a610-a58a398c0eb1}')
GUID_NDIS_GEN_LINK_STATE: Guid = Guid('{ba1f4c14-a945-4762-b916-0b5515b6f43a}')
GUID_NDIS_GEN_LINK_PARAMETERS: Guid = Guid('{8c7d3579-252b-4614-82c5-a650daa15049}')
GUID_NDIS_GEN_STATISTICS: Guid = Guid('{368c45b5-c129-43c1-939e-7edc2d7fe621}')
GUID_NDIS_GEN_PORT_STATE: Guid = Guid('{6fbf2a5f-8b8f-4920-8143-e6c460f52524}')
GUID_NDIS_GEN_ENUMERATE_PORTS: Guid = Guid('{f1d6abe8-15e4-4407-81b7-6b830c777cd9}')
GUID_NDIS_ENUMERATE_ADAPTERS_EX: Guid = Guid('{16716917-4306-4be4-9b5a-3809ae44b125}')
GUID_NDIS_GEN_PORT_AUTHENTICATION_PARAMETERS: Guid = Guid('{aab6ac31-86fb-48fb-8b48-63db235ace16}')
GUID_NDIS_GEN_INTERRUPT_MODERATION: Guid = Guid('{d9c8eea5-f16e-467c-84d5-6345a22ce213}')
GUID_NDIS_GEN_INTERRUPT_MODERATION_PARAMETERS: Guid = Guid('{d789adfa-9c56-433b-ad01-7574f3cedbe9}')
GUID_NDIS_GEN_PCI_DEVICE_CUSTOM_PROPERTIES: Guid = Guid('{aa39f5ab-e260-4d01-82b0-b737c880ea05}')
GUID_NDIS_GEN_PHYSICAL_MEDIUM_EX: Guid = Guid('{899e7782-035b-43f9-8bb6-2b58971612e5}')
GUID_NDIS_HD_SPLIT_CURRENT_CONFIG: Guid = Guid('{81d1303c-ab00-4e49-80b1-5e6e0bf9be53}')
GUID_NDIS_HD_SPLIT_PARAMETERS: Guid = Guid('{8c048bea-2913-4458-b68e-17f6c1e5c60e}')
GUID_NDIS_TCP_RSC_STATISTICS: Guid = Guid('{83104445-9b5d-4ee6-a2a5-2bd3fb3c36af}')
GUID_PM_HARDWARE_CAPABILITIES: Guid = Guid('{ece5360d-3291-4a6e-8044-00511fed27ee}')
GUID_PM_CURRENT_CAPABILITIES: Guid = Guid('{3abdbd14-d44a-4a3f-9a63-a0a42a51b131}')
GUID_PM_PARAMETERS: Guid = Guid('{560245d2-e251-409c-a280-311935be3b28}')
GUID_PM_ADD_WOL_PATTERN: Guid = Guid('{6fc83ba7-52bc-4faa-ac51-7d2ffe63ba90}')
GUID_PM_REMOVE_WOL_PATTERN: Guid = Guid('{a037a915-c6ca-4322-b3e3-ef754ec498dc}')
GUID_PM_WOL_PATTERN_LIST: Guid = Guid('{4022be37-7ee2-47be-a5a5-050fc79afc75}')
GUID_PM_ADD_PROTOCOL_OFFLOAD: Guid = Guid('{0c06c112-0d93-439b-9e6d-26be130c9784}')
GUID_PM_GET_PROTOCOL_OFFLOAD: Guid = Guid('{a6435cd9-149f-498e-951b-2d94bea3e3a3}')
GUID_PM_REMOVE_PROTOCOL_OFFLOAD: Guid = Guid('{decd7be2-a6b0-43ca-ae45-d000d20e5265}')
GUID_PM_PROTOCOL_OFFLOAD_LIST: Guid = Guid('{736ec5ab-ca8f-4043-bb58-da402a48d9cc}')
GUID_NDIS_RECEIVE_FILTER_HARDWARE_CAPABILITIES: Guid = Guid('{3f2c1419-83bc-11dd-94b8-001d09162bc3}')
GUID_NDIS_RECEIVE_FILTER_GLOBAL_PARAMETERS: Guid = Guid('{3f2c141a-83bc-11dd-94b8-001d09162bc3}')
GUID_NDIS_RECEIVE_FILTER_ENUM_QUEUES: Guid = Guid('{3f2c141b-83bc-11dd-94b8-001d09162bc3}')
GUID_NDIS_RECEIVE_FILTER_QUEUE_PARAMETERS: Guid = Guid('{3f2c141c-83bc-11dd-94b8-001d09162bc3}')
GUID_NDIS_RECEIVE_FILTER_ENUM_FILTERS: Guid = Guid('{3f2c141d-83bc-11dd-94b8-001d09162bc3}')
GUID_NDIS_RECEIVE_FILTER_PARAMETERS: Guid = Guid('{3f2c141e-83bc-11dd-94b8-001d09162bc3}')
GUID_RECEIVE_FILTER_CURRENT_CAPABILITIES: Guid = Guid('{4054e80f-2bc1-4ccc-b033-4abc0c4a1e8c}')
GUID_NIC_SWITCH_HARDWARE_CAPABILITIES: Guid = Guid('{37cab40c-d1e8-4301-8c1d-58465e0c4c0f}')
GUID_NIC_SWITCH_CURRENT_CAPABILITIES: Guid = Guid('{e76fdaf3-0be7-4d95-87e9-5aead4b590e9}')
GUID_NDIS_SWITCH_MICROSOFT_VENDOR_ID: Guid = Guid('{202547fe-1c9c-40b9-bba1-08ada1f98b3c}')
GUID_NDIS_SWITCH_PORT_PROPERTY_PROFILE_ID_DEFAULT_EXTERNAL_NIC: Guid = Guid('{0b347846-0a0c-470a-9b7a-0d965850698f}')
GUID_NDIS_GEN_XMIT_OK: Guid = Guid('{447956fa-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_RCV_OK: Guid = Guid('{447956fb-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_XMIT_ERROR: Guid = Guid('{447956fc-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_RCV_ERROR: Guid = Guid('{447956fd-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_RCV_NO_BUFFER: Guid = Guid('{447956fe-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_GEN_CO_HARDWARE_STATUS: Guid = Guid('{791ad192-e35c-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_MEDIA_SUPPORTED: Guid = Guid('{791ad193-e35c-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_MEDIA_IN_USE: Guid = Guid('{791ad194-e35c-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_LINK_SPEED: Guid = Guid('{791ad195-e35c-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_VENDOR_ID: Guid = Guid('{791ad196-e35c-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_VENDOR_DESCRIPTION: Guid = Guid('{791ad197-e35c-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_DRIVER_VERSION: Guid = Guid('{791ad198-e35c-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_MAC_OPTIONS: Guid = Guid('{791ad19a-e35c-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_MEDIA_CONNECT_STATUS: Guid = Guid('{791ad19b-e35c-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_VENDOR_DRIVER_VERSION: Guid = Guid('{791ad19c-e35c-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_MINIMUM_LINK_SPEED: Guid = Guid('{791ad19d-e35c-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_XMIT_PDUS_OK: Guid = Guid('{0a214805-e35f-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_RCV_PDUS_OK: Guid = Guid('{0a214806-e35f-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_XMIT_PDUS_ERROR: Guid = Guid('{0a214807-e35f-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_RCV_PDUS_ERROR: Guid = Guid('{0a214808-e35f-11d0-9692-00c04fc3358c}')
GUID_NDIS_GEN_CO_RCV_PDUS_NO_BUFFER: Guid = Guid('{0a214809-e35f-11d0-9692-00c04fc3358c}')
GUID_NDIS_802_3_PERMANENT_ADDRESS: Guid = Guid('{447956ff-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_3_CURRENT_ADDRESS: Guid = Guid('{44795700-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_3_MULTICAST_LIST: Guid = Guid('{44795701-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_3_MAXIMUM_LIST_SIZE: Guid = Guid('{44795702-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_3_MAC_OPTIONS: Guid = Guid('{44795703-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_3_RCV_ERROR_ALIGNMENT: Guid = Guid('{44795704-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_3_XMIT_ONE_COLLISION: Guid = Guid('{44795705-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_3_XMIT_MORE_COLLISIONS: Guid = Guid('{44795706-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_5_PERMANENT_ADDRESS: Guid = Guid('{44795707-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_5_CURRENT_ADDRESS: Guid = Guid('{44795708-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_5_CURRENT_FUNCTIONAL: Guid = Guid('{44795709-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_5_CURRENT_GROUP: Guid = Guid('{4479570a-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_5_LAST_OPEN_STATUS: Guid = Guid('{4479570b-a61b-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_5_CURRENT_RING_STATUS: Guid = Guid('{890a36ec-a61c-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_5_CURRENT_RING_STATE: Guid = Guid('{acf14032-a61c-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_5_LINE_ERRORS: Guid = Guid('{acf14033-a61c-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_5_LOST_FRAMES: Guid = Guid('{acf14034-a61c-11d0-8dd4-00c04fc3358c}')
GUID_NDIS_802_11_BSSID: Guid = Guid('{2504b6c2-1fa5-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_SSID: Guid = Guid('{7d2a90ea-2041-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_NETWORK_TYPES_SUPPORTED: Guid = Guid('{8531d6e6-2041-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_NETWORK_TYPE_IN_USE: Guid = Guid('{857e2326-2041-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_POWER_MODE: Guid = Guid('{85be837c-2041-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_TX_POWER_LEVEL: Guid = Guid('{11e6ba76-2053-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_RSSI: Guid = Guid('{1507db16-2053-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_RSSI_TRIGGER: Guid = Guid('{155689b8-2053-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_BSSID_LIST: Guid = Guid('{69526f9a-2062-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_INFRASTRUCTURE_MODE: Guid = Guid('{697d5a7e-2062-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_FRAGMENTATION_THRESHOLD: Guid = Guid('{69aaa7c4-2062-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_RTS_THRESHOLD: Guid = Guid('{0134d07e-2064-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_NUMBER_OF_ANTENNAS: Guid = Guid('{01779336-2064-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_RX_ANTENNA_SELECTED: Guid = Guid('{01ac07a2-2064-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_TX_ANTENNA_SELECTED: Guid = Guid('{01dbb74a-2064-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_SUPPORTED_RATES: Guid = Guid('{49db8722-2068-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_DESIRED_RATES: Guid = Guid('{452ee08e-2536-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_CONFIGURATION: Guid = Guid('{4a4df982-2068-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_STATISTICS: Guid = Guid('{42bb73b0-2129-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_ADD_WEP: Guid = Guid('{4307bff0-2129-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_REMOVE_WEP: Guid = Guid('{433c345c-2129-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_DISASSOCIATE: Guid = Guid('{43671f40-2129-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_AUTHENTICATION_MODE: Guid = Guid('{43920a24-2129-11d4-97eb-00c04f79c403}')
GUID_NDIS_802_11_PRIVACY_FILTER: Guid = Guid('{6733c4e9-4792-11d4-97f1-00c04f79c403}')
GUID_NDIS_802_11_BSSID_LIST_SCAN: Guid = Guid('{0d9e01e1-ba70-11d4-b675-002048570337}')
GUID_NDIS_802_11_WEP_STATUS: Guid = Guid('{b027a21f-3cfa-4125-800b-3f7a18fddcdc}')
GUID_NDIS_802_11_RELOAD_DEFAULTS: Guid = Guid('{748b14e8-32ee-4425-b91b-c9848c58b55a}')
GUID_NDIS_802_11_ADD_KEY: Guid = Guid('{ab8b5a62-1d51-49d8-ba5c-fa980be03a1d}')
GUID_NDIS_802_11_REMOVE_KEY: Guid = Guid('{73cb28e9-3188-42d5-b553-b21237e6088c}')
GUID_NDIS_802_11_ASSOCIATION_INFORMATION: Guid = Guid('{a08d4dd0-960e-40bd-8cf6-c538af98f2e3}')
GUID_NDIS_802_11_TEST: Guid = Guid('{4b9ca16a-6a60-4e9d-920c-6335953fa0b5}')
GUID_NDIS_802_11_MEDIA_STREAM_MODE: Guid = Guid('{0a56af66-d84b-49eb-a28d-5282cbb6d0cd}')
GUID_NDIS_STATUS_RESET_START: Guid = Guid('{981f2d76-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_STATUS_RESET_END: Guid = Guid('{981f2d77-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_STATUS_MEDIA_CONNECT: Guid = Guid('{981f2d7d-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_STATUS_MEDIA_DISCONNECT: Guid = Guid('{981f2d7e-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_STATUS_MEDIA_SPECIFIC_INDICATION: Guid = Guid('{981f2d84-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_STATUS_LINK_SPEED_CHANGE: Guid = Guid('{981f2d85-b1f3-11d0-8dd7-00c04fc3358c}')
GUID_NDIS_STATUS_PACKET_FILTER: Guid = Guid('{d47c5407-2e75-46dd-8146-1d7ed2d6ab1d}')
GUID_NDIS_STATUS_NETWORK_CHANGE: Guid = Guid('{ca8a56f9-ce81-40e6-a70f-a067a476e9e9}')
GUID_NDIS_STATUS_TASK_OFFLOAD_CURRENT_CONFIG: Guid = Guid('{45049fc6-54d8-40c8-9c3d-b011c4e715bc}')
GUID_NDIS_STATUS_TASK_OFFLOAD_HARDWARE_CAPABILITIES: Guid = Guid('{b6b8158b-217c-4b2a-be86-6a04beea65b8}')
GUID_NDIS_STATUS_TCP_CONNECTION_OFFLOAD_CURRENT_CONFIG: Guid = Guid('{f8edaeff-24e4-4ae6-a413-0b27f76b243d}')
GUID_NDIS_STATUS_TCP_CONNECTION_OFFLOAD_HARDWARE_CAPABILITIES: Guid = Guid('{391969b6-402c-43bf-8922-39eae0da1bb5}')
GUID_NDIS_STATUS_OPER_STATUS: Guid = Guid('{f917b663-845e-4d3d-b6d4-15eb27af81c5}')
GUID_NDIS_STATUS_LINK_STATE: Guid = Guid('{64c6f797-878c-4311-9246-65dba89c3a61}')
GUID_NDIS_STATUS_PORT_STATE: Guid = Guid('{1dac0dfe-43e5-44b7-b759-7bf46de32e81}')
GUID_NDIS_STATUS_EXTERNAL_CONNECTIVITY_CHANGE: Guid = Guid('{fd306974-c420-4433-b0fe-4cf6a613f59f}')
GUID_STATUS_MEDIA_SPECIFIC_INDICATION_EX: Guid = Guid('{aaacfca7-954a-4632-a16e-a8a63793a9e5}')
GUID_NDIS_STATUS_HD_SPLIT_CURRENT_CONFIG: Guid = Guid('{6c744b0e-ee9c-4205-90a2-015f6d65f403}')
GUID_NDIS_STATUS_PM_WOL_PATTERN_REJECTED: Guid = Guid('{f72cf68e-18d4-4d63-9a19-e69b13916b1a}')
GUID_NDIS_STATUS_PM_OFFLOAD_REJECTED: Guid = Guid('{add1d481-711e-4d1a-92ca-a62db9329712}')
GUID_NDIS_STATUS_PM_WAKE_REASON: Guid = Guid('{0933fd58-ca62-438f-83da-dfc1cccb8145}')
GUID_NDIS_STATUS_DOT11_SCAN_CONFIRM: Guid = Guid('{8500591e-a0c7-4efb-9342-b674b002cbe6}')
GUID_NDIS_STATUS_DOT11_MPDU_MAX_LENGTH_CHANGED: Guid = Guid('{1d6560ec-8e48-4a3e-9fd5-a01b698db6c5}')
GUID_NDIS_STATUS_DOT11_ASSOCIATION_START: Guid = Guid('{3927843b-6980-4b48-b15b-4de50977ac40}')
GUID_NDIS_STATUS_DOT11_ASSOCIATION_COMPLETION: Guid = Guid('{458bbea7-45a4-4ae2-b176-e51f96fc0568}')
GUID_NDIS_STATUS_DOT11_CONNECTION_START: Guid = Guid('{7b74299d-998f-4454-ad08-c5af28576d1b}')
GUID_NDIS_STATUS_DOT11_CONNECTION_COMPLETION: Guid = Guid('{96efd9c9-7f1b-4a89-bc04-3e9e271765f1}')
GUID_NDIS_STATUS_DOT11_ROAMING_START: Guid = Guid('{b2412d0d-26c8-4f4e-93df-f7b705a0b433}')
GUID_NDIS_STATUS_DOT11_ROAMING_COMPLETION: Guid = Guid('{dd9d47d1-282b-41e4-b924-66368817fcd3}')
GUID_NDIS_STATUS_DOT11_DISASSOCIATION: Guid = Guid('{3fbeb6fc-0fe2-43fd-b2ad-bd99b5f93e13}')
GUID_NDIS_STATUS_DOT11_TKIPMIC_FAILURE: Guid = Guid('{442c2ae4-9bc5-4b90-a889-455ef220f4ee}')
GUID_NDIS_STATUS_DOT11_PMKID_CANDIDATE_LIST: Guid = Guid('{26d8b8f6-db82-49eb-8bf3-4c130ef06950}')
GUID_NDIS_STATUS_DOT11_PHY_STATE_CHANGED: Guid = Guid('{deb45316-71b5-4736-bdef-0a9e9f4e62dc}')
GUID_NDIS_STATUS_DOT11_LINK_QUALITY: Guid = Guid('{a3285184-ea99-48ed-825e-a426b11c2754}')
NDK_ADAPTER_FLAG_IN_ORDER_DMA_SUPPORTED: UInt32 = 1
NDK_ADAPTER_FLAG_RDMA_READ_SINK_NOT_REQUIRED: UInt32 = 2
NDK_ADAPTER_FLAG_CQ_INTERRUPT_MODERATION_SUPPORTED: UInt32 = 4
NDK_ADAPTER_FLAG_MULTI_ENGINE_SUPPORTED: UInt32 = 8
NDK_ADAPTER_FLAG_RDMA_READ_LOCAL_INVALIDATE_SUPPORTED: UInt32 = 16
NDK_ADAPTER_FLAG_CQ_RESIZE_SUPPORTED: UInt32 = 256
NDK_ADAPTER_FLAG_LOOPBACK_CONNECTIONS_SUPPORTED: UInt32 = 65536
NET_IF_OPER_STATUS_DOWN_NOT_AUTHENTICATED: UInt32 = 1
NET_IF_OPER_STATUS_DOWN_NOT_MEDIA_CONNECTED: UInt32 = 2
NET_IF_OPER_STATUS_DORMANT_PAUSED: UInt32 = 4
NET_IF_OPER_STATUS_DORMANT_LOW_POWER: UInt32 = 8
NET_IF_OID_IF_ALIAS: UInt32 = 1
NET_IF_OID_COMPARTMENT_ID: UInt32 = 2
NET_IF_OID_NETWORK_GUID: UInt32 = 3
NET_IF_OID_IF_ENTRY: UInt32 = 4
NET_SITEID_UNSPECIFIED: UInt32 = 0
NET_SITEID_MAXUSER: UInt32 = 134217727
NET_SITEID_MAXSYSTEM: UInt32 = 268435455
NET_IFLUID_UNSPECIFIED: UInt32 = 0
NIIF_HARDWARE_INTERFACE: UInt32 = 1
NIIF_FILTER_INTERFACE: UInt32 = 2
NIIF_NDIS_RESERVED1: UInt32 = 4
NIIF_NDIS_RESERVED2: UInt32 = 8
NIIF_NDIS_RESERVED3: UInt32 = 16
NIIF_NDIS_WDM_INTERFACE: UInt32 = 32
NIIF_NDIS_ENDPOINT_INTERFACE: UInt32 = 64
NIIF_NDIS_ISCSI_INTERFACE: UInt32 = 128
NIIF_NDIS_RESERVED4: UInt32 = 256
IF_MAX_STRING_SIZE: UInt32 = 256
IF_MAX_PHYS_ADDRESS_LENGTH: UInt32 = 32
class BSSID_INFO(Structure):
    BSSID: Byte * 6
    PMKID: Byte * 16
class GEN_GET_NETCARD_TIME(Structure):
    ReadTime: UInt64
class GEN_GET_TIME_CAPS(Structure):
    Flags: UInt32
    ClockPrecision: UInt32
IF_ADMINISTRATIVE_STATE = Int32
IF_ADMINISTRATIVE_DISABLED: win32more.Windows.Win32.NetworkManagement.Ndis.IF_ADMINISTRATIVE_STATE = 0
IF_ADMINISTRATIVE_ENABLED: win32more.Windows.Win32.NetworkManagement.Ndis.IF_ADMINISTRATIVE_STATE = 1
IF_ADMINISTRATIVE_DEMANDDIAL: win32more.Windows.Win32.NetworkManagement.Ndis.IF_ADMINISTRATIVE_STATE = 2
class IF_COUNTED_STRING_LH(Structure):
    Length: UInt16
    String: Char * 257
IF_OPER_STATUS = Int32
IfOperStatusUp: win32more.Windows.Win32.NetworkManagement.Ndis.IF_OPER_STATUS = 1
IfOperStatusDown: win32more.Windows.Win32.NetworkManagement.Ndis.IF_OPER_STATUS = 2
IfOperStatusTesting: win32more.Windows.Win32.NetworkManagement.Ndis.IF_OPER_STATUS = 3
IfOperStatusUnknown: win32more.Windows.Win32.NetworkManagement.Ndis.IF_OPER_STATUS = 4
IfOperStatusDormant: win32more.Windows.Win32.NetworkManagement.Ndis.IF_OPER_STATUS = 5
IfOperStatusNotPresent: win32more.Windows.Win32.NetworkManagement.Ndis.IF_OPER_STATUS = 6
IfOperStatusLowerLayerDown: win32more.Windows.Win32.NetworkManagement.Ndis.IF_OPER_STATUS = 7
class IF_PHYSICAL_ADDRESS_LH(Structure):
    Length: UInt16
    Address: Byte * 32
class NDIS_802_11_AI_REQFI(Structure):
    Capabilities: UInt16
    ListenInterval: UInt16
    CurrentAPAddress: Byte * 6
class NDIS_802_11_AI_RESFI(Structure):
    Capabilities: UInt16
    StatusCode: UInt16
    AssociationId: UInt16
class NDIS_802_11_ASSOCIATION_INFORMATION(Structure):
    Length: UInt32
    AvailableRequestFixedIEs: UInt16
    RequestFixedIEs: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AI_REQFI
    RequestIELength: UInt32
    OffsetRequestIEs: UInt32
    AvailableResponseFixedIEs: UInt16
    ResponseFixedIEs: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AI_RESFI
    ResponseIELength: UInt32
    OffsetResponseIEs: UInt32
class NDIS_802_11_AUTHENTICATION_ENCRYPTION(Structure):
    AuthModeSupported: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE
    EncryptStatusSupported: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_WEP_STATUS
class NDIS_802_11_AUTHENTICATION_EVENT(Structure):
    Status: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_STATUS_INDICATION
    Request: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_REQUEST * 1
NDIS_802_11_AUTHENTICATION_MODE = Int32
Ndis802_11AuthModeOpen: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE = 0
Ndis802_11AuthModeShared: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE = 1
Ndis802_11AuthModeAutoSwitch: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE = 2
Ndis802_11AuthModeWPA: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE = 3
Ndis802_11AuthModeWPAPSK: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE = 4
Ndis802_11AuthModeWPANone: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE = 5
Ndis802_11AuthModeWPA2: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE = 6
Ndis802_11AuthModeWPA2PSK: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE = 7
Ndis802_11AuthModeWPA3: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE = 8
Ndis802_11AuthModeWPA3Ent192: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE = 8
Ndis802_11AuthModeWPA3SAE: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE = 9
Ndis802_11AuthModeWPA3Ent: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE = 10
Ndis802_11AuthModeMax: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_MODE = 11
class NDIS_802_11_AUTHENTICATION_REQUEST(Structure):
    Length: UInt32
    Bssid: Byte * 6
    Flags: UInt32
class NDIS_802_11_BSSID_LIST(Structure):
    NumberOfItems: UInt32
    Bssid: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WLAN_BSSID * 1
class NDIS_802_11_BSSID_LIST_EX(Structure):
    NumberOfItems: UInt32
    Bssid: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WLAN_BSSID_EX * 1
class NDIS_802_11_CAPABILITY(Structure):
    Length: UInt32
    Version: UInt32
    NoOfPMKIDs: UInt32
    NoOfAuthEncryptPairsSupported: UInt32
    AuthenticationEncryptionSupported: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_ENCRYPTION * 1
class NDIS_802_11_CONFIGURATION(Structure):
    Length: UInt32
    BeaconPeriod: UInt32
    ATIMWindow: UInt32
    DSConfig: UInt32
    FHConfig: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_CONFIGURATION_FH
class NDIS_802_11_CONFIGURATION_FH(Structure):
    Length: UInt32
    HopPattern: UInt32
    HopSet: UInt32
    DwellTime: UInt32
class NDIS_802_11_FIXED_IEs(Structure):
    Timestamp: Byte * 8
    BeaconInterval: UInt16
    Capabilities: UInt16
class NDIS_802_11_KEY(Structure):
    Length: UInt32
    KeyIndex: UInt32
    KeyLength: UInt32
    BSSID: Byte * 6
    KeyRSC: UInt64
    KeyMaterial: Byte * 1
NDIS_802_11_MEDIA_STREAM_MODE = Int32
Ndis802_11MediaStreamOff: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_MEDIA_STREAM_MODE = 0
Ndis802_11MediaStreamOn: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_MEDIA_STREAM_MODE = 1
NDIS_802_11_NETWORK_INFRASTRUCTURE = Int32
Ndis802_11IBSS: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_INFRASTRUCTURE = 0
Ndis802_11Infrastructure: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_INFRASTRUCTURE = 1
Ndis802_11AutoUnknown: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_INFRASTRUCTURE = 2
Ndis802_11InfrastructureMax: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_INFRASTRUCTURE = 3
NDIS_802_11_NETWORK_TYPE = Int32
Ndis802_11FH: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_TYPE = 0
Ndis802_11DS: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_TYPE = 1
Ndis802_11OFDM5: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_TYPE = 2
Ndis802_11OFDM24: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_TYPE = 3
Ndis802_11Automode: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_TYPE = 4
Ndis802_11NetworkTypeMax: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_TYPE = 5
class NDIS_802_11_NETWORK_TYPE_LIST(Structure):
    NumberOfItems: UInt32
    NetworkType: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_TYPE * 1
class NDIS_802_11_NON_BCAST_SSID_LIST(Structure):
    NumberOfItems: UInt32
    Non_Bcast_Ssid: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_SSID * 1
class NDIS_802_11_PMKID(Structure):
    Length: UInt32
    BSSIDInfoCount: UInt32
    BSSIDInfo: win32more.Windows.Win32.NetworkManagement.Ndis.BSSID_INFO * 1
class NDIS_802_11_PMKID_CANDIDATE_LIST(Structure):
    Version: UInt32
    NumCandidates: UInt32
    CandidateList: win32more.Windows.Win32.NetworkManagement.Ndis.PMKID_CANDIDATE * 1
NDIS_802_11_POWER_MODE = Int32
Ndis802_11PowerModeCAM: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_POWER_MODE = 0
Ndis802_11PowerModeMAX_PSP: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_POWER_MODE = 1
Ndis802_11PowerModeFast_PSP: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_POWER_MODE = 2
Ndis802_11PowerModeMax: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_POWER_MODE = 3
NDIS_802_11_PRIVACY_FILTER = Int32
Ndis802_11PrivFilterAcceptAll: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_PRIVACY_FILTER = 0
Ndis802_11PrivFilter8021xWEP: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_PRIVACY_FILTER = 1
NDIS_802_11_RADIO_STATUS = Int32
Ndis802_11RadioStatusOn: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_RADIO_STATUS = 0
Ndis802_11RadioStatusHardwareOff: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_RADIO_STATUS = 1
Ndis802_11RadioStatusSoftwareOff: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_RADIO_STATUS = 2
Ndis802_11RadioStatusHardwareSoftwareOff: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_RADIO_STATUS = 3
Ndis802_11RadioStatusMax: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_RADIO_STATUS = 4
NDIS_802_11_RELOAD_DEFAULTS = Int32
Ndis802_11ReloadWEPKeys: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_RELOAD_DEFAULTS = 0
class NDIS_802_11_REMOVE_KEY(Structure):
    Length: UInt32
    KeyIndex: UInt32
    BSSID: Byte * 6
class NDIS_802_11_SSID(Structure):
    SsidLength: UInt32
    Ssid: Byte * 32
class NDIS_802_11_STATISTICS(Structure):
    Length: UInt32
    TransmittedFragmentCount: Int64
    MulticastTransmittedFrameCount: Int64
    FailedCount: Int64
    RetryCount: Int64
    MultipleRetryCount: Int64
    RTSSuccessCount: Int64
    RTSFailureCount: Int64
    ACKFailureCount: Int64
    FrameDuplicateCount: Int64
    ReceivedFragmentCount: Int64
    MulticastReceivedFrameCount: Int64
    FCSErrorCount: Int64
    TKIPLocalMICFailures: Int64
    TKIPICVErrorCount: Int64
    TKIPCounterMeasuresInvoked: Int64
    TKIPReplays: Int64
    CCMPFormatErrors: Int64
    CCMPReplays: Int64
    CCMPDecryptErrors: Int64
    FourWayHandshakeFailures: Int64
    WEPUndecryptableCount: Int64
    WEPICVErrorCount: Int64
    DecryptSuccessCount: Int64
    DecryptFailureCount: Int64
class NDIS_802_11_STATUS_INDICATION(Structure):
    StatusType: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_STATUS_TYPE
NDIS_802_11_STATUS_TYPE = Int32
Ndis802_11StatusType_Authentication: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_STATUS_TYPE = 0
Ndis802_11StatusType_MediaStreamMode: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_STATUS_TYPE = 1
Ndis802_11StatusType_PMKID_CandidateList: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_STATUS_TYPE = 2
Ndis802_11StatusTypeMax: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_STATUS_TYPE = 3
class NDIS_802_11_TEST(Structure):
    Length: UInt32
    Type: UInt32
    Anonymous: _Anonymous_e__Union
    class _Anonymous_e__Union(Union):
        AuthenticationEvent: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_AUTHENTICATION_EVENT
        RssiTrigger: Int32
class NDIS_802_11_VARIABLE_IEs(Structure):
    ElementID: Byte
    Length: Byte
    data: Byte * 1
class NDIS_802_11_WEP(Structure):
    Length: UInt32
    KeyIndex: UInt32
    KeyLength: UInt32
    KeyMaterial: Byte * 1
NDIS_802_11_WEP_STATUS = Int32
Ndis802_11WEPEnabled: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_WEP_STATUS = 0
Ndis802_11Encryption1Enabled: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_WEP_STATUS = 0
Ndis802_11WEPDisabled: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_WEP_STATUS = 1
Ndis802_11EncryptionDisabled: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_WEP_STATUS = 1
Ndis802_11WEPKeyAbsent: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_WEP_STATUS = 2
Ndis802_11Encryption1KeyAbsent: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_WEP_STATUS = 2
Ndis802_11WEPNotSupported: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_WEP_STATUS = 3
Ndis802_11EncryptionNotSupported: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_WEP_STATUS = 3
Ndis802_11Encryption2Enabled: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_WEP_STATUS = 4
Ndis802_11Encryption2KeyAbsent: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_WEP_STATUS = 5
Ndis802_11Encryption3Enabled: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_WEP_STATUS = 6
Ndis802_11Encryption3KeyAbsent: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_WEP_STATUS = 7
NDIS_802_5_RING_STATE = Int32
NdisRingStateOpened: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_5_RING_STATE = 1
NdisRingStateClosed: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_5_RING_STATE = 2
NdisRingStateOpening: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_5_RING_STATE = 3
NdisRingStateClosing: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_5_RING_STATE = 4
NdisRingStateOpenFailure: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_5_RING_STATE = 5
NdisRingStateRingFailure: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_5_RING_STATE = 6
class NDIS_CO_DEVICE_PROFILE(Structure):
    DeviceDescription: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_VAR_DATA_DESC
    DevSpecificInfo: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_VAR_DATA_DESC
    ulTAPISupplementaryPassThru: UInt32
    ulAddressModes: UInt32
    ulNumAddresses: UInt32
    ulBearerModes: UInt32
    ulMaxTxRate: UInt32
    ulMinTxRate: UInt32
    ulMaxRxRate: UInt32
    ulMinRxRate: UInt32
    ulMediaModes: UInt32
    ulGenerateToneModes: UInt32
    ulGenerateToneMaxNumFreq: UInt32
    ulGenerateDigitModes: UInt32
    ulMonitorToneMaxNumFreq: UInt32
    ulMonitorToneMaxNumEntries: UInt32
    ulMonitorDigitModes: UInt32
    ulGatherDigitsMinTimeout: UInt32
    ulGatherDigitsMaxTimeout: UInt32
    ulDevCapFlags: UInt32
    ulMaxNumActiveCalls: UInt32
    ulAnswerMode: UInt32
    ulUUIAcceptSize: UInt32
    ulUUIAnswerSize: UInt32
    ulUUIMakeCallSize: UInt32
    ulUUIDropSize: UInt32
    ulUUISendUserUserInfoSize: UInt32
    ulUUICallInfoSize: UInt32
class NDIS_CO_LINK_SPEED(Structure):
    Outbound: UInt32
    Inbound: UInt32
NDIS_DEVICE_POWER_STATE = Int32
NdisDeviceStateUnspecified: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_DEVICE_POWER_STATE = 0
NdisDeviceStateD0: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_DEVICE_POWER_STATE = 1
NdisDeviceStateD1: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_DEVICE_POWER_STATE = 2
NdisDeviceStateD2: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_DEVICE_POWER_STATE = 3
NdisDeviceStateD3: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_DEVICE_POWER_STATE = 4
NdisDeviceStateMaximum: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_DEVICE_POWER_STATE = 5
NDIS_FDDI_ATTACHMENT_TYPE = Int32
NdisFddiTypeIsolated: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_ATTACHMENT_TYPE = 1
NdisFddiTypeLocalA: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_ATTACHMENT_TYPE = 2
NdisFddiTypeLocalB: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_ATTACHMENT_TYPE = 3
NdisFddiTypeLocalAB: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_ATTACHMENT_TYPE = 4
NdisFddiTypeLocalS: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_ATTACHMENT_TYPE = 5
NdisFddiTypeWrapA: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_ATTACHMENT_TYPE = 6
NdisFddiTypeWrapB: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_ATTACHMENT_TYPE = 7
NdisFddiTypeWrapAB: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_ATTACHMENT_TYPE = 8
NdisFddiTypeWrapS: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_ATTACHMENT_TYPE = 9
NdisFddiTypeCWrapA: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_ATTACHMENT_TYPE = 10
NdisFddiTypeCWrapB: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_ATTACHMENT_TYPE = 11
NdisFddiTypeCWrapS: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_ATTACHMENT_TYPE = 12
NdisFddiTypeThrough: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_ATTACHMENT_TYPE = 13
NDIS_FDDI_LCONNECTION_STATE = Int32
NdisFddiStateOff: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_LCONNECTION_STATE = 1
NdisFddiStateBreak: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_LCONNECTION_STATE = 2
NdisFddiStateTrace: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_LCONNECTION_STATE = 3
NdisFddiStateConnect: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_LCONNECTION_STATE = 4
NdisFddiStateNext: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_LCONNECTION_STATE = 5
NdisFddiStateSignal: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_LCONNECTION_STATE = 6
NdisFddiStateJoin: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_LCONNECTION_STATE = 7
NdisFddiStateVerify: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_LCONNECTION_STATE = 8
NdisFddiStateActive: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_LCONNECTION_STATE = 9
NdisFddiStateMaintenance: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_LCONNECTION_STATE = 10
NDIS_FDDI_RING_MGT_STATE = Int32
NdisFddiRingIsolated: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_RING_MGT_STATE = 1
NdisFddiRingNonOperational: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_RING_MGT_STATE = 2
NdisFddiRingOperational: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_RING_MGT_STATE = 3
NdisFddiRingDetect: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_RING_MGT_STATE = 4
NdisFddiRingNonOperationalDup: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_RING_MGT_STATE = 5
NdisFddiRingOperationalDup: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_RING_MGT_STATE = 6
NdisFddiRingDirected: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_RING_MGT_STATE = 7
NdisFddiRingTrace: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_FDDI_RING_MGT_STATE = 8
class NDIS_GUID(Structure):
    Guid: Guid
    Anonymous: _Anonymous_e__Union
    Size: UInt32
    Flags: UInt32
    class _Anonymous_e__Union(Union):
        Oid: UInt32
        Status: Int32
class NDIS_HARDWARE_CROSSTIMESTAMP(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    Flags: UInt32
    SystemTimestamp1: UInt64
    HardwareClockTimestamp: UInt64
    SystemTimestamp2: UInt64
NDIS_HARDWARE_STATUS = Int32
NdisHardwareStatusReady: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_HARDWARE_STATUS = 0
NdisHardwareStatusInitializing: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_HARDWARE_STATUS = 1
NdisHardwareStatusReset: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_HARDWARE_STATUS = 2
NdisHardwareStatusClosing: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_HARDWARE_STATUS = 3
NdisHardwareStatusNotReady: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_HARDWARE_STATUS = 4
class NDIS_INTERFACE_INFORMATION(Structure):
    ifOperStatus: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_OPER_STATUS
    ifOperStatusFlags: UInt32
    MediaConnectState: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_MEDIA_CONNECT_STATE
    MediaDuplexState: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_MEDIA_DUPLEX_STATE
    ifMtu: UInt32
    ifPromiscuousMode: win32more.Windows.Win32.Foundation.BOOLEAN
    ifDeviceWakeUpEnable: win32more.Windows.Win32.Foundation.BOOLEAN
    XmitLinkSpeed: UInt64
    RcvLinkSpeed: UInt64
    ifLastChange: UInt64
    ifCounterDiscontinuityTime: UInt64
    ifInUnknownProtos: UInt64
    ifInDiscards: UInt64
    ifInErrors: UInt64
    ifHCInOctets: UInt64
    ifHCInUcastPkts: UInt64
    ifHCInMulticastPkts: UInt64
    ifHCInBroadcastPkts: UInt64
    ifHCOutOctets: UInt64
    ifHCOutUcastPkts: UInt64
    ifHCOutMulticastPkts: UInt64
    ifHCOutBroadcastPkts: UInt64
    ifOutErrors: UInt64
    ifOutDiscards: UInt64
    ifHCInUcastOctets: UInt64
    ifHCInMulticastOctets: UInt64
    ifHCInBroadcastOctets: UInt64
    ifHCOutUcastOctets: UInt64
    ifHCOutMulticastOctets: UInt64
    ifHCOutBroadcastOctets: UInt64
    CompartmentId: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_COMPARTMENT_ID
    SupportedStatistics: UInt32
NDIS_INTERRUPT_MODERATION = Int32
NdisInterruptModerationUnknown: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_INTERRUPT_MODERATION = 0
NdisInterruptModerationNotSupported: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_INTERRUPT_MODERATION = 1
NdisInterruptModerationEnabled: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_INTERRUPT_MODERATION = 2
NdisInterruptModerationDisabled: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_INTERRUPT_MODERATION = 3
class NDIS_INTERRUPT_MODERATION_PARAMETERS(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    Flags: UInt32
    InterruptModeration: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_INTERRUPT_MODERATION
class NDIS_IPSEC_OFFLOAD_V1(Structure):
    Supported: _Supported_e__Struct
    IPv4AH: _IPv4AH_e__Struct
    IPv4ESP: _IPv4ESP_e__Struct
    class _Supported_e__Struct(Structure):
        Encapsulation: UInt32
        AhEspCombined: UInt32
        TransportTunnelCombined: UInt32
        IPv4Options: UInt32
        Flags: UInt32
    class _IPv4AH_e__Struct(Structure):
        Md5: Annotated[UInt32, 2]
        Sha_1: Annotated[UInt32, 2]
        Transport: Annotated[UInt32, 2]
        Tunnel: Annotated[UInt32, 2]
        Send: Annotated[UInt32, 2]
        Receive: Annotated[UInt32, 2]
    class _IPv4ESP_e__Struct(Structure):
        Des: Annotated[UInt32, 2]
        Reserved: Annotated[UInt32, 2]
        TripleDes: Annotated[UInt32, 2]
        NullEsp: Annotated[UInt32, 2]
        Transport: Annotated[UInt32, 2]
        Tunnel: Annotated[UInt32, 2]
        Send: Annotated[UInt32, 2]
        Receive: Annotated[UInt32, 2]
class NDIS_IP_OPER_STATE(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    Flags: UInt32
    IpOperationalStatus: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_IP_OPER_STATUS
class NDIS_IP_OPER_STATUS(Structure):
    AddressFamily: UInt32
    OperationalStatus: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_OPER_STATUS
    OperationalStatusFlags: UInt32
class NDIS_IP_OPER_STATUS_INFO(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    Flags: UInt32
    NumberofAddressFamiliesReturned: UInt32
    IpOperationalStatus: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_IP_OPER_STATUS * 32
class NDIS_IRDA_PACKET_INFO(Structure):
    ExtraBOFs: UInt32
    MinTurnAroundTime: UInt32
class NDIS_LINK_PARAMETERS(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    MediaDuplexState: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_MEDIA_DUPLEX_STATE
    XmitLinkSpeed: UInt64
    RcvLinkSpeed: UInt64
    PauseFunctions: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_SUPPORTED_PAUSE_FUNCTIONS
    AutoNegotiationFlags: UInt32
class NDIS_LINK_SPEED(Structure):
    XmitLinkSpeed: UInt64
    RcvLinkSpeed: UInt64
class NDIS_LINK_STATE(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    MediaConnectState: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_MEDIA_CONNECT_STATE
    MediaDuplexState: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_MEDIA_DUPLEX_STATE
    XmitLinkSpeed: UInt64
    RcvLinkSpeed: UInt64
    PauseFunctions: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_SUPPORTED_PAUSE_FUNCTIONS
    AutoNegotiationFlags: UInt32
NDIS_MEDIA_STATE = Int32
NdisMediaStateConnected: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIA_STATE = 0
NdisMediaStateDisconnected: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIA_STATE = 1
NDIS_MEDIUM = Int32
NdisMedium802_3: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 0
NdisMedium802_5: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 1
NdisMediumFddi: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 2
NdisMediumWan: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 3
NdisMediumLocalTalk: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 4
NdisMediumDix: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 5
NdisMediumArcnetRaw: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 6
NdisMediumArcnet878_2: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 7
NdisMediumAtm: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 8
NdisMediumWirelessWan: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 9
NdisMediumIrda: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 10
NdisMediumBpc: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 11
NdisMediumCoWan: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 12
NdisMedium1394: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 13
NdisMediumInfiniBand: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 14
NdisMediumTunnel: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 15
NdisMediumNative802_11: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 16
NdisMediumLoopback: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 17
NdisMediumWiMAX: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 18
NdisMediumIP: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 19
NdisMediumMax: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_MEDIUM = 20
NDIS_NETWORK_CHANGE_TYPE = Int32
NdisPossibleNetworkChange: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_NETWORK_CHANGE_TYPE = 1
NdisDefinitelyNetworkChange: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_NETWORK_CHANGE_TYPE = 2
NdisNetworkChangeFromMediaConnect: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_NETWORK_CHANGE_TYPE = 3
NdisNetworkChangeMax: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_NETWORK_CHANGE_TYPE = 4
class NDIS_OBJECT_HEADER(Structure):
    Type: Byte
    Revision: Byte
    Size: UInt16
class NDIS_OFFLOAD(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    Checksum: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_TCP_IP_CHECKSUM_OFFLOAD
    LsoV1: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_TCP_LARGE_SEND_OFFLOAD_V1
    IPsecV1: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_IPSEC_OFFLOAD_V1
    LsoV2: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_TCP_LARGE_SEND_OFFLOAD_V2
    Flags: UInt32
class NDIS_OFFLOAD_PARAMETERS(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    IPv4Checksum: Byte
    TCPIPv4Checksum: Byte
    UDPIPv4Checksum: Byte
    TCPIPv6Checksum: Byte
    UDPIPv6Checksum: Byte
    LsoV1: Byte
    IPsecV1: Byte
    LsoV2IPv4: Byte
    LsoV2IPv6: Byte
    TcpConnectionIPv4: Byte
    TcpConnectionIPv6: Byte
    Flags: UInt32
class NDIS_OPER_STATE(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    OperationalStatus: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_OPER_STATUS
    OperationalStatusFlags: UInt32
class NDIS_PCI_DEVICE_CUSTOM_PROPERTIES(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    DeviceType: UInt32
    CurrentSpeedAndMode: UInt32
    CurrentPayloadSize: UInt32
    MaxPayloadSize: UInt32
    MaxReadRequestSize: UInt32
    CurrentLinkSpeed: UInt32
    CurrentLinkWidth: UInt32
    MaxLinkSpeed: UInt32
    MaxLinkWidth: UInt32
    PciExpressVersion: UInt32
    InterruptType: UInt32
    MaxInterruptMessages: UInt32
NDIS_PHYSICAL_MEDIUM = Int32
NdisPhysicalMediumUnspecified: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 0
NdisPhysicalMediumWirelessLan: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 1
NdisPhysicalMediumCableModem: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 2
NdisPhysicalMediumPhoneLine: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 3
NdisPhysicalMediumPowerLine: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 4
NdisPhysicalMediumDSL: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 5
NdisPhysicalMediumFibreChannel: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 6
NdisPhysicalMedium1394: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 7
NdisPhysicalMediumWirelessWan: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 8
NdisPhysicalMediumNative802_11: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 9
NdisPhysicalMediumBluetooth: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 10
NdisPhysicalMediumInfiniband: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 11
NdisPhysicalMediumWiMax: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 12
NdisPhysicalMediumUWB: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 13
NdisPhysicalMedium802_3: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 14
NdisPhysicalMedium802_5: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 15
NdisPhysicalMediumIrda: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 16
NdisPhysicalMediumWiredWAN: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 17
NdisPhysicalMediumWiredCoWan: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 18
NdisPhysicalMediumOther: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 19
NdisPhysicalMediumNative802_15_4: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 20
NdisPhysicalMediumMax: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PHYSICAL_MEDIUM = 21
class NDIS_PM_PACKET_PATTERN(Structure):
    Priority: UInt32
    Reserved: UInt32
    MaskSize: UInt32
    PatternOffset: UInt32
    PatternSize: UInt32
    PatternFlags: UInt32
class NDIS_PM_WAKE_UP_CAPABILITIES(Structure):
    MinMagicPacketWakeUp: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_DEVICE_POWER_STATE
    MinPatternWakeUp: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_DEVICE_POWER_STATE
    MinLinkChangeWakeUp: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_DEVICE_POWER_STATE
class NDIS_PNP_CAPABILITIES(Structure):
    Flags: UInt32
    WakeUpCapabilities: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PM_WAKE_UP_CAPABILITIES
class NDIS_PORT(Structure):
    Next: POINTER(win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT)
    NdisReserved: VoidPtr
    MiniportReserved: VoidPtr
    ProtocolReserved: VoidPtr
    PortCharacteristics: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_CHARACTERISTICS
class NDIS_PORT_ARRAY(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    NumberOfPorts: UInt32
    OffsetFirstPort: UInt32
    ElementSize: UInt32
    Ports: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_CHARACTERISTICS * 1
class NDIS_PORT_AUTHENTICATION_PARAMETERS(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    SendControlState: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_CONTROL_STATE
    RcvControlState: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_CONTROL_STATE
    SendAuthorizationState: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_AUTHORIZATION_STATE
    RcvAuthorizationState: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_AUTHORIZATION_STATE
NDIS_PORT_AUTHORIZATION_STATE = Int32
NdisPortAuthorizationUnknown: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_AUTHORIZATION_STATE = 0
NdisPortAuthorized: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_AUTHORIZATION_STATE = 1
NdisPortUnauthorized: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_AUTHORIZATION_STATE = 2
NdisPortReauthorizing: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_AUTHORIZATION_STATE = 3
class NDIS_PORT_CHARACTERISTICS(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    PortNumber: UInt32
    Flags: UInt32
    Type: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_TYPE
    MediaConnectState: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_MEDIA_CONNECT_STATE
    XmitLinkSpeed: UInt64
    RcvLinkSpeed: UInt64
    Direction: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_DIRECTION_TYPE
    SendControlState: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_CONTROL_STATE
    RcvControlState: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_CONTROL_STATE
    SendAuthorizationState: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_AUTHORIZATION_STATE
    RcvAuthorizationState: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_AUTHORIZATION_STATE
NDIS_PORT_CONTROL_STATE = Int32
NdisPortControlStateUnknown: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_CONTROL_STATE = 0
NdisPortControlStateControlled: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_CONTROL_STATE = 1
NdisPortControlStateUncontrolled: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_CONTROL_STATE = 2
class NDIS_PORT_STATE(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    MediaConnectState: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_MEDIA_CONNECT_STATE
    XmitLinkSpeed: UInt64
    RcvLinkSpeed: UInt64
    Direction: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_DIRECTION_TYPE
    SendControlState: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_CONTROL_STATE
    RcvControlState: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_CONTROL_STATE
    SendAuthorizationState: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_AUTHORIZATION_STATE
    RcvAuthorizationState: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_AUTHORIZATION_STATE
    Flags: UInt32
NDIS_PORT_TYPE = Int32
NdisPortTypeUndefined: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_TYPE = 0
NdisPortTypeBridge: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_TYPE = 1
NdisPortTypeRasConnection: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_TYPE = 2
NdisPortType8021xSupplicant: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_TYPE = 3
NdisPortTypeMax: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PORT_TYPE = 4
NDIS_PROCESSOR_VENDOR = Int32
NdisProcessorVendorUnknown: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PROCESSOR_VENDOR = 0
NdisProcessorVendorGenuinIntel: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PROCESSOR_VENDOR = 1
NdisProcessorVendorGenuineIntel: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PROCESSOR_VENDOR = 1
NdisProcessorVendorAuthenticAMD: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_PROCESSOR_VENDOR = 2
class NDIS_RECEIVE_HASH_PARAMETERS(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    Flags: UInt32
    HashInformation: UInt32
    HashSecretKeySize: UInt16
    HashSecretKeyOffset: UInt32
class NDIS_RECEIVE_SCALE_CAPABILITIES(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    CapabilitiesFlags: UInt32
    NumberOfInterruptMessages: UInt32
    NumberOfReceiveQueues: UInt32
class NDIS_RECEIVE_SCALE_PARAMETERS(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    Flags: UInt16
    BaseCpuNumber: UInt16
    HashInformation: UInt32
    IndirectionTableSize: UInt16
    IndirectionTableOffset: UInt32
    HashSecretKeySize: UInt16
    HashSecretKeyOffset: UInt32
NDIS_REQUEST_TYPE = Int32
NdisRequestQueryInformation: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_REQUEST_TYPE = 0
NdisRequestSetInformation: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_REQUEST_TYPE = 1
NdisRequestQueryStatistics: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_REQUEST_TYPE = 2
NdisRequestOpen: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_REQUEST_TYPE = 3
NdisRequestClose: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_REQUEST_TYPE = 4
NdisRequestSend: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_REQUEST_TYPE = 5
NdisRequestTransferData: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_REQUEST_TYPE = 6
NdisRequestReset: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_REQUEST_TYPE = 7
NdisRequestGeneric1: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_REQUEST_TYPE = 8
NdisRequestGeneric2: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_REQUEST_TYPE = 9
NdisRequestGeneric3: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_REQUEST_TYPE = 10
NdisRequestGeneric4: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_REQUEST_TYPE = 11
class NDIS_STATISTICS_INFO(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    SupportedStatistics: UInt32
    ifInDiscards: UInt64
    ifInErrors: UInt64
    ifHCInOctets: UInt64
    ifHCInUcastPkts: UInt64
    ifHCInMulticastPkts: UInt64
    ifHCInBroadcastPkts: UInt64
    ifHCOutOctets: UInt64
    ifHCOutUcastPkts: UInt64
    ifHCOutMulticastPkts: UInt64
    ifHCOutBroadcastPkts: UInt64
    ifOutErrors: UInt64
    ifOutDiscards: UInt64
    ifHCInUcastOctets: UInt64
    ifHCInMulticastOctets: UInt64
    ifHCInBroadcastOctets: UInt64
    ifHCOutUcastOctets: UInt64
    ifHCOutMulticastOctets: UInt64
    ifHCOutBroadcastOctets: UInt64
class NDIS_STATISTICS_VALUE(Structure):
    Oid: UInt32
    DataLength: UInt32
    Data: Byte * 1
class NDIS_STATISTICS_VALUE_EX(Structure):
    Oid: UInt32
    DataLength: UInt32
    Length: UInt32
    Data: Byte * 1
NDIS_SUPPORTED_PAUSE_FUNCTIONS = Int32
NdisPauseFunctionsUnsupported: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_SUPPORTED_PAUSE_FUNCTIONS = 0
NdisPauseFunctionsSendOnly: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_SUPPORTED_PAUSE_FUNCTIONS = 1
NdisPauseFunctionsReceiveOnly: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_SUPPORTED_PAUSE_FUNCTIONS = 2
NdisPauseFunctionsSendAndReceive: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_SUPPORTED_PAUSE_FUNCTIONS = 3
NdisPauseFunctionsUnknown: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_SUPPORTED_PAUSE_FUNCTIONS = 4
class NDIS_TCP_CONNECTION_OFFLOAD(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    Encapsulation: UInt32
    SupportIPv4: Annotated[UInt32, 2]
    SupportIPv6: Annotated[UInt32, 2]
    SupportIPv6ExtensionHeaders: Annotated[UInt32, 2]
    SupportSack: Annotated[UInt32, 2]
    TcpConnectionOffloadCapacity: UInt32
    Flags: UInt32
class NDIS_TCP_IP_CHECKSUM_OFFLOAD(Structure):
    IPv4Transmit: _IPv4Transmit_e__Struct
    IPv4Receive: _IPv4Receive_e__Struct
    IPv6Transmit: _IPv6Transmit_e__Struct
    IPv6Receive: _IPv6Receive_e__Struct
    class _IPv4Transmit_e__Struct(Structure):
        Encapsulation: UInt32
        IpOptionsSupported: Annotated[UInt32, 2]
        TcpOptionsSupported: Annotated[UInt32, 2]
        TcpChecksum: Annotated[UInt32, 2]
        UdpChecksum: Annotated[UInt32, 2]
        IpChecksum: Annotated[UInt32, 2]
    class _IPv4Receive_e__Struct(Structure):
        Encapsulation: UInt32
        IpOptionsSupported: Annotated[UInt32, 2]
        TcpOptionsSupported: Annotated[UInt32, 2]
        TcpChecksum: Annotated[UInt32, 2]
        UdpChecksum: Annotated[UInt32, 2]
        IpChecksum: Annotated[UInt32, 2]
    class _IPv6Transmit_e__Struct(Structure):
        Encapsulation: UInt32
        IpExtensionHeadersSupported: Annotated[UInt32, 2]
        TcpOptionsSupported: Annotated[UInt32, 2]
        TcpChecksum: Annotated[UInt32, 2]
        UdpChecksum: Annotated[UInt32, 2]
    class _IPv6Receive_e__Struct(Structure):
        Encapsulation: UInt32
        IpExtensionHeadersSupported: Annotated[UInt32, 2]
        TcpOptionsSupported: Annotated[UInt32, 2]
        TcpChecksum: Annotated[UInt32, 2]
        UdpChecksum: Annotated[UInt32, 2]
class NDIS_TCP_LARGE_SEND_OFFLOAD_V1(Structure):
    IPv4: _IPv4_e__Struct
    class _IPv4_e__Struct(Structure):
        Encapsulation: UInt32
        MaxOffLoadSize: UInt32
        MinSegmentCount: UInt32
        TcpOptions: Annotated[UInt32, 2]
        IpOptions: Annotated[UInt32, 2]
class NDIS_TCP_LARGE_SEND_OFFLOAD_V2(Structure):
    IPv4: _IPv4_e__Struct
    IPv6: _IPv6_e__Struct
    class _IPv4_e__Struct(Structure):
        Encapsulation: UInt32
        MaxOffLoadSize: UInt32
        MinSegmentCount: UInt32
    class _IPv6_e__Struct(Structure):
        Encapsulation: UInt32
        MaxOffLoadSize: UInt32
        MinSegmentCount: UInt32
        IpExtensionHeadersSupported: Annotated[UInt32, 2]
        TcpOptionsSupported: Annotated[UInt32, 2]
class NDIS_TIMEOUT_DPC_REQUEST_CAPABILITIES(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    Flags: UInt32
    TimeoutArrayLength: UInt32
    TimeoutArray: UInt32 * 1
class NDIS_TIMESTAMP_CAPABILITIES(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    HardwareClockFrequencyHz: UInt64
    CrossTimestamp: win32more.Windows.Win32.Foundation.BOOLEAN
    Reserved1: UInt64
    Reserved2: UInt64
    TimestampFlags: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_TIMESTAMP_CAPABILITY_FLAGS
class NDIS_TIMESTAMP_CAPABILITY_FLAGS(Structure):
    PtpV2OverUdpIPv4EventMsgReceiveHw: win32more.Windows.Win32.Foundation.BOOLEAN
    PtpV2OverUdpIPv4AllMsgReceiveHw: win32more.Windows.Win32.Foundation.BOOLEAN
    PtpV2OverUdpIPv4EventMsgTransmitHw: win32more.Windows.Win32.Foundation.BOOLEAN
    PtpV2OverUdpIPv4AllMsgTransmitHw: win32more.Windows.Win32.Foundation.BOOLEAN
    PtpV2OverUdpIPv6EventMsgReceiveHw: win32more.Windows.Win32.Foundation.BOOLEAN
    PtpV2OverUdpIPv6AllMsgReceiveHw: win32more.Windows.Win32.Foundation.BOOLEAN
    PtpV2OverUdpIPv6EventMsgTransmitHw: win32more.Windows.Win32.Foundation.BOOLEAN
    PtpV2OverUdpIPv6AllMsgTransmitHw: win32more.Windows.Win32.Foundation.BOOLEAN
    AllReceiveHw: win32more.Windows.Win32.Foundation.BOOLEAN
    AllTransmitHw: win32more.Windows.Win32.Foundation.BOOLEAN
    TaggedTransmitHw: win32more.Windows.Win32.Foundation.BOOLEAN
    AllReceiveSw: win32more.Windows.Win32.Foundation.BOOLEAN
    AllTransmitSw: win32more.Windows.Win32.Foundation.BOOLEAN
    TaggedTransmitSw: win32more.Windows.Win32.Foundation.BOOLEAN
class NDIS_VAR_DATA_DESC(Structure):
    Length: UInt16
    MaximumLength: UInt16
    Offset: UIntPtr
NDIS_WAN_HEADER_FORMAT = Int32
NdisWanHeaderNative: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_HEADER_FORMAT = 0
NdisWanHeaderEthernet: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_HEADER_FORMAT = 1
NDIS_WAN_MEDIUM_SUBTYPE = Int32
NdisWanMediumHub: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 0
NdisWanMediumX_25: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 1
NdisWanMediumIsdn: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 2
NdisWanMediumSerial: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 3
NdisWanMediumFrameRelay: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 4
NdisWanMediumAtm: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 5
NdisWanMediumSonet: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 6
NdisWanMediumSW56K: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 7
NdisWanMediumPPTP: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 8
NdisWanMediumL2TP: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 9
NdisWanMediumIrda: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 10
NdisWanMediumParallel: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 11
NdisWanMediumPppoe: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 12
NdisWanMediumSSTP: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 13
NdisWanMediumAgileVPN: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 14
NdisWanMediumGre: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 15
NdisWanMediumSubTypeMax: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_MEDIUM_SUBTYPE = 16
class NDIS_WAN_PROTOCOL_CAPS(Structure):
    Flags: UInt32
    Reserved: UInt32
NDIS_WAN_QUALITY = Int32
NdisWanRaw: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_QUALITY = 0
NdisWanErrorControl: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_QUALITY = 1
NdisWanReliable: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WAN_QUALITY = 2
class NDIS_WLAN_BSSID(Structure):
    Length: UInt32
    MacAddress: Byte * 6
    Reserved: Byte * 2
    Ssid: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_SSID
    Privacy: UInt32
    Rssi: Int32
    NetworkTypeInUse: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_TYPE
    Configuration: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_CONFIGURATION
    InfrastructureMode: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_INFRASTRUCTURE
    SupportedRates: Byte * 8
class NDIS_WLAN_BSSID_EX(Structure):
    Length: UInt32
    MacAddress: Byte * 6
    Reserved: Byte * 2
    Ssid: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_SSID
    Privacy: UInt32
    Rssi: Int32
    NetworkTypeInUse: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_TYPE
    Configuration: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_CONFIGURATION
    InfrastructureMode: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_802_11_NETWORK_INFRASTRUCTURE
    SupportedRates: Byte * 16
    IELength: UInt32
    IEs: Byte * 1
class NDIS_WMI_ENUM_ADAPTER(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    IfIndex: UInt32
    NetLuid: win32more.Windows.Win32.NetworkManagement.Ndis.NET_LUID_LH
    DeviceNameLength: UInt16
    DeviceName: win32more.Windows.Win32.Foundation.CHAR * 1
class NDIS_WMI_EVENT_HEADER(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    IfIndex: UInt32
    NetLuid: win32more.Windows.Win32.NetworkManagement.Ndis.NET_LUID_LH
    RequestId: UInt64
    PortNumber: UInt32
    DeviceNameLength: UInt32
    DeviceNameOffset: UInt32
    Padding: Byte * 4
class NDIS_WMI_IPSEC_OFFLOAD_V1(Structure):
    Supported: _Supported_e__Struct
    IPv4AH: _IPv4AH_e__Struct
    IPv4ESP: _IPv4ESP_e__Struct
    class _Supported_e__Struct(Structure):
        Encapsulation: UInt32
        AhEspCombined: UInt32
        TransportTunnelCombined: UInt32
        IPv4Options: UInt32
        Flags: UInt32
    class _IPv4AH_e__Struct(Structure):
        Md5: UInt32
        Sha_1: UInt32
        Transport: UInt32
        Tunnel: UInt32
        Send: UInt32
        Receive: UInt32
    class _IPv4ESP_e__Struct(Structure):
        Des: UInt32
        Reserved: UInt32
        TripleDes: UInt32
        NullEsp: UInt32
        Transport: UInt32
        Tunnel: UInt32
        Send: UInt32
        Receive: UInt32
class NDIS_WMI_METHOD_HEADER(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    PortNumber: UInt32
    NetLuid: win32more.Windows.Win32.NetworkManagement.Ndis.NET_LUID_LH
    RequestId: UInt64
    Timeout: UInt32
    Padding: Byte * 4
class NDIS_WMI_OFFLOAD(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    Checksum: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WMI_TCP_IP_CHECKSUM_OFFLOAD
    LsoV1: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WMI_TCP_LARGE_SEND_OFFLOAD_V1
    IPsecV1: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WMI_IPSEC_OFFLOAD_V1
    LsoV2: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_WMI_TCP_LARGE_SEND_OFFLOAD_V2
    Flags: UInt32
class NDIS_WMI_OUTPUT_INFO(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    Flags: UInt32
    SupportedRevision: Byte
    DataOffset: UInt32
class NDIS_WMI_SET_HEADER(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    PortNumber: UInt32
    NetLuid: win32more.Windows.Win32.NetworkManagement.Ndis.NET_LUID_LH
    RequestId: UInt64
    Timeout: UInt32
    Padding: Byte * 4
class NDIS_WMI_TCP_CONNECTION_OFFLOAD(Structure):
    Header: win32more.Windows.Win32.NetworkManagement.Ndis.NDIS_OBJECT_HEADER
    Encapsulation: UInt32
    SupportIPv4: UInt32
    SupportIPv6: UInt32
    SupportIPv6ExtensionHeaders: UInt32
    SupportSack: UInt32
    TcpConnectionOffloadCapacity: UInt32
    Flags: UInt32
class NDIS_WMI_TCP_IP_CHECKSUM_OFFLOAD(Structure):
    IPv4Transmit: _IPv4Transmit_e__Struct
    IPv4Receive: _IPv4Receive_e__Struct
    IPv6Transmit: _IPv6Transmit_e__Struct
    IPv6Receive: _IPv6Receive_e__Struct
    class _IPv4Transmit_e__Struct(Structure):
        Encapsulation: UInt32
        IpOptionsSupported: UInt32
        TcpOptionsSupported: UInt32
        TcpChecksum: UInt32
        UdpChecksum: UInt32
        IpChecksum: UInt32
    class _IPv4Receive_e__Struct(Structure):
        Encapsulation: UInt32
        IpOptionsSupported: UInt32
        TcpOptionsSupported: UInt32
        TcpChecksum: UInt32
        UdpChecksum: UInt32
        IpChecksum: UInt32
    class _IPv6Transmit_e__Struct(Structure):
        Encapsulation: UInt32
        IpExtensionHeadersSupported: UInt32
        TcpOptionsSupported: UInt32
        TcpChecksum: UInt32
        UdpChecksum: UInt32
    class _IPv6Receive_e__Struct(Structure):
        Encapsulation: UInt32
        IpExtensionHeadersSupported: UInt32
        TcpOptionsSupported: UInt32
        TcpChecksum: UInt32
        UdpChecksum: UInt32
class NDIS_WMI_TCP_LARGE_SEND_OFFLOAD_V1(Structure):
    IPv4: _IPv4_e__Struct
    class _IPv4_e__Struct(Structure):
        Encapsulation: UInt32
        MaxOffLoadSize: UInt32
        MinSegmentCount: UInt32
        TcpOptions: UInt32
        IpOptions: UInt32
class NDIS_WMI_TCP_LARGE_SEND_OFFLOAD_V2(Structure):
    IPv4: _IPv4_e__Struct
    IPv6: _IPv6_e__Struct
    class _IPv4_e__Struct(Structure):
        Encapsulation: UInt32
        MaxOffLoadSize: UInt32
        MinSegmentCount: UInt32
    class _IPv6_e__Struct(Structure):
        Encapsulation: UInt32
        MaxOffLoadSize: UInt32
        MinSegmentCount: UInt32
        IpExtensionHeadersSupported: UInt32
        TcpOptionsSupported: UInt32
class NDK_ADAPTER_INFO(Structure):
    Version: win32more.Windows.Win32.NetworkManagement.Ndis.NDK_VERSION
    VendorId: UInt32
    DeviceId: UInt32
    MaxRegistrationSize: UIntPtr
    MaxWindowSize: UIntPtr
    FRMRPageCount: UInt32
    MaxInitiatorRequestSge: UInt32
    MaxReceiveRequestSge: UInt32
    MaxReadRequestSge: UInt32
    MaxTransferLength: UInt32
    MaxInlineDataSize: UInt32
    MaxInboundReadLimit: UInt32
    MaxOutboundReadLimit: UInt32
    MaxReceiveQueueDepth: UInt32
    MaxInitiatorQueueDepth: UInt32
    MaxSrqDepth: UInt32
    MaxCqDepth: UInt32
    LargeRequestThreshold: UInt32
    MaxCallerData: UInt32
    MaxCalleeData: UInt32
    AdapterFlags: UInt32
    RdmaTechnology: win32more.Windows.Win32.NetworkManagement.Ndis.NDK_RDMA_TECHNOLOGY
NDK_RDMA_TECHNOLOGY = Int32
NdkUndefined: win32more.Windows.Win32.NetworkManagement.Ndis.NDK_RDMA_TECHNOLOGY = 0
NdkiWarp: win32more.Windows.Win32.NetworkManagement.Ndis.NDK_RDMA_TECHNOLOGY = 1
NdkInfiniBand: win32more.Windows.Win32.NetworkManagement.Ndis.NDK_RDMA_TECHNOLOGY = 2
NdkRoCE: win32more.Windows.Win32.NetworkManagement.Ndis.NDK_RDMA_TECHNOLOGY = 3
NdkRoCEv2: win32more.Windows.Win32.NetworkManagement.Ndis.NDK_RDMA_TECHNOLOGY = 4
NdkMaxTechnology: win32more.Windows.Win32.NetworkManagement.Ndis.NDK_RDMA_TECHNOLOGY = 5
class NDK_VERSION(Structure):
    Major: UInt16
    Minor: UInt16
class NETWORK_ADDRESS(Structure):
    AddressLength: UInt16
    AddressType: UInt16
    Address: Byte * 1
class NETWORK_ADDRESS_IP(Structure):
    sin_port: UInt16
    IN_ADDR: UInt32
    sin_zero: Byte * 8
class NETWORK_ADDRESS_IP6(Structure):
    sin6_port: UInt16
    sin6_flowinfo: UInt32
    sin6_addr: UInt16 * 8
    sin6_scope_id: UInt32
class NETWORK_ADDRESS_IPX(Structure):
    NetworkAddress: UInt32
    NodeAddress: Byte * 6
    Socket: UInt16
class NETWORK_ADDRESS_LIST(Structure):
    AddressCount: Int32
    AddressType: UInt16
    Address: win32more.Windows.Win32.NetworkManagement.Ndis.NETWORK_ADDRESS * 1
NET_IF_ACCESS_TYPE = Int32
NET_IF_ACCESS_LOOPBACK: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_ACCESS_TYPE = 1
NET_IF_ACCESS_BROADCAST: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_ACCESS_TYPE = 2
NET_IF_ACCESS_POINT_TO_POINT: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_ACCESS_TYPE = 3
NET_IF_ACCESS_POINT_TO_MULTI_POINT: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_ACCESS_TYPE = 4
NET_IF_ACCESS_MAXIMUM: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_ACCESS_TYPE = 5
NET_IF_ADMIN_STATUS = Int32
NET_IF_ADMIN_STATUS_UP: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_ADMIN_STATUS = 1
NET_IF_ADMIN_STATUS_DOWN: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_ADMIN_STATUS = 2
NET_IF_ADMIN_STATUS_TESTING: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_ADMIN_STATUS = 3
class NET_IF_ALIAS_LH(Structure):
    ifAliasLength: UInt16
    ifAliasOffset: UInt16
NET_IF_COMPARTMENT_ID = UInt32
NET_IF_CONNECTION_TYPE = Int32
NET_IF_CONNECTION_DEDICATED: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_CONNECTION_TYPE = 1
NET_IF_CONNECTION_PASSIVE: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_CONNECTION_TYPE = 2
NET_IF_CONNECTION_DEMAND: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_CONNECTION_TYPE = 3
NET_IF_CONNECTION_MAXIMUM: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_CONNECTION_TYPE = 4
NET_IF_DIRECTION_TYPE = Int32
NET_IF_DIRECTION_SENDRECEIVE: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_DIRECTION_TYPE = 0
NET_IF_DIRECTION_SENDONLY: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_DIRECTION_TYPE = 1
NET_IF_DIRECTION_RECEIVEONLY: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_DIRECTION_TYPE = 2
NET_IF_DIRECTION_MAXIMUM: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_DIRECTION_TYPE = 3
NET_IF_MEDIA_CONNECT_STATE = Int32
MediaConnectStateUnknown: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_MEDIA_CONNECT_STATE = 0
MediaConnectStateConnected: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_MEDIA_CONNECT_STATE = 1
MediaConnectStateDisconnected: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_MEDIA_CONNECT_STATE = 2
NET_IF_MEDIA_DUPLEX_STATE = Int32
MediaDuplexStateUnknown: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_MEDIA_DUPLEX_STATE = 0
MediaDuplexStateHalf: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_MEDIA_DUPLEX_STATE = 1
MediaDuplexStateFull: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_MEDIA_DUPLEX_STATE = 2
NET_IF_OPER_STATUS = Int32
NET_IF_OPER_STATUS_UP: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_OPER_STATUS = 1
NET_IF_OPER_STATUS_DOWN: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_OPER_STATUS = 2
NET_IF_OPER_STATUS_TESTING: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_OPER_STATUS = 3
NET_IF_OPER_STATUS_UNKNOWN: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_OPER_STATUS = 4
NET_IF_OPER_STATUS_DORMANT: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_OPER_STATUS = 5
NET_IF_OPER_STATUS_NOT_PRESENT: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_OPER_STATUS = 6
NET_IF_OPER_STATUS_LOWER_LAYER_DOWN: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_OPER_STATUS = 7
class NET_IF_RCV_ADDRESS_LH(Structure):
    ifRcvAddressType: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_RCV_ADDRESS_TYPE
    ifRcvAddressLength: UInt16
    ifRcvAddressOffset: UInt16
NET_IF_RCV_ADDRESS_TYPE = Int32
NET_IF_RCV_ADDRESS_TYPE_OTHER: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_RCV_ADDRESS_TYPE = 1
NET_IF_RCV_ADDRESS_TYPE_VOLATILE: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_RCV_ADDRESS_TYPE = 2
NET_IF_RCV_ADDRESS_TYPE_NON_VOLATILE: win32more.Windows.Win32.NetworkManagement.Ndis.NET_IF_RCV_ADDRESS_TYPE = 3
class NET_LUID_LH(Union):
    Value: UInt64
    Info: _Info_e__Struct
    class _Info_e__Struct(Structure):
        Reserved: Annotated[UInt64, 24]
        NetLuidIndex: Annotated[UInt64, 24]
        IfType: Annotated[UInt64, 16]
class NET_PHYSICAL_LOCATION_LH(Structure):
    BusNumber: UInt32
    SlotNumber: UInt32
    FunctionNumber: UInt32
class OFFLOAD_ALGO_INFO(Structure):
    algoIdentifier: UInt32
    algoKeylen: UInt32
    algoRounds: UInt32
OFFLOAD_CONF_ALGO = Int32
OFFLOAD_IPSEC_CONF_NONE: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_CONF_ALGO = 0
OFFLOAD_IPSEC_CONF_DES: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_CONF_ALGO = 1
OFFLOAD_IPSEC_CONF_RESERVED: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_CONF_ALGO = 2
OFFLOAD_IPSEC_CONF_3_DES: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_CONF_ALGO = 3
OFFLOAD_IPSEC_CONF_MAX: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_CONF_ALGO = 4
OFFLOAD_INTEGRITY_ALGO = Int32
OFFLOAD_IPSEC_INTEGRITY_NONE: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_INTEGRITY_ALGO = 0
OFFLOAD_IPSEC_INTEGRITY_MD5: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_INTEGRITY_ALGO = 1
OFFLOAD_IPSEC_INTEGRITY_SHA: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_INTEGRITY_ALGO = 2
OFFLOAD_IPSEC_INTEGRITY_MAX: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_INTEGRITY_ALGO = 3
class OFFLOAD_IPSEC_ADD_SA(Structure):
    SrcAddr: UInt32
    SrcMask: UInt32
    DestAddr: UInt32
    DestMask: UInt32
    Protocol: UInt32
    SrcPort: UInt16
    DestPort: UInt16
    SrcTunnelAddr: UInt32
    DestTunnelAddr: UInt32
    Flags: UInt16
    NumSAs: Int16
    SecAssoc: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_SECURITY_ASSOCIATION * 3
    OffloadHandle: win32more.Windows.Win32.Foundation.HANDLE
    KeyLen: UInt32
    KeyMat: Byte * 1
class OFFLOAD_IPSEC_ADD_UDPESP_SA(Structure):
    SrcAddr: UInt32
    SrcMask: UInt32
    DstAddr: UInt32
    DstMask: UInt32
    Protocol: UInt32
    SrcPort: UInt16
    DstPort: UInt16
    SrcTunnelAddr: UInt32
    DstTunnelAddr: UInt32
    Flags: UInt16
    NumSAs: Int16
    SecAssoc: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_SECURITY_ASSOCIATION * 3
    OffloadHandle: win32more.Windows.Win32.Foundation.HANDLE
    EncapTypeEntry: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_IPSEC_UDPESP_ENCAPTYPE_ENTRY
    EncapTypeEntryOffldHandle: win32more.Windows.Win32.Foundation.HANDLE
    KeyLen: UInt32
    KeyMat: Byte * 1
class OFFLOAD_IPSEC_DELETE_SA(Structure):
    OffloadHandle: win32more.Windows.Win32.Foundation.HANDLE
class OFFLOAD_IPSEC_DELETE_UDPESP_SA(Structure):
    OffloadHandle: win32more.Windows.Win32.Foundation.HANDLE
    EncapTypeEntryOffldHandle: win32more.Windows.Win32.Foundation.HANDLE
class OFFLOAD_IPSEC_UDPESP_ENCAPTYPE_ENTRY(Structure):
    UdpEncapType: win32more.Windows.Win32.NetworkManagement.Ndis.UDP_ENCAP_TYPE
    DstEncapPort: UInt16
OFFLOAD_OPERATION_E = Int32
AUTHENTICATE: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_OPERATION_E = 1
ENCRYPT: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_OPERATION_E = 2
class OFFLOAD_SECURITY_ASSOCIATION(Structure):
    Operation: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_OPERATION_E
    SPI: UInt32
    IntegrityAlgo: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_ALGO_INFO
    ConfAlgo: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_ALGO_INFO
    Reserved: win32more.Windows.Win32.NetworkManagement.Ndis.OFFLOAD_ALGO_INFO
class PMKID_CANDIDATE(Structure):
    BSSID: Byte * 6
    Flags: UInt32
class TRANSPORT_HEADER_OFFSET(Structure):
    ProtocolType: UInt16
    HeaderOffset: UInt16
TUNNEL_TYPE = Int32
TUNNEL_TYPE_NONE: win32more.Windows.Win32.NetworkManagement.Ndis.TUNNEL_TYPE = 0
TUNNEL_TYPE_OTHER: win32more.Windows.Win32.NetworkManagement.Ndis.TUNNEL_TYPE = 1
TUNNEL_TYPE_DIRECT: win32more.Windows.Win32.NetworkManagement.Ndis.TUNNEL_TYPE = 2
TUNNEL_TYPE_6TO4: win32more.Windows.Win32.NetworkManagement.Ndis.TUNNEL_TYPE = 11
TUNNEL_TYPE_ISATAP: win32more.Windows.Win32.NetworkManagement.Ndis.TUNNEL_TYPE = 13
TUNNEL_TYPE_TEREDO: win32more.Windows.Win32.NetworkManagement.Ndis.TUNNEL_TYPE = 14
TUNNEL_TYPE_IPHTTPS: win32more.Windows.Win32.NetworkManagement.Ndis.TUNNEL_TYPE = 15
UDP_ENCAP_TYPE = Int32
OFFLOAD_IPSEC_UDPESP_ENCAPTYPE_IKE: win32more.Windows.Win32.NetworkManagement.Ndis.UDP_ENCAP_TYPE = 0
OFFLOAD_IPSEC_UDPESP_ENCAPTYPE_OTHER: win32more.Windows.Win32.NetworkManagement.Ndis.UDP_ENCAP_TYPE = 1


make_ready(__name__)
